#
# spec file for package installation-images
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#
# needsrootforbuild
# needsbinariesforbuild

# This is for building a test iso for debugging. Note when building
# locally with osc you need --nopreinstallimage --userootforbuild
%bcond_with iso

# The files from i-i are, in parts, extracted and published in the FTP Tree
# Since they are all auto-generated files, so they keep on changing. Having the mtime
# constant though causes issues for rsync - which uses this information by default to decide
# wether there is something to sync or not
%global clamp_mtime_to_source_date_epoch 0

# do not build 32-bit s390
ExcludeArch:    s390

%if "openSUSE" == ""
ExclusiveArch:  do_not_build
%endif

%global flavor openSUSE%nil

%define with_vbox 0
%define with_plymouth 1
%define with_shim 1
%define with_storage_ng 1
%define with_reiserfs_kmp 0
%define with_ssl_hmac 1
%define with_exfat 0
%define with_kernel_extra 0
%bcond_without sbl
%bcond_without vnc
%bcond_with xen
%bcond_with xenkmp

# ===  Repo arch may differ from OBS build arch  ===

%define the_arch %{_target_cpu}
%ifarch ppc64 ppc64le
%define the_arch ppc
%endif

# ===  sort out which flavor to build  ===

%if "%flavor" == "openSUSE"
%if 0%{?is_opensuse}
%define theme openSUSE
%if 0%{?sle_version}
%define with_kernel_extra 1
# define the_version %(echo %sle_version | sed -Ee 's/^([0-9][0-9])(0|([0-9]))([0-9]).*/\\1.\\3\\4/')
%define the_version \\$releasever
%if "%{the_version}" == ""
%error "bad version string"
%endif
%define net_repo https://download.opensuse.org/distribution/leap/%{the_version}/repo/oss
%else
%define with_exfat 1
%ifarch %arm aarch64 ppc64 ppc64le
%define net_repo https://download.opensuse.org/ports/%{the_arch}/tumbleweed/repo/oss/
%else
%define net_repo https://download.opensuse.org/tumbleweed/repo/oss
%endif
%endif
%endif
%endif

%if "%flavor" == "Kubic"
# don't build on Leap for now
%if 0%{?is_opensuse} && !0%{?sle_version}
%ifnarch %ix86
%define theme Kubic
%endif
%endif
%endif

%if "%flavor" == "SMO"
%if 0%{?is_smo}
# build for both Leap and SLE
%if 0%{?sle_version}
%ifnarch %ix86
%define theme SMO
%endif
%endif
%endif
%endif

%if "%flavor" == "MicroOS"
# don't build on Leap for now
%if 0%{?is_opensuse} && !0%{?sle_version}
%ifnarch %ix86
%define theme MicroOS
%endif
%endif
%endif

%if "%flavor" == "SLED"
# build SLED only on x86_64
%if "%{_target_cpu}" == "x86_64" && 0%{?sle_version} && !0%{?is_opensuse}
%define theme SLED
%endif
%endif

%if "%flavor" == "SLES"
%if 0%{?sle_version} && !0%{?is_opensuse}
%ifnarch %ix86
%define theme SLES
%endif
%endif
%endif

%if "%flavor" == "SLES_SAP"
%if 0%{?sle_version} && 0%{?is_susesap} && ( "%{_target_cpu}" == "x86_64" || "%{_target_cpu}" == "ppc64le" )
%define theme SLES_SAP
%endif
%endif

%if "%flavor" == "CAASP"
%if 0%{?is_susecaasp}
%ifnarch %ix86
%define theme CAASP
%endif
%endif
%endif

# ===  set product string (based on required packages)  ===

%global product_name %(bash %_sourcedir/product_name)

# ===  define each theme  ===

%if "%{?theme}" == ""
ExclusiveArch:  do_not_build
%endif

%if "%theme" == "openSUSE"
%define with_storage_ng 1
%define with_ssl_hmac 0
%define branding_skelcd   openSUSE
%define branding_systemd  openSUSE
%define branding_plymouth openSUSE
%define branding_grub2    openSUSE
%define branding_gfxboot  openSUSE
BuildRequires:  adobe-sourcesanspro-fonts
BuildRequires:  openSUSE-release
BuildRequires:  susepaste
%if 0%{?is_opensuse} && !0%{?sle_version}
BuildRequires:  distribution-logos-openSUSE-Tumbleweed
%else
BuildRequires:  distribution-logos-openSUSE-Leap
%endif
%endif

%if "%theme" == "Kubic"
%define with_storage_ng 1
%define with_ssl_hmac 0
%define branding_skelcd   Kubic
%define branding_systemd  MicroOS
%define branding_plymouth openSUSE
%define branding_grub2    openSUSE
%define branding_gfxboot  openSUSE
%define config_bootmenu_no_upgrade 1
BuildRequires:  MicroOS-release
BuildRequires:  adobe-sourcesanspro-fonts
BuildRequires:  distribution-logos-openSUSE-Kubic

# Kubic is based on MicroOS but we don't want this to show
# note: keep this in sync with the Kubic settings in etc/config
%global product_name openSUSE-Kubic
%endif

%if "%theme" == "SMO"
%define with_storage_ng 1
%define with_ssl_hmac 0
%define branding_skelcd   SMO
%define branding_systemd  SMO
%define branding_plymouth SLE
%define branding_grub2    SLE
%define branding_gfxboot  SLE
%define config_bootmenu_no_upgrade 1
BuildRequires:  SUSE-MicroOS-release
# system-group-kvm needed for 15-SP2 based MicroOS
BuildRequires:  system-group-kvm 
%endif

%if "%theme" == "MicroOS"
%define with_storage_ng 1
%define with_ssl_hmac 0
%define branding_skelcd   MicroOS
%define branding_systemd  MicroOS
%define branding_plymouth openSUSE
%define branding_grub2    openSUSE
%define branding_gfxboot  openSUSE
%define config_bootmenu_no_upgrade 1
BuildRequires:  MicroOS-release
BuildRequires:  adobe-sourcesanspro-fonts
BuildRequires:  distribution-logos-openSUSE-MicroOS
%endif

%if "%theme" == "SLED"
%define with_reiserfs_kmp 1
%define branding_skelcd   leanos
%define branding_systemd  SLE
%define branding_plymouth SLE
%define branding_grub2    SLE
%define branding_gfxboot  SLE
BuildRequires:  unified-installer-release
%endif

%if "%theme" == "SLES"
%define with_reiserfs_kmp 1
%define branding_skelcd   leanos
%define branding_systemd  SLE
%define branding_plymouth SLE
%define branding_grub2    SLE
%define branding_gfxboot  SLE
BuildRequires:  skelcd-fallbackrepo-SLES
BuildRequires:  system-role-common-criteria
%ifarch x86_64
BuildRequires:  skelcd-fallbackrepo-SLED
BuildRequires:  skelcd-fallbackrepo-SLES_SAP
BuildRequires:  skelcd-fallbackrepo-SLE_HPC
BuildRequires:  skelcd-fallbackrepo-SLE_RT
%endif
%ifarch ppc64le
BuildRequires:  skelcd-fallbackrepo-SLES_SAP
%endif
%ifarch aarch64
BuildRequires:  skelcd-fallbackrepo-SLE_HPC
%endif
BuildRequires:  unified-installer-release
%endif

%if "%theme" == "SLES_SAP"
%define with_reiserfs_kmp 1
%define branding_skelcd   leanos
%define branding_systemd  SLE
%define branding_plymouth SLE
%define branding_grub2    SLE
%define branding_gfxboot  SLE
BuildRequires:  unified-installer-release
%endif

%if "%theme" == "CAASP"
%define with_reiserfs_kmp 1
%define branding_skelcd   CAASP
%define branding_systemd  CAASP
%define branding_plymouth SLE
%define branding_grub2    SLE
%define branding_gfxboot  SLE
%define config_bootmenu_no_upgrade 1
BuildRequires:  caasp-release
BuildRequires:  skelcd-fallbackrepo-CAASP
%endif

# ===  product name with architecture appended  ===

%global product_name_arch %product_name-%{_target_cpu}

# ===  branding specific packages  ===

BuildRequires:  skelcd-control-%branding_skelcd
BuildRequires:  systemd-presets-branding-%branding_systemd
%if %with_plymouth
BuildRequires:  plymouth-branding-%branding_plymouth
%endif
%ifarch %ix86 x86_64
BuildRequires:  gfxboot-branding-%branding_gfxboot
%endif
%ifarch %ix86 x86_64 aarch64 %{arm}
BuildRequires:  grub2-branding-%branding_grub2
%endif

# ===  branding end  ===

# no i586 in Leap
%if %suse_version == 1500
ExcludeArch:    %ix86
%endif

%if %with_reiserfs_kmp
BuildRequires:  reiserfs-kmp-default
%endif
%ifnarch s390x
BuildRequires:  xf86-input-libinput
%endif
BuildRequires:  google-roboto-fonts
BuildRequires:  noto-sans-fonts
%ifarch ia64 %ix86 x86_64
BuildRequires:  libsmbios_c2
%endif
BuildRequires:  Mesa
BuildRequires:  Mesa-libEGL1
BuildRequires:  Mesa-libGL1
BuildRequires:  aaa_base
BuildRequires:  aaa_base-extras
BuildRequires:  adaptec-firmware
BuildRequires:  alsa
BuildRequires:  alsa-utils
BuildRequires:  arphic-uming-fonts
BuildRequires:  audit-libs
BuildRequires:  bc
BuildRequires:  bcache-tools
BuildRequires:  bcm43xx-firmware
BuildRequires:  bind-libs
BuildRequires:  bind-utils
BuildRequires:  blueprint-cursor-theme
BuildRequires:  btrfsprogs
BuildRequires:  build-key
BuildRequires:  busybox
BuildRequires:  bzip2
BuildRequires:  ca-certificates-mozilla
BuildRequires:  cairo
BuildRequires:  checkmedia
BuildRequires:  cifs-utils
BuildRequires:  cracklib
BuildRequires:  cracklib-dict-full
BuildRequires:  cron
BuildRequires:  cryptsetup
BuildRequires:  cups-libs
BuildRequires:  curl
BuildRequires:  dash
BuildRequires:  dbus-1-x11
BuildRequires:  dd_rescue
BuildRequires:  dejavu-fonts
BuildRequires:  dhcp-server
BuildRequires:  dmraid
BuildRequires:  dosfstools
BuildRequires:  dracut-fips
BuildRequires:  dump
BuildRequires:  e2fsprogs
BuildRequires:  ed
BuildRequires:  efont-unicode-bitmap-fonts
BuildRequires:  elfutils
BuildRequires:  ethtool
BuildRequires:  noto-naskharabic-fonts
%if %with_exfat
BuildRequires:  exfatprogs
%endif
BuildRequires:  fbiterm
BuildRequires:  finger
BuildRequires:  fonts-config
BuildRequires:  gamin-server
BuildRequires:  gdb
BuildRequires:  gettext-runtime-mini
BuildRequires:  glibc-i18ndata
BuildRequires:  gpart
BuildRequires:  gpg2
BuildRequires:  gpm
BuildRequires:  gptfdisk
BuildRequires:  graphviz
BuildRequires:  graphviz-gnome
BuildRequires:  haveged
BuildRequires:  hdparm
BuildRequires:  hex
BuildRequires:  hfsutils
BuildRequires:  hostname
BuildRequires:  icewm-lite
BuildRequires:  icmpinfo
BuildRequires:  indic-fonts
BuildRequires:  initviocons
BuildRequires:  ipa-gothic-fonts
BuildRequires:  iproute2
BuildRequires:  iptables
BuildRequires:  iputils
BuildRequires:  iscsiuio
BuildRequires:  jfsutils
BuildRequires:  joe
BuildRequires:  kbd
BuildRequires:  kernel-default
%if %with_kernel_extra
BuildRequires:  kernel-default-extra
BuildRequires:  kernel-default-optional
%endif
BuildRequires:  kernel-firmware
BuildRequires:  kexec-tools
BuildRequires:  khmeros-fonts
BuildRequires:  kmod
BuildRequires:  krb5-devel
BuildRequires:  less
%if %with_ssl_hmac
BuildRequires:  libopenssl1_1-hmac
%endif
BuildRequires:  libpcsclite1
BuildRequires:  libyui-ncurses15
BuildRequires:  libyui-ncurses-pkg15
BuildRequires:  libyui-ncurses-rest-api15
BuildRequires:  libyui-qt15
BuildRequires:  libyui-qt-graph15
BuildRequires:  libyui-qt-pkg15
BuildRequires:  libyui-qt-rest-api15
BuildRequires:  linuxrc
BuildRequires:  lklug-fonts
BuildRequires:  lsscsi
BuildRequires:  lvm2
BuildRequires:  mdadm
BuildRequires:  mingetty
BuildRequires:  mkfontdir
BuildRequires:  mkfontscale
BuildRequires:  mtools
BuildRequires:  multipath-tools
BuildRequires:  nasm
BuildRequires:  ncurses-utils
BuildRequires:  netcat-openbsd
BuildRequires:  netpbm
BuildRequires:  nfs-client
BuildRequires:  nfs-kernel-server
BuildRequires:  nfs-utils
BuildRequires:  novnc
BuildRequires:  ntfs-3g
BuildRequires:  ntfsprogs
BuildRequires:  nvme-cli
BuildRequires:  open-iscsi
BuildRequires:  openldap2-client
BuildRequires:  openslp-server
BuildRequires:  openssh
BuildRequires:  openssh-fips
BuildRequires:  pango
BuildRequires:  pango-tools
BuildRequires:  parted
BuildRequires:  pciutils
BuildRequires:  pcre-devel
BuildRequires:  pcsc-lite
BuildRequires:  perl-Config-Crontab
BuildRequires:  perl-HTML-Parser
BuildRequires:  perl-Switch
BuildRequires:  perl-XML-Bare
BuildRequires:  perl-XML-NamespaceSupport
BuildRequires:  perl-XML-Parser
BuildRequires:  perl-XML-Simple
BuildRequires:  perl-solv
BuildRequires:  pinentry
BuildRequires:  python3-websockify
BuildRequires:  google-poppins-fonts
BuildRequires:  samba
BuildRequires:  snapper
BuildRequires:  suse-module-tools
BuildRequires:  systemd
BuildRequires:  systemd-presets-branding
BuildRequires:  sysvinit-tools
BuildRequires:  tftpboot-installation-common
BuildRequires:  thai-fonts
BuildRequires:  tunctl
BuildRequires:  udev
BuildRequires:  vlan
BuildRequires:  vsftpd
%if %with_plymouth
BuildRequires:  plymouth
BuildRequires:  plymouth-branding
BuildRequires:  plymouth-plugin-script
BuildRequires:  plymouth-scripts
BuildRequires:  plymouth-theme-tribar
%endif
BuildRequires:  klogd
BuildRequires:  ltrace
BuildRequires:  nscd
BuildRequires:  polkit
BuildRequires:  popt-devel
BuildRequires:  pothana2000
BuildRequires:  procinfo
BuildRequires:  procps
BuildRequires:  psmisc
BuildRequires:  reiserfs
BuildRequires:  rgb
BuildRequires:  rpcbind
BuildRequires:  rsync
BuildRequires:  rsyslog
BuildRequires:  screen
BuildRequires:  sdparm
BuildRequires:  setserial
BuildRequires:  setxkbmap
BuildRequires:  sg3_utils
BuildRequires:  sharutils
BuildRequires:  smartmontools
BuildRequires:  smp_utils
BuildRequires:  socat
BuildRequires:  sqlite3
BuildRequires:  squashfs
BuildRequires:  star
BuildRequires:  strace
BuildRequires:  systemd-sysvinit
BuildRequires:  tcpd-devel
BuildRequires:  termcap
BuildRequires:  terminfo
BuildRequires:  udftools
BuildRequires:  un-fonts
BuildRequires:  usbutils
BuildRequires:  util-linux
BuildRequires:  util-linux-systemd
BuildRequires:  valgrind
BuildRequires:  vim-small
BuildRequires:  wget
BuildRequires:  wicked
BuildRequires:  wireless-tools
%ifnarch s390 s390x
BuildRequires:  wpa_supplicant
%endif
BuildRequires:  chrony
BuildRequires:  xauth
BuildRequires:  xdm
BuildRequires:  xdpyinfo
BuildRequires:  xfsdump
BuildRequires:  xfsprogs
BuildRequires:  xhost
BuildRequires:  xkbcomp
BuildRequires:  xkeyboard-config
BuildRequires:  xmodmap
BuildRequires:  xorg-x11-fonts
BuildRequires:  xorg-x11-fonts-legacy
BuildRequires:  xorg-x11-server
BuildRequires:  xrandr
BuildRequires:  xrefresh
BuildRequires:  xset
BuildRequires:  xterm
BuildRequires:  xz
BuildRequires:  yast2-devtools
BuildRequires:  yast2-schema
BuildRequires:  yast2-trans-allpacks
%if 0%{?with_storage_ng}
BuildRequires:  libstorage-ng-lang
BuildRequires:  yast2-storage-ng
#!BuildIgnore:  yast2-storage
#!BuildIgnore:  libstorage7
%endif
%if %{with sbl}
BuildRequires:  sbl
%endif
%if %{with vnc}
BuildRequires:  xorg-x11-Xvnc
%endif
# kmps
%ifarch %ix86 x86_64
BuildRequires:  atmel-firmware
BuildRequires:  dos2unix
BuildRequires:  ftp
BuildRequires:  hyper-v
BuildRequires:  ipw-firmware
BuildRequires:  tftp
BuildRequires:  xen-tools-domU
%if %{with xen}
BuildRequires:  kernel-xen
%if %{with xenkmp}
BuildRequires:  xen-kmp-default
%endif
%else
##BuildIgnore: kernel-xen
%endif
%endif
%ifnarch s390 s390x
%ifarch ppc64 ppc64le
BuildRequires:  iprutils
%endif
BuildRequires:  kbd
%ifarch %ix86 x86_64
BuildRequires:  xf86-video-amdgpu
BuildRequires:  xf86-video-intel
BuildRequires:  xf86-video-qxl
BuildRequires:  xf86-video-vesa
%endif
BuildRequires:  xf86-input-wacom
BuildRequires:  xf86-video-fbdev
%endif
BuildRequires:  grub2
%ifarch ppc ppc64 ppc64le
%ifnarch ppc64le
BuildRequires:  pdisk
%endif
BuildRequires:  grub2-powerpc-ieee1275
BuildRequires:  powerpc-utils
%endif
%ifarch %ix86 x86_64
BuildRequires:  acpica
BuildRequires:  biosdevname
BuildRequires:  dhcp-client
BuildRequires:  dmidecode
BuildRequires:  elilo
BuildRequires:  memtest86+
BuildRequires:  syslinux
%if %with_vbox
BuildRequires:  virtualbox-guest-kmp-default
BuildRequires:  virtualbox-guest-x11
%endif
%endif
%ifarch %ix86
BuildRequires:  dos2unix
BuildRequires:  ftp
BuildRequires:  tftp
%endif
%ifarch x86_64
BuildRequires:  grub2-x86_64-efi
%if %with_shim
BuildRequires:  shim
%endif
BuildRequires:  efibootmgr
#!BuildIgnore:  glibc-32bit
%endif
%ifarch ia64
BuildRequires:  acpica
BuildRequires:  dmidecode
BuildRequires:  efibootmgr
BuildRequires:  elilo
BuildRequires:  fpswa
%endif
%ifarch s390x
BuildRequires:  s390-tools-hmcdrvfs
%endif
%ifarch %ix86 x86_64
BuildRequires:  gfxboot-branding
%endif
%ifarch %ix86 x86_64 aarch64 %{arm}
BuildRequires:  grub2-branding
%endif
%ifnarch s390 s390x
#BuildRequires:  enic-kmp-default fnic-kmp-default ofed-kmp-default
%endif
BuildRequires:  dmz-icon-theme-cursors
%ifarch aarch64
BuildRequires:  grub2-arm64-efi
BuildRequires:  raspberrypi-firmware
BuildRequires:  raspberrypi-firmware-config
BuildRequires:  raspberrypi-firmware-dt
BuildRequires:  u-boot-rpiarm64
%if %with_shim
BuildRequires:  shim
%endif
%endif
%ifarch %arm
BuildRequires:  grub2-arm-efi
%endif
# inst-sys module for libstoragemgmt
BuildRequires:  libstoragemgmt-netapp-plugin
BuildRequires:  libstoragemgmt-smis-plugin
# our images are not reproducible and it's taking time
#!BuildIgnore:  build-compare

%if %{with iso}
BuildRequires:  createrepo_c
BuildRequires:  mkisofs
BuildRequires:  mksusecd
BuildRequires:  skelcd-openSUSE
%endif

%if "openSUSE" == ""
# This package is never built - but it helps the bots seeing that this package
# is intentionally as messed up as it is
Name:           installation-images
%else
Name:           installation-images-%{theme}
%endif
AutoReqProv:    off
Summary:        Installation Image Files for %theme
License:        GPL-2.0-or-later
Group:          Metapackages
Version:        16.56.10
Release:        lp153.1.15
Provides:       installation-images = %version-%release
Conflicts:      otherproviders(installation-images)
Source:         installation-images-%{version}.tar.xz
Source1:        installation-images-rpmlintrc
Source2:        product_name
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
%define _binary_payload w.ufdio

%description -n installation-images-%{theme}
Files needed for %theme installation media.


%package -n     install-initrd-%{theme}
Provides:       install-initrd = %version-%release
Conflicts:      otherproviders(install-initrd)
Obsoletes:      install-initrd-%theme < %version-%release
Obsoletes:      install-initrd-branding-%theme < %version-%release
AutoReqProv:    off
Summary:        Create initrd for %theme installation
Group:          System/Kernel
PreReq:         /bin/ln

%description -n install-initrd-%{theme}
You can create an initrd for %theme installation. Useful, for example, to set
up a UML or XEN environment.


%package -n     tftpboot-installation-%{product_name_arch}
AutoReqProv:    off
Summary:        tftp installation tree
Group:          System/Management
BuildArch:      noarch

%description -n tftpboot-installation-%{product_name_arch}
This package contains the kernel, initrd and installation images
to install SUSE CaaS Platform with PXE boot/tftpboot on x86-64.


%package -n     skelcd-installer-%{theme}
Provides:       skelcd-installer = %version-%release
Conflicts:      otherproviders(skelcd-installer)
Conflicts:      rescue-server
AutoReqProv:    off
Summary:        installer and related files needed on dvd1
Group:          Metapackages

%description -n skelcd-installer-%{theme}
This package contains kernel, initrd and installation images
needed on the first product dvds to start an installation.


%package -n     skelcd-installer-net-%{theme}
Provides:       skelcd-installer = %version-%release
Conflicts:      otherproviders(skelcd-installer)
Conflicts:      rescue-server
AutoReqProv:    off
Summary:        installer and related files needed on network medium
Group:          Metapackages

%description -n skelcd-installer-net-%{theme}
This package contains kernel, initrd and installation images
needed on the network install medium to start an installation.


%package -n     installation-images-debuginfodeps-%{theme}
Provides:       installation-images-debuginfodeps = %version-%release
Conflicts:      otherproviders(installation-images-debuginfodeps)
Obsoletes:      installation-images-debuginfodeps-%theme < %version-%release
Summary:        Debuginfo dependencies for %theme installation-images
Group:          Metapackages

%description -n installation-images-debuginfodeps-%{theme}
Package that holds debuginfo dependencies for image files in installation-image.


%define __debuginfo_requires   xargs grep build-id
%define __debuginfo_path       ^/usr/share/debuginfodeps

%prep
%setup -n installation-images-%{version}
rm -f /usr/lib/build/checks/04-check-filelist

%build
echo building product "'%product_name_arch'"
unset MALLOC_CHECK_
BUILD_DISTRIBUTION_NAME="%distribution"
export BUILD_DISTRIBUTION_NAME
test ! -z "$BUILD_DISTRIBUTION_NAME"
# build id (for linuxrc to start the correct instsys)
export instsys_build_id=`bin/build_id`
# beta only: warn testers about wrong instsys
export instsys_complain=1
# careful: will make all non-matching initrds fail hard
# export instsys_complain_root=2
# beta only: ignore non-critical errors
# export debug=ignore
# remove 'upgrade' option from boot menu
%if 0%{?config_bootmenu_no_upgrade}
export BOOTMENU_NO_UPGRADE=1
%endif
# force selfupdate setting, if defined
%if 0%{?config_yast_selfupdate:1}
export YAST_SELFUPDATE=%{config_yast_selfupdate}
%endif
# check that we are generally ok
make test
# build it
make THEMES=%theme
%ifarch %ix86 x86_64
%if %{with xen}
# build xen initrd & kernel
image=initrd-xen kernel=kernel-xen MOD_CFG=xen make initrd+modules THEMES=%theme
MOD_CFG=xen make kernel
%endif
%endif
%ifarch ppc ppc64
image=initrd-default kernel=kernel-default MOD_CFG=ppc64 make initrd+modules+gefrickel THEMES=%theme
%endif
%ifarch ppc64le
image=initrd-default kernel=kernel-default MOD_CFG=ppc64le make initrd+modules+gefrickel THEMES=%theme
%endif

%if %{with iso}
make THEMES=%theme iso
%endif

%install
BUILD_DISTRIBUTION_NAME="%distribution"
export BUILD_DISTRIBUTION_NAME
test ! -z "$BUILD_DISTRIBUTION_NAME"
make install DESTDIR=%{buildroot} THEMES=%theme
# make debuginfo DESTDIR=%{buildroot}
make install-initrd DESTDIR=%{buildroot}/usr/lib/install-initrd THEMES=%theme
ln -s %theme %{buildroot}/usr/lib/install-initrd/branding
install -d -m 755 %{buildroot}/usr/sbin
install -m 755 etc/mkinstallinitrd %{buildroot}/usr/sbin
%ifarch x86_64
%if %{without xen}
ln -s loader/initrd %{buildroot}/branding/%theme/CD1/boot/x86_64/initrd-xen
ln -s loader/linux %{buildroot}/CD1/boot/x86_64/vmlinuz-xen
%endif
%endif
# get rid of /usr/lib/rpm/brp-strip-debug 
# strip kills the zImage.chrp-rs6k 
export NO_BRP_STRIP_DEBUG=true
export NO_DEBUGINFO_STRIP_DEBUG=true
# for compatibility
mv %{buildroot}/branding %{buildroot}/SuSE
# file list for install-initrd
echo '%defattr(-,root,root)' >install-initrd.files
( cd %{buildroot}/usr/lib/install-initrd ; find -maxdepth 1 | sed -e '/\.$/d ; /\.\/branding/d ; s#\.#/usr/lib/install-initrd#' ) >>install-initrd.files
echo '%ghost' /usr/lib/install-initrd/branding >>install-initrd.files
echo '%dir' /usr/lib/install-initrd >>install-initrd.files
echo /usr/sbin/mkinstallinitrd >>install-initrd.files
# cd1
mkdir -p %{buildroot}/usr/lib/skelcd/CD1
cp -a %{buildroot}/usr/share/tftpboot-installation/*/* %{buildroot}/usr/lib/skelcd/CD1
rm -f %{buildroot}/usr/lib/skelcd/CD1/boot/*/rpmlist
rm -f %{buildroot}/usr/lib/skelcd/CD1/boot/*/mkbootdisk
rm -rf %{buildroot}/usr/lib/skelcd/CD1/{README,net}
# net
cp -a %{buildroot}/usr/lib/skelcd/CD1 %{buildroot}/usr/lib/skelcd/NET
rm -f %{buildroot}/usr/lib/skelcd/NET/boot/*/*.rpm
rm -f %{buildroot}/usr/lib/skelcd/NET/boot/*/{bind,common,config,control.xml,gdb,libstoragemgmt,rescue,root}
if [ -n "%{net_repo}" ] ; then
  CPU=%{_target_cpu}
  [ "$CPU" = i586 ] && CPU=i386
  RD=%{buildroot}/usr/lib/skelcd/NET/boot/$CPU/initrd
  if [ ! -f $RD ] ; then
    RD=%{buildroot}/usr/lib/skelcd/NET/boot/$CPU/loader/initrd
  fi
  if [ -f $RD ] ; then
    mkdir -p tmp_xxx/etc/linuxrc.d
    echo defaultrepo=%{net_repo} > tmp_xxx/etc/linuxrc.d/10_repo
    ( cd tmp_xxx ; find etc | cpio -o -H newc ) | xz --check=crc32 -c >> $RD
    rm -rf tmp_xxx
  fi
fi

%if %{with iso}
install -D -m 644 images/cd1.iso %{_topdir}/ISO/cd1.iso
%endif

%post -n install-initrd-%{theme}
/bin/ln -snf %theme /usr/lib/install-initrd/branding 2>/dev/null || true

%clean 
rm -rf %{buildroot}

%files
%defattr(-,root,root)
/CD1
/SuSE
%exclude /usr/share/debuginfodeps
/usr/share/mini-iso-rmlist
%ifarch x86_64
/usr/share/rescue-server
%endif

%files -n install-initrd-%{theme} -f install-initrd.files

%files -n tftpboot-installation-%{product_name_arch}
%defattr(-,root,root)
%dir %attr(0755,tftp,tftp) /usr/share/tftpboot-installation
/usr/share/tftpboot-installation

%files -n skelcd-installer-%{theme}
%defattr(-,root,root)
%dir /usr/lib/skelcd
/usr/lib/skelcd/CD1

%files -n skelcd-installer-net-%{theme}
%defattr(-,root,root)
%dir /usr/lib/skelcd
/usr/lib/skelcd/NET

%files -n installation-images-debuginfodeps-%{theme}
%defattr(-,root,root)
/usr/share/debuginfodeps

%changelog
* Mon May  3 2021 wfeldt@opensuse.org
- merge gh#openSUSE/installation-images#508
- create NVMe config files before udevd is started (bsc#1184908)
- 16.56.10
* Wed Apr 28 2021 wfeldt@opensuse.org
- merge gh#openSUSE/installation-images#507
- Revert "trigger automatic nvme discovery (bsc#1184908)"
- trigger automatic nvme discovery in udev start script
  (bsc#1184908)
- 16.56.9
* Mon Apr 26 2021 wfeldt@opensuse.org
- merge gh#openSUSE/installation-images#501
- trigger automatic nvme discovery (bsc#1184908)
- 16.56.8
* Fri Apr 23 2021 wfeldt@opensuse.org
- merge gh#openSUSE/installation-images#499
- fix NVMf autoconnect udev rule (bsc#1184908)
* Tue Apr 20 2021 wfeldt@opensuse.org
- merge gh#openSUSE/installation-images#495
- add USB Type-C modules (bsc#1184867)
- add even more USB Type-C modules (bsc#1185010)
- 16.56.7
* Tue Apr 20 2021 wfeldt@opensuse.org
- merge gh#openSUSE/installation-images#494
- add udev rules for NVMf autoconnect in the installation system
  (bsc#1184908)
* Tue Apr 20 2021 wfeldt@opensuse.org
- merge gh#openSUSE/installation-images#482
- enable multipathd in rescue system (bsc#1184686)
* Tue Apr 20 2021 wfeldt@opensuse.org
- merge gh#openSUSE/installation-images#493
- re-enable SecureBoot on AARCH64 on SLE Micro enable building the
  SLE Micro flavor based on OBS macro
- re-enable SecureBoot on AARCH64 on SLE Micro (bsc#1185018)
- 16.56.6
* Tue Apr 20 2021 wfeldt@opensuse.org
- merge gh#openSUSE/installation-images#489
- allow loading of unsupported modules (bsc#1184413, bsc#1183140)
- 16.56.5
* Sat Apr 17 2021 Lubos.Kocman@suse.com
- merge gh#openSUSE/installation-images#485
- build with kernel-default-optional on Leap (bsc#1184413)
- 16.56.4
* Fri Apr 16 2021 wfeldt@opensuse.org
- merge gh#openSUSE/installation-images#483
- build with kernel-default-extra on Leap (bsc#1184413, bsc#1183140)
- 16.56.3
* Thu Apr 15 2021 wfeldt@opensuse.org
- merge gh#openSUSE/installation-images#479
- Fix grub branding for %%{arm} - boo#1181571, jsc#SLE-17212
- 16.56.2
* Mon Apr 12 2021 wfeldt@opensuse.org
- merge gh#openSUSE/installation-images#477
- adjust NVME config initialisation (bsc#1183230)
- 16.56.1
* Thu Mar 11 2021 wfeldt@opensuse.org
- merge gh#openSUSE/installation-images#471
- ensure base modules are loaded before starting the rescue system
  (bsc#1183388)
- 16.56
* Wed Mar 10 2021 wfeldt@opensuse.org
- merge gh#openSUSE/installation-images#469
- Add bcond to build debug iso (boo#1183264)
- 16.55
* Wed Mar 10 2021 wfeldt@opensuse.org
- merge gh#openSUSE/installation-images#467
- Only create lib64 dirs if filesystem has it (boo#1183264)
- 16.54
* Wed Mar 10 2021 wfeldt@opensuse.org
- merge gh#openSUSE/installation-images#468
- disable zram swap only if there's another swap active
  (bsc#1183276)
- 16.53
* Wed Mar 10 2021 wfeldt@opensuse.org
- merge gh#openSUSE/installation-images#466
- susepaste only for Tumbleweed/Leap (bsc#1182212)
- 16.52
* Tue Mar  9 2021 ancor@suse.de
- merge gh#openSUSE/installation-images#463
- Add susepaste to the rescue system (bsc#1182212)
- Add susepaste to the inst-sys as well
- susepaste dependency
- 16.51
* Thu Mar  4 2021 wfeldt@opensuse.org
- merge gh#openSUSE/installation-images#465
- Prepare UsrMerge (boo#1029961)
- remove explicit libblogger2 dep
- clean up kernel module config
- 16.50
* Wed Mar  3 2021 wfeldt@opensuse.org
- merge gh#openSUSE/installation-images#462
- support using zram device as root file system (jsc#SLE-17630)
- 16.49
* Wed Mar  3 2021 wfeldt@opensuse.org
- merge gh#openSUSE/installation-images#464
- fix efi local boot entry on x86_64 (bsc#1182891)
- 16.48
* Thu Feb 25 2021 wfeldt@opensuse.org
- merge gh#openSUSE/installation-images#460
- go back to plymouth-theme-tribar (bsc#1182755)
- adjust spec file
- 16.47
* Tue Feb 23 2021 wfeldt@opensuse.org
- merge gh#openSUSE/installation-images#459
- fix adapting grub.cfg for different architectures (bsc#1182593)
- 16.46
* Mon Feb 22 2021 wfeldt@opensuse.org
- merge gh#openSUSE/installation-images#458
- Do not use shim on aarch64 for SLE Micro (based on SP2)
- 16.45
* Fri Feb 19 2021 wfeldt@opensuse.org
- merge gh#openSUSE/installation-images#457
- fix kernel & initrd location for x86_64 (bsc#1182239)
- 16.44
* Fri Feb 19 2021 wfeldt@opensuse.org
- fix library dependency check
- 16.43
* Fri Feb 19 2021 wfeldt@opensuse.org
- drop linuxefi/initrdefi on x86_64
* Fri Feb 19 2021 wfeldt@opensuse.org
- enable shim on aarch64
* Thu Feb 18 2021 wfeldt@opensuse.org
- unify all EFI-using grub configurations into a single config file
  (bsc#1182239)
* Thu Feb 18 2021 wfeldt@opensuse.org
- Use one grub.cfg for all ARM architectures
* Thu Feb 18 2021 wfeldt@opensuse.org
- merge gh#openSUSE/installation-images#455
- allow wildcards in modinfo firmware names (bsc#1180336)
- 16.42
* Thu Feb 18 2021 wfeldt@opensuse.org
- merge gh#openSUSE/installation-images#454
- spec: no longer have ports project for Leap since 15.3
- 16.41
* Thu Feb 18 2021 wfeldt@opensuse.org
- merge gh#openSUSE/installation-images#452
- remove some obsolete parts from installation-images (bsc#1182291)
- rewrite check_libs script
- fix zenworks image build
- 16.40
* Tue Feb 16 2021 wfeldt@opensuse.org
- merge gh#openSUSE/installation-images#453
- Add kernel modules necessary for Raspberry Pi 4 (bsc#1180336)
- 16.39
* Tue Feb 16 2021 wfeldt@opensuse.org
- merge gh#openSUSE/installation-images#449
- etc: update module.config to match 5.11 (bsc#1182301)
- 16.38
* Wed Feb 10 2021 wfeldt@opensuse.org
- merge gh#openSUSE/installation-images#451
- Replace Raleway fonts by Poppins (jsc#SLE-14772)
- 16.37
* Mon Feb  1 2021 wfeldt@opensuse.org
- merge gh#openSUSE/installation-images#448
- Switch to vim-small (boo#1181633)
- 16.36
* Thu Jan 28 2021 wfeldt@opensuse.org
- merge gh#openSUSE/installation-images#439
- Don't replace directory symlinks (boo#1029961)
- 16.35
* Wed Jan 27 2021 wfeldt@opensuse.org
- merge gh#openSUSE/installation-images#447
- aarch64: add tegra20-apb-dma module (bsc#1181463)
- 16.34
* Wed Jan 27 2021 wfeldt@opensuse.org
- merge gh#openSUSE/installation-images#446
- work around broken plymouth (bsc#1149070)
- 16.33
* Wed Jan 27 2021 wfeldt@opensuse.org
- merge gh#openSUSE/installation-images#445
- do not run prein script for openssh-server in root image
- 16.32
* Fri Jan 22 2021 wfeldt@opensuse.org
- merge gh#openSUSE/installation-images#443
- revert plymouth branding for SLE to tribar
- support both plymouth-theme-tribar and plymouth-theme-bgrt
- 16.31
* Thu Jan 21 2021 wfeldt@opensuse.org
- merge gh#openSUSE/installation-images#442
- Replace tribar plymouth theme for installation with bgrt
  (boo#1149070)
- 16.30
* Thu Jan 14 2021 wfeldt@opensuse.org
- merge gh#openSUSE/installation-images#441
- Handle the rename of MicroOS to SLE Micro (bsc#1180918)
- handle the change of the user-visible name of SUSE MicroOS to SLE
  Micro
- 16.29
* Tue Dec 15 2020 wfeldt@opensuse.org
- merge gh#openSUSE/installation-images#440
- add system-group-kvm explicitly
- 16.28
* Mon Nov  9 2020 wfeldt@opensuse.org
- merge gh#openSUSE/installation-images#436
- etc: update module.config to match 5.10
- 16.27
* Thu Oct 29 2020 wfeldt@opensuse.org
- merge gh#openSUSE/installation-images#435
- don't forget .lib*.hmac files (bsc#1178208)
- 16.26
* Fri Oct 23 2020 wfeldt@opensuse.org
- merge gh#openSUSE/installation-images#434
- add framework for perl tests
- cleanup Conv2Image
- remove minix support
- cleanup MakeExt2Image
- move shellcheck checks into test framework
- add regression test for dash bug bsc#1177691
- add tests for CompressImage
- add tests for Conv2Image
- documented CompressImage.pm
- documented lib/Conv2Image.pm
- reworked doc in MakeExt2Image.pm
- adjusted 10_lib_compress_image.t
- added test for MakeExt2Image
- removed obsolete FAT fs modules
- enable tests
- 16.25
* Tue Oct 13 2020 wfeldt@opensuse.org
- merge gh#openSUSE/installation-images#430
- Refresh spec file.
- Support 32bit ARM (boo#1177264).
- 16.24
* Wed Oct  7 2020 wfeldt@opensuse.org
- merge gh#openSUSE/installation-images#429
- remove dependency on insserv-compat (bsc#1176501)
- remove ia64-specific dependency on ia32el
- remove obsolete kbd_simple script
- convert remaining insserv uses to systemctl calls
- 16.23
* Tue Oct  6 2020 wfeldt@opensuse.org
- merge gh#openSUSE/installation-images#428
- include all of xorg-x11-server
- 16.22
* Tue Oct  6 2020 wfeldt@opensuse.org
- merge gh#openSUSE/installation-images#427
- ensure /proc is mounted in chroot environments (bsc#1176972)
- 16.21
* Thu Oct  1 2020 jlopez@suse.com
- merge gh#openSUSE/installation-images#426
- Extra yast module for common criteria (boo#1176982)
- 16.20
* Fri Sep 25 2020 wfeldt@opensuse.org
- merge gh#openSUSE/installation-images#424
- adjust to openssh package split
- 16.19
* Wed Sep 23 2020 wfeldt@opensuse.org
- merge gh#openSUSE/installation-images#422
- prevent cross-filesystem relative symlinks to kmod in initrd
  (bsc#1169094)
- 16.18
* Fri Sep 18 2020 wfeldt@opensuse.org
- merge gh#openSUSE/installation-images#421
- plymouthd.defaults will be moved to branding package
  (jsc#SLE-11637)
- 16.17
* Thu Sep 17 2020 wfeldt@opensuse.org
- merge gh#openSUSE/installation-images#419
- really create /dev symlinks udevd used to create (bsc#1176610)
- 16.16
* Wed Sep 16 2020 wfeldt@opensuse.org
- merge gh#openSUSE/installation-images#418
- create /dev symlinks udev used to create (bsc#1176610)
- 16.15
* Wed Sep  9 2020 wfeldt@opensuse.org
- merge gh#openSUSE/installation-images#416
- fix library dependency checking
- 16.14
* Tue Sep  8 2020 ludwig.nussel@suse.de
- BuildRequire system-role-common-criteria in SLE
- 16.13
* Tue Sep  8 2020 ludwig.nussel@suse.de
- Include common critera system role handler (jsc#SLE-12905)
* Mon Sep  7 2020 wfeldt@opensuse.org
- merge gh#openSUSE/installation-images#413
- add watchdog modules (bsc#1176112)
- 16.12
* Wed Aug 26 2020 wfeldt@opensuse.org
- merge gh#openSUSE/installation-images#411
- make exfat support optional
- 16.11
* Tue Aug 25 2020 wfeldt@opensuse.org
- merge gh#openSUSE/installation-images#410
- add exfatprogs to spec file
- 16.10
* Tue Aug 25 2020 wfeldt@opensuse.org
- merge gh#openSUSE/installation-images#409
- support exfat filesystem (bsc#1175731)
- 16.9
* Mon Aug 17 2020 wfeldt@opensuse.org
- merge gh#openSUSE/installation-images#408
- document default network repo location
- 16.8
* Fri Aug 14 2020 wfeldt@opensuse.org
- merge gh#openSUSE/installation-images#407
- rename product release package 'SUSE_MicroOS' to 'SUSE-MicroOS'
- rename 'SUSE_MicroOS' to 'SUSE-MicroOS'
- 16.7
* Thu Aug 13 2020 wfeldt@opensuse.org
- merge gh#openSUSE/installation-images#406
- use $releasever in repo URL (bsc#1171018)
- 16.6
* Wed Aug 12 2020 wfeldt@opensuse.org
- merge gh#openSUSE/installation-images#405
- rename MicroOSNG to "SUSE MicroOS"
- 16.5
* Mon Aug 10 2020 wfeldt@opensuse.org
- merge gh#openSUSE/installation-images#401
- wicked started using /usr/libexec (bsc#1174957)
- fix nokogiri update-alternatives handling
- 16.4
* Sun Aug  2 2020 mvidner@suse.cz
- merge gh#openSUSE/installation-images#398
- Update the environment variable reference (doc/configoptions.md)
- Removed obsolete bin/mk_boot
- Remove unused liveeval option
- 16.3
* Wed Jul 29 2020 mvidner@suse.cz
- merge gh#openSUSE/installation-images#399
- Remove pycache to save space (20 MB uncompressed)
- Remove pycache to save space (20:4 MiB pre:post squashfs-ing)
- 16.2
* Tue Jul 28 2020 mvidner@suse.cz
- merge gh#openSUSE/installation-images#400
- check_libs internals: use xargs, enable perl warnings
- check_libs internals: document data structures, use xargs, enable
  perl warnings
- 16.1
* Thu Jul 16 2020 wfeldt@opensuse.org
- merge gh#openSUSE/installation-images#397
- move OBS files used for building to git
- adjust doc
- 16.0
* Wed Jul 15 2020 wfeldt@opensuse.org
- merge gh#openSUSE/installation-images#396
- Rename openSUSE-MicroOS -> MicroOS
- 15.14
* Tue Jul 14 2020 mvidner@suse.cz
- merge gh#openSUSE/installation-images#388
- Adjust style to fix shellcheck warnings; admit this needs bash
- Remove bashisms, explicitly use /bin/dash as interpreter
  (bsc#1172139)
- 'make check' will run shellcheck on the scripts needing dash
- Save 1.5 MiB RAM by switching inst_setup to dash
- 15.13
* Fri Jul 10 2020 wfeldt@opensuse.org
- merge gh#openSUSE/installation-images#395
- kmod-compat will be dropped
- 15.12
* Fri Jul  3 2020 wfeldt@opensuse.org
- merge gh#openSUSE/installation-images#393
- libzypp wants to write to /var/lib/zypp (bsc#1172870)
- 15.11
* Wed Jul  1 2020 aschnell@suse.com
- merge gh#openSUSE/installation-images#391
- generate hostnqn and hostid for NVMe (bsc#1172853)
- mount /proc for 'nvme gen-hostnqn'
- 15.10
* Thu Jun 25 2020 aschnell@suse.com
- merge gh#openSUSE/installation-images#390
- updated list of branches
- 15.9
* Wed Jun 24 2020 wfeldt@opensuse.org
- merge gh#openSUSE/installation-images#389
- aarch64: add ipa kernel module
- add system-group-wheel to rescue system
- 15.8
* Fri Jun 19 2020 jlopez@suse.com
- merge gh#openSUSE/installation-images#387
- Add YaST dir (workaround for bsc#1172898)
- 15.7
* Wed Jun 17 2020 mvidner@suse.cz
- merge gh#openSUSE/installation-images#386
- Add /bin/dash to reduce script memory consumption (bsc#1172139)
- 15.6
* Wed Jun 10 2020 Antonio Larrosa <alarrosa@suse.com>
- Add BuildRequires: xorg-x11-fonts-legacy (bsc#1169444)
* Wed Jun 10 2020 wfeldt@opensuse.org
- merge gh#openSUSE/installation-images#384
- Add missed file to instsys. bsc#1158522 [Build 101.1] openQA test
  fails in windows_client_remotelogin
- 15.5
* Tue Jun  9 2020 lslezak@suse.cz
- merge gh#openSUSE/installation-images#382
- follow xorg font file shuffle (xorg-x11-legacy, bsc#1169444)
- 15.4
* Tue May 19 2020 wfeldt@opensuse.org
- merge gh#openSUSE/installation-images#378
- ensure there's a writable /var/lib/rpm directory (bsc#1171733)
- 15.3
* Mon May 18 2020 wfeldt@opensuse.org
- merge gh#openSUSE/installation-images#377
- support Leap-based MicroOS (bsc#1171585)
- 15.2
* Tue May 12 2020 wfeldt@opensuse.org
- merge gh#openSUSE/installation-images#376
- added microosng to the list of supported products
- 15.1
* Mon May 11 2020 wfeldt@opensuse.org
- merge gh#openSUSE/installation-images#375
- add more Realtek wifi drivers (bsc#1169127)
- 15.0
* Wed May  6 2020 wfeldt@opensuse.org
- merge gh#openSUSE/installation-images#374
- support MicroOSNG (bsc#1170885)
- 14.470
* Wed May  6 2020 Steffen Winterfeldt <snwint@suse.com>
- prepare for MicroOSNG
* Mon May  4 2020 wfeldt@opensuse.org
- merge gh#openSUSE/installation-images#373
- beware of bash using update-alternatives
- 14.469
* Wed Apr 29 2020 wfeldt@opensuse.org
- merge gh#openSUSE/installation-images#372
- remove ruby parts that are not needed in installation system
- 14.468
* Wed Apr 29 2020 wfeldt@opensuse.org
- merge gh#openSUSE/installation-images#371
- etc: update module.config to match 5.7
- 14.467
* Thu Apr 23 2020 Steffen Winterfeldt <snwint@suse.com>
- remove python dependency
* Thu Apr 16 2020 wfeldt@opensuse.org
- merge gh#openSUSE/installation-images#370
- avoid python3-numpy
- 14.466
* Tue Apr  7 2020 wfeldt@opensuse.org
- merge gh#openSUSE/installation-images#369
- add missing vbox drivers (bsc#1168742)
- 14.465
* Mon Apr  6 2020 wfeldt@opensuse.org
- merge gh#openSUSE/installation-images#360
- Update module list for 5.5:
- 14.464
* Mon Apr  6 2020 wfeldt@opensuse.org
- merge gh#openSUSE/installation-images#368
- put S390 I/O device pre-config into a separate script (bsc#1168036)
* Wed Mar 25 2020 wfeldt@opensuse.org
- merge gh#openSUSE/installation-images#367
- samba-libs needs libgnutls now
- 14.463
* Thu Mar 12 2020 wfeldt@opensuse.org
- merge gh#openSUSE/installation-images#364
- use u-boot-rpiarm64 if available (bsc#1164080)
- 14.462
* Mon Mar  9 2020 wfeldt@opensuse.org
- merge gh#openSUSE/installation-images#363
- adapt system-user-* and system-group-* package handling
  (bsc#1163938)
- 14.461
* Fri Mar  6 2020 wfeldt@opensuse.org
- merge gh#openSUSE/installation-images#362
- fix rescue system setup (bsc#1160378)
- 14.460
* Sat Feb 29 2020 Stasiek Michalski <stasiek@michalski.cc>
- Pull the correct distribution-logos per distribution theme
* Wed Feb 26 2020 wfeldt@opensuse.org
- merge gh#openSUSE/installation-images#361
- etc: ptp_clockmatrix to module.config
- 14.459
* Thu Feb 20 2020 wfeldt@opensuse.org
- merge gh#openSUSE/installation-images#359
- etc: update module.config to match 5.6
- 14.458
* Tue Feb 11 2020 lslezak@suse.cz
- merge gh#openSUSE/installation-images#358
- Added libyui-rest-api extension image (bsc#1163275)
- Adapt also the tftp.file_list file
- 14.457
* Thu Feb  6 2020 wfeldt@opensuse.org
- merge gh#openSUSE/installation-images#357
- move gconv files into initrd (bsc#1161701)
- netcfg has moved files to /usr/etc
- 14.456
* Mon Feb  3 2020 wfeldt@opensuse.org
- merge gh#openSUSE/installation-images#356
- remove explicit dependency on openssl package
- mount /proc in chroot environment during image build (bsc#1160594)
- fix package version comparing
- 14.455
* Fri Jan 24 2020 wfeldt@opensuse.org
- merge gh#openSUSE/installation-images#355
- don't bind-mount / in rescue system (bsc#1160449)
- 14.454
* Fri Jan 24 2020 wfeldt@opensuse.org
- merge gh#openSUSE/installation-images#353
- remove net-tools and net-tools-deprecated
- remove obsolete net-tools package
* Tue Jan 21 2020 wfeldt@opensuse.org
- merge gh#openSUSE/installation-images#352
- s390x: I/O device pre-configuration (jsc#SLE-7396)
- 14.453
* Mon Jan 13 2020 wfeldt@opensuse.org
- merge gh#openSUSE/installation-images#350
- udevd compat symlink has been removed from udev package
- 14.452
* Thu Dec 19 2019 shundhammer@suse.de
- merge gh#openSUSE/installation-images#348
- add some missing pci controller modules (bsc#1159503)
- 14.451
* Mon Dec  9 2019 wfeldt@opensuse.org
- merge gh#openSUSE/installation-images#347
- prepare for syslinux 6.x setup (jsc#SLE-2969)
- use gfxboot script from repo, not the installed one
- 14.450
* Thu Nov 28 2019 wfeldt@opensuse.org
- merge gh#openSUSE/installation-images#346
- etc: module.config, fix build on i586 with 5.4 kernel
- 14.449
* Thu Nov 28 2019 wfeldt@opensuse.org
- merge gh#openSUSE/installation-images#345
- etc: update module.config to match 5.4-final
- 14.448
* Fri Nov 15 2019 wfeldt@opensuse.org
- merge gh#openSUSE/installation-images#343
- Revert "Include KacstOne font for Persian (boo#1092920)"
- Use Noto Naskh Arabic instead of KacstBook (boo#1092920)
- another attempt to fix fonts
- 14.447
* Fri Nov 15 2019 wfeldt@opensuse.org
- merge gh#openSUSE/installation-images#344
- Added linuxrc reboot_timeout option (bsc1122493)
- 14.446
* Thu Nov  7 2019 wfeldt@opensuse.org
- merge gh#openSUSE/installation-images#342
- Include KacstOne font for Persian (boo#1092920)
- 14.445
* Wed Oct 30 2019 wfeldt@opensuse.org
- merge gh#openSUSE/installation-images#341
- include yast2-schema package (bsc#1153746)
- 14.444
* Wed Oct 30 2019 wfeldt@opensuse.org
- merge gh#openSUSE/installation-images#340
- fix initial sshd key generation
- setup /etc/sysconfig/ssh in rescue system
- 14.443
* Wed Oct 16 2019 wfeldt@opensuse.org
- merge gh#openSUSE/installation-images#338
- adjust samba library list
- include correct udev dir for virtualbox-guest-tools
- remove multipath-tools from initrd
- adjust to /usr/etc move in pam and shadow packages
- 14.442
* Wed Oct 16 2019 wfeldt@opensuse.org
- merge gh#openSUSE/installation-images#337
- etc: module.config, sort other kernel/* modules
- etc: update module.config to match 5.4
- handle kernel 5.4
- 14.441
* Mon Oct 14 2019 Dominique Leuenberger <dimstar@opensuse.org>
- Set clamp_mtime_to_source_date_epoch 0: as the content of i-i is
  published in extracted form on download.o.o, and rsynced around,
  we need to be able to rely on changing mtime's for the content.
* Tue Oct  8 2019 wfeldt@opensuse.org
- merge gh#openSUSE/installation-images#336
- ensure /etc/sysctl.d is writable (bsc#1153285)
- 14.440
* Wed Oct  2 2019 wfeldt@opensuse.org
- anticipate pam config might be in /usr/etc (bsc#1152771)
- 14.439
* Fri Sep 27 2019 wfeldt@opensuse.org
- merge gh#openSUSE/installation-images#335
- add /etc/zkey to initrd to ensure it is writable (jsc#SLE-7376)
- default udev rules are in /usr/lib
- 14.438
* Wed Sep 25 2019 wfeldt@opensuse.org
- merge gh#openSUSE/installation-images#334
- do not stop haveged process in inst_setup (bsc#1140171)
- 14.437
* Mon Sep 23 2019 wfeldt@opensuse.org
- merge gh#openSUSE/installation-images#332
- move setsid and mount to initrd
- 14.436
* Fri Sep  6 2019 wfeldt@opensuse.org
- fix sshd location so that it works with fips enabled (bsc#1140169)
- 14.435
* Fri Aug 30 2019 wfeldt@opensuse.org
- merge gh#openSUSE/installation-images#329
- handle compressed modules
- 14.434
* Fri Aug 30 2019 wfeldt@opensuse.org
- merge gh#openSUSE/installation-images#328
- Speed up fix_perms
- 14.433
* Fri Aug 23 2019 wfeldt@opensuse.org
- merge gh#openSUSE/installation-images#327
- add all gpio modules (bsc#1145777)
- 14.432
* Thu Jul 18 2019 wfeldt@opensuse.org
- merge gh#openSUSE/installation-images#326
- merge branch master
- data/root/etc/xorg.conf.template: disable acceleration for
  modeset driver
- xorg.conf.template: disable acceleration for modeset driver
- 14.431
* Thu Jul 18 2019 wfeldt@opensuse.org
- merge gh#openSUSE/installation-images#325
- allow explicit setting of product name
- 14.430
* Thu Jul 11 2019 Steffen Winterfeldt <snwint@suse.com>
- add 'Conflicts: rescue-server' to skelcd-installer-*
* Thu Jul 11 2019 wfeldt@opensuse.org
- merge gh#openSUSE/installation-images#322
- aarch64: fix kernel and initrd location in grub config
  (bsc#1141038)
- 14.429
* Fri Jul  5 2019 Dominique Leuenberger <dimstar@opensuse.org>
- Complete the tftpboot subpackage rename for the Kubic flavor:
  also rename the directory inside tftpboot-installation, matching
  the package name.
* Fri Jul  5 2019 wfeldt@opensuse.org
- merge gh#openSUSE/installation-images#320
- remove SuSEfirewall2 dependency that was introduced in bnc#887406
- 14.428
* Wed May 29 2019 Dominique Leuenberger <dimstar@opensuse.org>
- Rename the tftpboot subpackage for Kubic to be kubic relevant,
  not using the generic MicroOS name.
* Tue May 21 2019 wfeldt@opensuse.org
- merge gh#openSUSE/installation-images#314
- set root password for rescue system explicitly (bsc#1134524)
- 14.427
* Mon May 20 2019 wfeldt@opensuse.org
- merge gh#openSUSE/installation-images#313
- aarch64: ptp_qoriq.ko is now ptp-qoriq.ko
- 14.426
* Wed May 15 2019 Steffen Winterfeldt <snwint@suse.com>
- do not use openssl-1_1-hmac in openSUSE for now
* Fri May  3 2019 wfeldt@opensuse.org
- merge gh#openSUSE/installation-images#312
- follow aaa_base package change
- 14.425
* Thu May  2 2019 wfeldt@opensuse.org
- merge gh#openSUSE/installation-images#311
- prevent MD/RAID auto-assembly if linuxrc says so (bsc#1132688)
- 14.424
* Tue Apr 30 2019 wfeldt@opensuse.org
- merge gh#openSUSE/installation-images#310
- Revert "add /dev/btrfs-control to initrd (bsc#1133368)"
- autoload btrfs module to get /dev/btrfs-control (bsc#1133368)
- 14.423
* Thu Apr 25 2019 wfeldt@opensuse.org
- merge gh#openSUSE/installation-images#308
- add /dev/btrfs-control to initrd (bsc#1133368)
- 14.422
* Wed Apr 24 2019 snwint@suse.de
- merge gh#openSUSE/installation-images#307
- patch zypp config also for MicroOS (bsc#1132848)
- adjust branding example
- 14.421
* Thu Apr  4 2019 Richard Brown <rbrown@suse.com>
- Add MicroOS flavor in addition to MicroOS theme introduced on Apr 1
* Thu Apr  4 2019 Richard Brown <rbrown@suse.com>
- Add MicroOS to _multibuild
* Mon Apr  1 2019 Richard Brown <rbrown@suse.com>
- Fix specfile for MicroOS flavour introduced in 14.418
* Fri Mar 29 2019 snwint@suse.com
- disable SLES_SAP build (fcrozat)
* Thu Mar 28 2019 snwint@suse.de
- merge gh#openSUSE/installation-images#306
- add more aarch64 modules (bsc#1129815)
- 14.420
* Thu Mar 28 2019 snwint@suse.de
- merge gh#openSUSE/installation-images#305
- remove obsolete paragraph from doc
- update git2log to latest version
- inform user better about why things failed
- fix archive creation with detached git HEAD state
- 14.419
* Wed Mar 27 2019 snwint@suse.de
- merge gh#openSUSE/installation-images#303
- Establish MicroOS as seperate media, with Kubic as a derivative
  of MicroOS
- 14.418
* Wed Mar 20 2019 snwint@suse.de
- merge gh#openSUSE/installation-images#302
- fine-tune RPi firmware inclusion (jsc:SLE-4394)
- 14.417
* Wed Mar 13 2019 snwint@suse.com
- adjust build contraints to require 24GB to build
- disable SLED build (fcrozat)
* Wed Mar 13 2019 schubi@suse.de
- merge gh#openSUSE/installation-images#301
- Package mkfontdir is optional. So it can be obsoleted by package
  mkfontscale.
- 14.416
* Tue Mar 12 2019 snwint@suse.de
- merge gh#openSUSE/installation-images#300
- adjust EFI boot setup to also include RPi firmware files
  (jsc:SLE-4394)
- 14.415
* Tue Mar 12 2019 snwint@suse.com
- add raspberry pi firmware files
* Tue Mar 12 2019 snwint@suse.de
- merge gh#openSUSE/installation-images#299
- bash is really in /usr/bin, do not rely in symlink in /bin
- 14.414
* Mon Mar 11 2019 snwint@suse.com
- do not build for s390 (32 bit)
* Mon Mar 11 2019 snwint@suse.de
- merge gh#openSUSE/installation-images#298
- bash has been moved to /usr/bin
- systemd branding for Kubic is now MicroOS
- 14.413
* Sun Mar 10 2019 kukuk@suse.de
- Kubic: replace CAASP systemd branding with MicroOS
* Wed Mar  6 2019 opensuse-packaging@opensuse.org
- merge gh#openSUSE/installation-images#297
- Add nvme-cli package (bsc#1127815)
- 14.412
* Tue Feb 26 2019 snwint@suse.de
- merge gh#openSUSE/installation-images#296
- remove dependency on pciutils-ids
- 14.411
* Fri Feb 22 2019 snwint@suse.de
- merge gh#openSUSE/installation-images#295
- make openssl-hmac optional
- 14.410
* Tue Feb 19 2019 snwint@suse.de
- merge gh#openSUSE/installation-images#294
- include the full set of kernel modules on ppc (bsc#1123349)
- 14.409
* Thu Jan 31 2019 opensuse-packaging@opensuse.org
- merge gh#openSUSE/installation-images#293
- Revert "Add bcache-tools package (fate#325346)"
- Remove optional for initrd
- Add bcache-tools to rescue system (fate#325346)
- Add bcache-tools package to rescue system
- 14.408
* Wed Jan 30 2019 opensuse-packaging@opensuse.org
- merge gh#openSUSE/installation-images#292
- Add bcache-tools package (fate#325346)
- 14.407
* Mon Jan 28 2019 snwint@suse.com
- updated skelcd-fallbackrepo package list
* Mon Jan 28 2019 snwint@suse.com
- fix spec to require correct skelcd-fallbackrepo packages
* Thu Jan 24 2019 snwint@suse.de
- merge gh#openSUSE/installation-images#290
- adjust to grub2 package changes (fate#326960, bsc#1122992)
- adjust to nfs-utils package changes (bsc#1122994)
- avoid perl warnings using BigInt module
- correct efi and shim dir
- 14.406
* Tue Jan 15 2019 schubi@suse.de
- merge gh#openSUSE/installation-images#289
- Added new linuxrc option: specialproduct (fate#327099)
- 14.405
* Thu Jan 10 2019 snwint@suse.de
- merge gh#openSUSE/installation-images#288
- added required tools for network setup (bsc#1121046)
- 14.404
* Wed Jan  9 2019 snwint@suse.com
- skelcd-fallbackrepo-SLED exists only on x86_64 (bsc#1121074)
* Mon Dec 17 2018 snwint@suse.com
- added skelcd-fallbackrepo for SLE_HPC, SLE_RT, and CAASP
* Mon Dec 17 2018 snwint@suse.com
- add skelcd-fallbackrepo-* packages to SLES image
* Mon Dec 17 2018 snwint@suse.de
- merge gh#openSUSE/installation-images#286
- allow adding package files to inst-sys (fate#325482)
- add skelcd-fallbackrepo packages to instsys
- 14.403
* Wed Dec 12 2018 snwint@suse.de
- merge gh#openSUSE/installation-images#285
- check font config (bsc#1113164)
- add missing Source Sans Pro fonts (bsc#1113164)
- add not always all skelcd-control packages
- fix style issue in check_fonts
- add check_fonts script (and other stuff)
- 14.402
* Wed Dec 12 2018 snwint@suse.com
- use adobe-sourcesanspro-fonts on openSUSE
* Tue Dec 11 2018 snwint@suse.de
- merge gh#openSUSE/installation-images#284
- add all available skelcd-control packages to inst-sys (fate#325482)
- 14.401
* Tue Dec 11 2018 snwint@suse.de
- merge gh#openSUSE/installation-images#283
- support adding packages matching a regexp (fate#325482)
- minor correction
- 14.400
* Mon Dec 10 2018 snwint@suse.de
- merge gh#openSUSE/installation-images#282
- Do not set Y2MAXLOGSIZE and Y2MAXLOGNUM in YaST debug mode
  (bsc#1118643)
- 14.399
* Wed Dec  5 2018 snwint@suse.de
- merge gh#openSUSE/installation-images#281
- no longer block hicolor-icon-theme (bsc#1118410)
- 14.398
* Tue Dec  4 2018 snwint@suse.de
- merge gh#openSUSE/installation-images#280
- s390x: adjust rexx sample script (bsc#1108089, bsc#1108090)
- 14.397
* Mon Dec  3 2018 lslezak@suse.cz
- merge gh#openSUSE/installation-images#279
- YaST theme cleanup (related to boo#1109310)
- 14.396
* Mon Dec  3 2018 opensuse-packaging@opensuse.org
- merge gh#openSUSE/installation-images#277
- Add udftools package (fate#326877)
- 14.395
* Mon Dec  3 2018 snwint@suse.de
- merge gh#openSUSE/installation-images#278
- re-enable ssh root login to installation system (bsc#1118114)
- 14.394
* Tue Nov 20 2018 snwint@suse.de
- merge gh#openSUSE/installation-images#275
- rescue: change service name of nfsserver to nfs-server
- 14.393
* Wed Nov 14 2018 snwint@suse.de
- merge gh#openSUSE/installation-images#274
- setctsid is dead, long live setsid (bsc#1109290)
- 14.392
* Mon Nov 12 2018 snwint@suse.de
- merge gh#openSUSE/installation-images#273
- fix patching systemd-udevd.service file
- udevd needs a mountpoint for / to start (bsc#937237)
- 14.391
* Fri Nov  9 2018 snwint@suse.de
- merge gh#openSUSE/installation-images#272
- suse-module-tools now have a dependency on binutils
- 14.390
* Thu Nov  8 2018 snwint@suse.de
- merge gh#openSUSE/installation-images#271
- don't run udevd in its own private fs namespace
- 14.389
* Mon Nov  5 2018 snwint@suse.de
- merge gh#openSUSE/installation-images#270
- Kubic has its own skelcd package now (bsc#1114455)
- 14.388
* Mon Nov  5 2018 Richard Brown <rbrown@suse.com>
- Use skelcd-control-Kubic for Kubic flavour (boo#1114455)
* Mon Oct 22 2018 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Handle aarch64 and ppc64/ppc64le repos
* Fri Oct 19 2018 snwint@suse.de
- merge gh#openSUSE/installation-images#269
- don't use 'iterm' terminfo (fate#325746)
- 14.387
* Thu Oct 18 2018 snwint@suse.de
- merge gh#openSUSE/installation-images#268
- pick better fonts for fbiterm (fate#325746)
- 14.386
* Mon Oct  1 2018 snwint@suse.de
- merge gh#openSUSE/installation-images#267
- adjust to glibc-locale package split
- 14.385
* Wed Sep 26 2018 snwint@suse.de
- merge gh#openSUSE/installation-images#264
- aarch64: add gpio-thunderx.ko module (bsc#1106114)
- 14.384
* Wed Sep 26 2018 snwint@suse.de
- merge gh#openSUSE/installation-images#262
- adjust to iptables using update-alternatives (bsc#1108289)
- added 'clear' to instsys (bsc#1108005)
- 14.383
* Wed Sep 26 2018 snwint@suse.de
- merge gh#openSUSE/installation-images#261
- Make monitor miror mode during installation the default again
  (bsc#1108905)
* Tue Sep 25 2018 snwint@suse.de
- merge gh#openSUSE/installation-images#260
- Add ptp_qoriq to module.config
- 14.382
* Fri Sep 21 2018 snwint@suse.de
- merge gh#openSUSE/installation-images#259
- add bcache-tools to installation initrd (fate#325346)
- add bcache-tools to installatio initrd (fate#325346)
- 14.381
* Mon Aug 20 2018 agraf@suse.de
- Fix rpi file list
- hdimage: Use at least FAT16
- 14.380
* Mon Aug 20 2018 wfeldt@opensuse.org
- merge gh#openSUSE/installation-images#258
- add raspberry pi firmware files
* Thu Aug  9 2018 snwint@suse.com
- get leap version from %%sle_version macro (bsc#1103208)
* Mon Jul 23 2018 jslaby@suse.cz
- merge gh#openSUSE/installation-images#256
- etc: update module.config to match 4.18
- 14.379
* Fri Jul  6 2018 wfeldt@opensuse.org
- merge gh#openSUSE/installation-images#255
- add pinctrl-* modules (bsc#1095796)
- 14.378
* Mon Jul  2 2018 wfeldt@opensuse.org
- merge gh#openSUSE/installation-images#253
- add bcm43xx-firmware (bsc#1099327)
- 14.377
* Mon Jun 25 2018 afaerber@suse.de
- merge gh#openSUSE/installation-images#252
- Tidy module.config comment notes
- Add mailbox modules (boo#1040492)
- 14.376
* Tue Jun  5 2018 wfeldt@opensuse.org
- merge gh#openSUSE/installation-images#251
- include all kernel input modules (bsc#1095289)
- 14.375
* Wed May 30 2018 jslaby@suse.cz
- merge gh#openSUSE/installation-images#246
- etc: update module.config to match 4.17
- 14.374
* Thu May 17 2018 wfeldt@opensuse.org
- merge gh#openSUSE/installation-images#250
- use reiserfs-kmp (fate#323394)
- 14.373
* Mon May 14 2018 tchvatal@suse.com
- merge gh#openSUSE/installation-images#248
- Use proper libsmbios_c2 name for the smbios library
- 14.372
* Fri May  4 2018 jsrain@suse.cz
- merge gh#openSUSE/installation-images#247
- adjusted libopenssl*_*-hmac dependency to match current versions
  (bsc#1090360)
- 14.371
* Wed Apr 25 2018 tchvatal@suse.com
- Use proper libsmbios_c2 name for the smbios library
* Mon Apr 23 2018 wfeldt@opensuse.org
- merge gh#openSUSE/installation-images#245
- remove last mozilla-nspr reference
- 14.370
* Thu Apr 19 2018 wfeldt@opensuse.org
- merge gh#openSUSE/installation-images#244
- remove dmraid from inst-sys (fate#323743, bsc#1088570)
- remove explicit dependency from mozilla-nspr
- 14.369
* Wed Apr 18 2018 wfeldt@opensuse.org
- merge gh#openSUSE/installation-images#243
- run postin script of yast2-storage-ng (bsc#1081198)
- 14.368
* Wed Apr 11 2018 snwint@suse.de
- disable Kubic 32-bit build (bsc#1089102)
* Mon Apr  9 2018 kukuk@suse.de
- No upgrade option for Kubic (bsc#1088304)
* Mon Apr  9 2018 snwint@suse.de
- do not delete efi image in skelcd-installer-net (bsc#1088679)
* Fri Apr  6 2018 wfeldt@opensuse.org
- merge gh#openSUSE/installation-images#242
- adjust adddir script to allow updating coreutils (bsc#1087901)
- 14.367
* Wed Mar 28 2018 wfeldt@opensuse.org
- merge gh#openSUSE/installation-images#241
- s390x: add zpxe.rexx to dvd (bsc#813454)
- 14.366
* Mon Mar 26 2018 wfeldt@opensuse.org
- merge gh#openSUSE/installation-images#240
- add libstorage-ng translations (bsc#1081454)
- 14.365
* Thu Mar 22 2018 wfeldt@opensuse.org
- merge gh#openSUSE/installation-images#239
- add novnc & python3-websockify (bsc#1078785)
- 14.364
* Thu Mar 22 2018 wfeldt@opensuse.org
- merge gh#openSUSE/installation-images#238
- allow udevd to be run with --debug (bsc#1085212)
- 14.363
* Fri Mar 16 2018 wfeldt@opensuse.org
- merge gh#openSUSE/installation-images#237
- move tftpboot location (bsc#1085479)
- 14.362
* Fri Mar  9 2018 wfeldt@opensuse.org
- merge gh#openSUSE/installation-images#236
- remove default driver update url (bsc#1084510)
- 14.361
* Fri Mar  9 2018 wfeldt@opensuse.org
- merge gh#openSUSE/installation-images#235
- udevadm should retrigger 'add' events (bsc#1084357)
- 14.360
* Thu Feb 22 2018 snwint@suse.de
- build skelcd-installer-net subpackage containing the network
  install setup (bsc#1063789)
* Fri Feb  9 2018 wfeldt@opensuse.org
- merge gh#openSUSE/installation-images#234
- add vmd.ko module (bsc#1079924)
- 14.359
* Wed Jan 31 2018 wfeldt@opensuse.org
- merge gh#openSUSE/installation-images#233
- add missing drivers for ppc (bsc#1077546)
- 14.358
* Tue Jan 30 2018 wfeldt@opensuse.org
- merge gh#openSUSE/installation-images#232
- add full open-iscsi package to zenworks image (bsc# 1077301)
- 14.357
* Mon Jan 29 2018 dimstar@opensuse.org
- merge gh#openSUSE/installation-images#231
- mk_image: /var/lib/rpm/alternatives was moved to
  /var/lib/alternatives
- 14.356
* Mon Jan 29 2018 dimstar@opensuse.org
- Do not explicitly BuildRequire libcryptsetup4-hmac and
  libgcrypt20-hmac: since those packages change sonmae every now
  and then, it makes it only difficult to follow it. They are
  already pulled in by dracut-fips, so we still have them in the
  buildroot available.
* Mon Jan 29 2018 wfeldt@opensuse.org
- merge gh#openSUSE/installation-images#229
- make cypto lib dependencies more flexible
- make dependency on bash explicit
- 14.355
* Mon Jan 29 2018 dimstar@opensuse.org
- Own /usr/lib/skelcd if skelcd_compat is set: until the products
  are fully migrated to the product builder rewrite, some still use
  the legacy /CD1 path. They advertise this by defining
  skelcd_compat=1.
* Wed Jan 24 2018 wfeldt@opensuse.org
- merge gh#openSUSE/installation-images#228
- set product and menu title in gfxboot.cfg
- 14.354
* Tue Jan 23 2018 ludwig.nussel@suse.de
- merge gh#openSUSE/installation-images#227
- copy grub2 background conditionally (boo#1076577)
- 14.353
* Sat Jan 13 2018 dimstar@opensuse.org
- Switch openSUSE and Kubic to storage-ng.
* Tue Jan  9 2018 wfeldt@opensuse.org
- merge gh#openSUSE/installation-images#226
- simplify definitions for libstoragemgmt image
- 14.352
* Tue Jan  9 2018 snwint@suse.de
- avoid explicit dependency on python-libstoragemgmt
* Mon Jan  8 2018 wfeldt@opensuse.org
- merge gh#openSUSE/installation-images#224
- switch to using unified-installer-release
- fix typo: must be sles, not sle
- 14.351
* Mon Jan  8 2018 snwint@suse.de
- clean up spec file and remove support for pre-sle15 distros
* Mon Jan  8 2018 wfeldt@opensuse.org
- merge gh#openSUSE/installation-images#223
- create user/group entries for chrony (fate#323432)
- 14.350
* Thu Dec 14 2017 wfeldt@opensuse.org
- merge gh#openSUSE/installation-images#222
- allow dangling machine-id symlink (bsc#1027200)
- 14.349
* Thu Dec 14 2017 jslaby@suse.cz
- merge gh#openSUSE/installation-images#218
- etc: update module.config to match 4.15
- 14.348
* Fri Dec  8 2017 wfeldt@opensuse.org
- merge gh#openSUSE/installation-images#221
- create groups needed in inst-sys (bsc#1064822)
- added comment
- 14.347
* Mon Dec  4 2017 jreidinger@suse.cz
- merge gh#openSUSE/installation-images#217
- Replace ntp with chrony (fate#323432)
- 14.346
* Mon Dec  4 2017 rbrownccb@opensuse.org
- merge gh#openSUSE/installation-images#220
- Adjust for new fillup-templates location (boo#1069468)
- 14.345
* Fri Dec  1 2017 wfeldt@opensuse.org
- merge gh#openSUSE/installation-images#219
- add gpg-agent to instsys (bsc#1067992)
- 14.344
* Mon Nov 20 2017 wfeldt@opensuse.org
- merge gh#openSUSE/installation-images#216
- adjust to ruby2.5
- 14.343
* Fri Nov 17 2017 wfeldt@opensuse.org
- merge gh#openSUSE/installation-images#215
- add fixed.ko (bsc#1067827)
- 14.342
* Fri Nov 17 2017 wfeldt@opensuse.org
- merge gh#openSUSE/installation-images#213
- move cryptsetup into initrd to allow reading of encrypted volumes
- 14.341
* Fri Nov 17 2017 jslaby@suse.cz
- merge gh#openSUSE/installation-images#212
- squashfs.ko might depend on zstd_decompress
* Wed Nov  8 2017 wfeldt@opensuse.org
- merge gh#openSUSE/installation-images#210
- include modules from kernel/drivers/phy (bsc#1064128)
- 14.340
* Thu Oct 19 2017 jberry@suse.com
- Update suse_version check to exclude in ix86 for Leap 15.0.
* Tue Oct 17 2017 dmueller@suse.com
- merge gh#openSUSE/installation-images#209
- etc: update module.config to match 4.13
- 14.339
* Wed Oct 11 2017 wfeldt@opensuse.org
- merge gh#openSUSE/installation-images#208
- use skelcd-control-leanos for SLES & co
- 14.338
* Wed Oct 11 2017 wfeldt@opensuse.org
- merge gh#openSUSE/installation-images#207
- fix typo preventing the adding of control.xml
- adjust package name: skelcd-casp.rpm -> skelcd-caasp.rpm
- 14.337
* Thu Oct  5 2017 wfeldt@opensuse.org
- merge gh#openSUSE/installation-images#206
- use the same driver updates for caasp as the dist it is based on
- 14.336
* Wed Oct  4 2017 dimstar@opensuse.org
- Changed permissions of /srv/tftpboot to be readable (bsc#940608).
* Wed Sep 27 2017 wfeldt@opensuse.org
- merge gh#openSUSE/installation-images#205
- control.xml is now optional
- 14.335
* Tue Sep 26 2017 wfeldt@opensuse.org
- merge gh#openSUSE/installation-images#204
- adjust xorg input & video driver list
- 14.334
* Thu Sep 21 2017 wfeldt@opensuse.org
- merge gh#openSUSE/installation-images#203
- system-user-root needs to be treated specially
- python-argparse is gone
- 14.333
* Wed Sep 20 2017 wfeldt@opensuse.org
- merge gh#openSUSE/installation-images#202
- allow adding packages by running rpm directly
- 14.332
* Mon Sep 18 2017 wfeldt@opensuse.org
- merge gh#openSUSE/installation-images#201
- include all mouse drivers (bsc#1055628)
- 14.331
* Wed Sep 13 2017 snwint@suse.de
- xf86-video-vesa is back (bsc#1058310)
* Tue Sep 12 2017 snwint@suse.de
- use new is_susesap flag to trigger sap builds
* Mon Sep 11 2017 wfeldt@opensuse.org
- merge gh#openSUSE/installation-images#200
- adjust to work with the graphviz package split
- enhance documentation of 'exists' function in file lists
- 14.330
* Mon Sep 11 2017 wfeldt@opensuse.org
- merge gh#openSUSE/installation-images#199
- tumbleweed kubic: os-release file changed again
- 14.329
* Mon Sep 11 2017 rbrownccb@opensuse.org
- merge gh#openSUSE/installation-images#198
- Kubic needs to be have the same zypp.conf as CaaSP
* Fri Sep  8 2017 wfeldt@opensuse.org
- merge gh#openSUSE/installation-images#197
- treat tumbleweed-kubic as tumbleweed for driver updates
- 14.328
* Thu Sep  7 2017 wfeldt@opensuse.org
- merge gh#openSUSE/installation-images#196
- fix unsupported product detection logic
- 14.327
* Thu Sep  7 2017 wfeldt@opensuse.org
- merge gh#openSUSE/installation-images#195
- adjust to keep it working also on sle12-sp3
- Kubic is now Tumbleweed-Kubic
- have build fail if we build for an (yet) unknown distro
- 14.326
* Thu Sep  7 2017 snwint@suse.de
- it's now openSUSE-Tumbleweed-Kubic-release
* Thu Sep  7 2017 snwint@suse.de
- make building with storage-ng configurable again and turn it off
  with openSUSE builds
* Tue Sep  5 2017 snwint@suse.de
- always use libinput driver (bsc#1055513)
* Tue Sep  5 2017 snwint@suse.de
- remove unused dmapi from BuildRequires
* Mon Sep  4 2017 snwint@suse.de
- remove unused recode from BuildRequires (bsc#1053648)
* Fri Aug 18 2017 snwint@suse.de
- don't build sles on ix86 (bsc#1054238)
* Wed Aug 16 2017 snwint@suse.de
- switch to storage-ng
* Wed Aug 16 2017 wfeldt@opensuse.org
- merge gh#openSUSE/installation-images#194
- drop obsolete xorg input drivers (bsc#1053806)
- 14.325
* Tue Aug 15 2017 wfeldt@opensuse.org
- merge gh#openSUSE/installation-images#193
- drop obsolete xorg drivers (bsc#1053806)
- 14.324
* Fri Aug  4 2017 lslezak@suse.cz
- merge gh#openSUSE/installation-images#192
- Fix the default cursor theme (bsc#1051664)
- 14.323
* Fri Jul 28 2017 jimmy@boombatower.com
- Add Conflicts: otherproviders() and Provides for relevant packages.
* Mon Jul 24 2017 wfeldt@opensuse.org
- merge gh#openSUSE/installation-images#191
- always load dm_multipath module
- 14.322
* Thu Jul 20 2017 wfeldt@opensuse.org
- merge gh#openSUSE/installation-images#190
- run udev prein script in initrd (bsc#1047598)
- 14.321
* Wed Jul 19 2017 snwint@suse.de
- increase disk size contraints to 12GB
* Mon Jul  3 2017 snwint@suse.de
- revert last change: it is vital that CAASP/SLES/SLED builds can all happen
  in the same project (sbehlert)
* Mon Jul  3 2017 snwint@suse.de
- don't build SLED/SLES on CAASP
* Fri Jun 30 2017 snwint@suse.de
- don't build SLES_SAP on CAASP
* Thu Jun 29 2017 varkoly@suse.de
- merge gh#openSUSE/installation-images#189
- Add new theme SLES_SAP (bsc#1032850)
- 14.320
* Wed Jun 21 2017 snwint@suse.de
- remove obsolete dependency on links (bsc#1044791)
* Mon Jun 19 2017 wfeldt@opensuse.org
- merge gh#openSUSE/installation-images#188
- /etc/systemd: keep symlinks instead of files (bsc#1044791)
- 14.319
* Thu Jun  8 2017 wfeldt@opensuse.org
- merge gh#openSUSE/installation-images#187
- leap-42.3: include video drivers from drm-kmp (bsc#1043146)
- 14.318
* Fri Jun  2 2017 jslaby@suse.cz
- merge gh#openSUSE/installation-images#186
- etc: update module.config to match 4.12
- 14.317
* Thu Jun  1 2017 snwint@suse.de
- sle15: don't require obsolete sles-release-DVD package (bsc#1041893)
* Tue May 30 2017 wfeldt@opensuse.org
- merge gh#openSUSE/installation-images#185
- allow driver updates also to be applied to the rescue system
  (bsc#1025621)
- avoid build problems when different openssl versions exist
- new skelcd-control-<BRANDING> packages have files in /usr/lib/skelcd
- 14.316
* Mon May 29 2017 snwint@suse.de
- rewrite spec file to simplify building different flavors (bsc#1039285)
* Tue May 16 2017 snwint@suse.de
- require star explicitly
* Fri May 12 2017 wfeldt@opensuse.org
- merge gh#openSUSE/installation-images#184
- build 'real' SLED theme (bsc#1038838)
- 14.315
* Wed May 10 2017 wfeldt@opensuse.org
- merge gh#openSUSE/installation-images#183
- anticipate openssl repackaging
- 14.314
* Wed May 10 2017 snwint@suse.de
- adjust spec file for sle15 (bsc#1038473)
* Wed May 10 2017 jslaby@suse.cz
- merge gh#openSUSE/installation-images#180
- etc: update module.config to match 4.11
- 14.313
* Wed May 10 2017 snwint@suse.de
- don't build Kubic on Leap (bsc#1038025)
* Fri May  5 2017 wfeldt@opensuse.org
- merge gh#openSUSE/installation-images#181
- added Kubic theme
- rename skelcd-control-CASP to *-CAASP
- calculate driver update path for Kubic release
- 14.312
* Fri Apr 28 2017 snwint@suse.de
- fix spec file
* Fri Apr 28 2017 wfeldt@opensuse.org
- merge gh#openSUSE/installation-images#179
- add Mesa-libGL1 (bsc#1035770)
- 14.311
* Wed Apr 26 2017 wfeldt@opensuse.org
- enhance documentation
- add password bug warning
- merge gh#openSUSE/installation-images#178
- some doc adjustments
- 14.310
* Tue Apr 25 2017 wfeldt@opensuse.org
- merge gh#openSUSE/installation-images#177
- add dwc2 module (bsc#1035999)
- 14.309
* Fri Apr 21 2017 lslezak@suse.cz
- merge gh#openSUSE/installation-images#176
- Ignore python2-setuptools package instead of python-setuptools
- 14.308
* Tue Apr 18 2017 lslezak@suse.cz
- SLED fixes:
  * build only on x86_64 (bsc#1034595)
  * do not include the SAP installation wizard
* Tue Apr 11 2017 snwint@suse.de
- change package name (again) to contain "-<THEME>" (fate#322275)
- use osc multibuild feature
- new skelcd-installer-<THEME> sub-package that will become the default
  in the future (bsc#1031335)
* Wed Apr  5 2017 snwint@suse.com
- adjust virtio module config (bsc#1028369)
- 14.307
* Fri Mar 31 2017 snwint@suse.com
- vim uses update-alternatives
- 14.306
* Tue Mar 28 2017 snwint@suse.com
- adjust module config
- 14.305
* Mon Mar  6 2017 snwint@suse.de
- selfupdate enabled also in sle12-sp3
* Fri Mar  3 2017 snwint@suse.com
- copy the correct modprobe blacklist files to rescue system (bsc#1023023)
- 14.304
* Thu Mar  2 2017 snwint@suse.com
- ensure lvm config files are writable
- 14.303
* Thu Mar  2 2017 snwint@suse.de
- change tftpboot-installation subpackages to contain product in package name
* Mon Feb 20 2017 snwint@suse.com
- fix install script to move the correct files (fate#322275)
- enhance tftpboot-installation package to include all files needed to build our installation iso
- 14.302
* Mon Feb 20 2017 snwint@suse.com
- adjust 'boot from harddisk' to also work on caasp systems (bsc#1025851)
- 14.301
* Wed Feb 15 2017 snwint@suse.com
- make yast selfupdate feature configurable via YAST_SELFUPDATE env variable
- 14.300
* Wed Feb 15 2017 snwint@suse.de
- turn off YaST selfupdates for SLE12
* Tue Feb  7 2017 snwint@suse.de
- adjust /srv/tftpboot permissions
* Mon Feb  6 2017 snwint@suse.com
- install tftp files to /srv/tftpboot
- drop obsolete telnet and remaining ncurses5 uses
- 14.299
* Mon Feb  6 2017 snwint@suse.com
- adjust module config
- 14.298
* Mon Jan 30 2017 snwint@suse.com
- move grub file into x86_64-efi subdir to avoid issues mentioned in bsc#1022294
- copy tftp files into final position
- use cracklib-dict-full instead of cracklib-dict-small
- readme for x86_64
- generic readme for all architectures
- pxelinux startup message
- basic pxelinux config
- basic tftp grub2 config
- build tftp directory
- include sha256 sums of image files in initrd
- load control.xml from instsys location
- add tftp Makefile target
- add some more config settings to $ConfigData
- don't add package list if it's empty
- create noarch subpackages: tftpboot-installation-<THEME>-<ARCH>
- 14.297
* Thu Jan 19 2017 snwint@suse.com
- remove xf86-video-vmware (bsc#1020649)
- drop glibc-32bit dependencies
- 14.296
* Mon Jan 16 2017 snwint@suse.com
- rename remaining bits from CASP to CAASP
- 14.295
* Mon Jan 16 2017 snwint@suse.com
- use TEST_ARCH also in mlist2 script
- sanitize s390x module config
- 14.294
* Fri Jan 13 2017 snwint@suse.com
- follow casp -> caasp renaming in driver update directory
- adjust module config for kernel 4.10
- 14.293
* Fri Jan 13 2017 snwint@suse.com
- casp-release is now caasp-release
- 14.292
* Thu Jan 12 2017 snwint@suse.com
- additional log files for fate#318971
- 14.291
* Thu Jan 12 2017 snwint@suse.com
- zypp.conf is really in initrd, so modify it there
- 14.290
* Thu Jan 12 2017 snwint@suse.com
- there are *.so files now in /usr/lib/systemd (bsc#1019355)
- 14.289
* Wed Dec 21 2016 snwint@suse.com
- fix typo in initrd.file_list
- 14.288
* Wed Dec 21 2016 snwint@suse.com
- add uuencode to initrd
- 14.287
* Wed Dec 21 2016 snwint@suse.com
- documentation update
- caveats on make's linuxrc env variable
- deleted whitespaces
- some more precise instructions
- added a tree to explicitly show how the directories look like
- added a section link
- added troubleshooting section
- typos fix and wording changes
- deleted images.md because obsolete, instead Anatomy of the images
- 14.286
* Fri Dec 16 2016 snwint@suse.de
- test %%with_storage_ng flag so we can build against the new yast storage code directly
* Fri Dec  9 2016 snwint@suse.com
- dbus-launch moved into dbus-1; we don't need it
- we need yet another branding config var
- use new theme variables to adjust branding
- libsystemd is a separate package meanwhile
- drop obsolete xf86-video-modesetting, make xf86-input-libinput optional
- /etc/issue is no longer available in casp, use our own
- remove /etc/issue from root image (it's in initrd aleady)
- adjust zypp.conf for CASP (fate#321764)
- remove support for obsolete pango-modules package
- start rsyslogd in inst_setup if not already running
- add CASP branding to test iso
- add CASP branding to x86 install script
- sanitize config variable expansion code
- allow arbitrary theme config settings
- support casp in dud directory calculation
- adjust kernel module config
- keep sample CASP os-release for reference and testing
- add more fine-grained control over branding
- cleanup Makefile: remove obsolete stuff
- add our own /etc/issue for rescue system
- delete obsolete files
- 14.285
* Tue Dec  6 2016 snwint@suse.com
- removed yet another trace of syslogd
- build without *-release-mini packages
- replace syslogd with rsyslog
- 14.284
* Tue Dec  6 2016 snwint@suse.com
- remove 'upgrade' entry from boot menu if BOOTMENU_NO_UPGRADE is set (fate#322063)
- 14.283
* Fri Dec  2 2016 snwint@suse.com
- remove unused dbus-1-x11 (bsc#1012564)
- 14.282
* Mon Nov 28 2016 snwint@suse.com
- adjust dud directory calculation to new tumbleweed os-release format (bsc#1012241)
- 14.281
* Fri Nov 25 2016 snwint@suse.com
- linuxrc's loghost scripts added fate#318971
- 14.280
* Thu Nov 24 2016 snwint@suse.com
- removed local alias
- 14.279
* Fri Nov 18 2016 snwint@suse.com
- removed double documentation page for README
- enabled "edit on github" button on the doc pages
- 14.278
* Wed Nov  9 2016 snwint@suse.com
- fix last module config change
- stick to grub default colors (bsc#1005899)
- 14.277
* Wed Nov  9 2016 snwint@suse.com
- update module.config to match 4.9
- Correct susehmc.ins to have full paths to the files in boot/s390x/
- Corrected the line to install parmfile.hmc
- Added susehmc.ins and parmfile.hmc files to allow installation from the DVD reader in the HMC without a network connection. (bsc#1002974)
- 14.276
* Tue Oct 18 2016 snwint@suse.com
- add dwc3 driver (bsc#1005007)
- 14.275
* Mon Oct 17 2016 snwint@suse.com
- Added susehmc.ins and parmfile.hmc files to allow installation from the DVD reader in the HMC without a network connection. (bsc#1002974)
- 14.274
* Fri Oct 14 2016 snwint@suse.com
- pass on Screenmode option to yast (bsc#780621)
- 14.273
* Fri Oct  7 2016 snwint@suse.com
- add xf86-input-libinput to inst-sys (bsc#999098)
- 14.272
* Fri Sep 30 2016 snwint@suse.com
- gather ibft devices from wicked (bsc#997598)
- 14.271
* Fri Sep 23 2016 snwint@suse.com
- adjust to release package changes
- update documentation
- extend file list syntax
- adjust to obs api change
- 14.270
* Thu Sep 22 2016 snwint@suse.com
- update module.config to match 4.8
- 14.269
* Tue Sep 20 2016 snwint@suse.com
- add iscsiuio (bsc#999658)
- 14.268
* Tue Aug 16 2016 snwint@suse.com
- Small fix to IBM and SUSE branding
- 14.267
* Tue Aug  9 2016 snwint@suse.com
- add zypp config to initrd to ensure it's writable (bsc#967828)
- fix symlink verification function
- 14.266
* Mon Aug  8 2016 snwint@suse.com
- Make pam-modules optional
- 14.265
* Fri Jul 29 2016 snwint@suse.com
- update module.config to match 4.7
- 14.264
* Thu Jul 28 2016 snwint@suse.com
- adjust to recent package changes
- 14.263
* Mon Jul 25 2016 snwint@suse.com
- fix hyperv_fb.ko location (bsc#989351)
- adjust powerpc-utils paths (bsc#989706)
- 14.262
* Wed Jul 20 2016 snwint@suse.com
- exclude kmod-compat (bsc#989706)
- 14.261
* Wed Jul 20 2016 snwint@suse.com
- Include perl-XML-Simple again in inst-sys (bsc#989702)
- 14.260
* Tue Jul 19 2016 snwint@suse.com
- use EGL_LOG_LEVEL=fatal (bsc#976374)
- 14.259
* Mon Jul 18 2016 snwint@suse.de
- limit sap packages to supported architectures
* Thu Jul 14 2016 snwint@suse.de
- don't include wpa_supplicant for s390x (bsc#974601)
* Thu Jul 14 2016 snwint@suse.com
- documented common_tree script
- load only an exactly matching inst-sys (bsc#974601)
- reduce instsys size by removing files already in initrd
- 14.258
* Thu Jul 14 2016 snwint@suse.com
- Adjust the OOM killers score for haveged (bsc#974601)
- 14.257
* Tue Jul 12 2016 snwint@suse.de
- remove obsolete firmwarekit from BuildRequires
* Tue Jul 12 2016 snwint@suse.com
- Drop some unused packages from the root image (bsc#974601)
- yast2-devtools
- yast2-buildtools
- perl-Bootloader
- perl-XML-Parser
- perl-XML-Simple
- 14.256
* Mon Jul 11 2016 snwint@suse.com
- set EGL_LOG_LEVEL=0 to stop some libELG warning (bsc#976374, bsc#970883)
- 14.255
* Wed Jun 22 2016 ohering@suse.de
- Add missing xen-tools-domU to BuildRequires (bsc#979002)
* Tue Jun 21 2016 snwint@suse.com
- add 'make' target to build ISO image for testing
- 14.254
* Tue Jun 21 2016 snwint@suse.com
- fix handling of blacklisted packages
- really exclude yast2-storage when atorage-ng is selected
- support new yast storage code
- 14.253
* Tue Jun 21 2016 snwint@suse.com
- check if /tmp/host_name really exists (bsc#985804)
- 14.252
* Fri Jun 17 2016 snwint@suse.com
- handle build id in Makefile
- 14.251
* Wed Jun 15 2016 snwint@suse.com
- add xrandr to inst-sys and pass XVideo option to install.inf (bsc#974821)
- 14.250
* Wed Jun 15 2016 snwint@suse.com
- change how rubygem-byebug is added to inst-sys
- 14.249
* Mon Jun 13 2016 snwint@suse.com
- Add xen-tools-domU on x86 to get its udev rules (bsc#979002)
- 14.248
* Wed Jun  1 2016 dimstar@opensuse.org
- Up the disk constraints to 9GB.
* Mon May 30 2016 snwint@suse.com
- adjust to update-alternative package change
- 14.247
* Mon May 30 2016 snwint@suse.com
- module.config: add macsec
- 14.246
* Mon May 23 2016 lnussel@suse.de
- disable i586 on Leap
* Thu May 19 2016 snwint@suse.com
- remove the Ruby gem cache files to save some space
- Fix byebug (Ruby debugger) symlinks if it is present (fate#318421)
- 14.245
* Tue May 17 2016 mimi.vx@gmail.com
- remove lilo from Recomends.
* Tue May 17 2016 snwint@suse.com
- add sample wicked output
- adjust hostip_from_wicked script to take real arguments
- sanitize hostname handling (fate#319639)
- 14.244
* Tue May 10 2016 snwint@suse.com
- Mount efivarfs automatically (bsc#978593)
- 14.243
* Mon May  9 2016 snwint@suse.com
- add modules needed for httpboot installation (fate#320134)
- 14.242
* Mon May  9 2016 snwint@suse.com
- include and load efivarfs module (bsc#978593)
- 14.241
* Tue May  3 2016 snwint@suse.com
- adjust config to new 'hiddenmenu' feature (bsc#976836)
- 14.240
* Thu Apr 28 2016 snwint@suse.com
- allow user to switch efi grub2 console to text mode
- 14.239
* Wed Apr 20 2016 snwint@suse.com
- More detailed listing of ifaces provided in ssh installation.bsc#956473
- 14.238
* Mon Apr  4 2016 snwint@suse.de
- remove obsolete xf86-video-modesetting dependency
* Thu Mar 31 2016 snwint@suse.com
- re-add which (bsc#973301)
- 14.237
* Wed Mar 23 2016 snwint@suse.com
- reverted list of default modules for root
- Build inst-sys extension for libstoragemgmt (fate#320272)
- 14.236
* Fri Mar 11 2016 snwint@suse.com
- Remove uga grub2 module
- 14.235
* Thu Mar 10 2016 snwint@suse.com
- Added modprobe for fuse so that hmcdrv can actually work
- 14.234
* Wed Mar  2 2016 snwint@suse.com
- Also allow desktop-specific mimeapps.list files
- 14.233
* Thu Feb 25 2016 snwint@suse.de
- drop xf86-input-vmmouse (fate#320612)
* Tue Feb 23 2016 snwint@suse.com
- added systemd-vconsole-setup (bsc#964342)
- 14.232
* Mon Feb 22 2016 snwint@suse.com
- adjust to samba package changes
- 14.231
* Mon Feb 22 2016 snwint@suse.com
- we need libblogger
- showconsole has been split from sysvinit-tools into package blog
- 14.230
* Fri Feb 19 2016 snwint@suse.com
- fix xen module list
- 14.229
* Fri Feb 19 2016 snwint@suse.com
- Include more xen frontend drivers (bsc#964342)
- 14.228
* Thu Feb 18 2016 snwint@suse.com
- Adjust aarch64 grub2 config to be more x86_64 like
- 14.227
* Thu Feb 18 2016 snwint@suse.com
- hmc: change menu label
- updated hmc mount script
- added s390-tools-hmcdrvfs
- HMC doesn't need a path
- s390x: add support for HMC (fate#318899)
- 14.226
* Thu Feb 11 2016 snwint@suse.com
- giving up on rubygem packaging (bsc#966145)
- 14.225
* Mon Feb  8 2016 snwint@suse.com
- drop the '(SNAPSHOT)' part of displayed Tumbleweed version (bsc#965645)
- 14.224
* Wed Feb  3 2016 snwint@suse.com
- adjust product/version handling
- 14.223
* Fri Jan 29 2016 snwint@suse.com
- don't chainload shim for now (bsc#963919)
- 14.222
* Thu Jan 28 2016 snwint@suse.com
- adjust rubygem handling
- 14.221
* Thu Jan 28 2016 snwint@suse.com
- fix typo in Makefile
- 14.220
* Wed Jan 27 2016 snwint@suse.com
- rework product/version handling to use the values from /etc/os-release
- 14.219
* Mon Jan 25 2016 snwint@suse.com
- filelists: glib looks for mime handler list in mimeapps.list
- 14.218
* Fri Jan 22 2016 snwint@suse.com
- nvme module has been moved (bsc#963114)
- 14.217
* Wed Jan 20 2016 snwint@suse.com
- also include VERSION files for ruby gems
- 14.216
* Tue Jan 19 2016 snwint@suse.com
- squashfs.ko might depend on lz4_decompress (bsc#962493)
- 14.215
* Mon Jan 18 2016 snwint@suse.com
- ensure /etc/hosts is writable (bsc#961880)
- 14.214
* Mon Jan 18 2016 snwint@suse.com
- Add IBM vNIC module
- 14.213
* Mon Jan 18 2016 snwint@suse.com
- noto-sans has been renamed to noto-sans-fonts
- 14.212
* Mon Jan 18 2016 olaf@aepfle.de
- Correct name of vmlinuz-xen symlink
* Thu Dec 17 2015 snwint@suse.com
- adjust module config
- add xen kernel/initrd links for compat
- 14.211
* Wed Nov 25 2015 snwint@suse.com
- added all i2c drivers (bsc#954101)
- 14.210
* Fri Nov 20 2015 snwint@suse.com
- adjust text menu message
- add 'boot installed system' boot option
- rework boot menus to hide advanced stuff in a submenu
- add 'boot from hard disk' entry to efi boot menu
- 14.209
* Fri Nov 13 2015 snwint@suse.com
- add inst_sap-start.rb (fate#318072)
- 14.208
* Fri Nov 13 2015 snwint@suse.de
- noto-sans and google-roboto-fonts only for openSUSE
* Thu Nov 12 2015 snwint@suse.com
- Add noto-sans and google-roboto-fonts to installation images
- 14.207
* Thu Nov  5 2015 snwint@suse.com
- adjust module config
- 14.206
* Fri Oct 30 2015 dvaleev@suse.com
- Require iprutils only for Power 64 bit architectures
* Thu Oct 29 2015 snwint@suse.com
- include systemd-detect-virt (bsc#952397)
- 14.205
* Tue Oct 27 2015 snwint@suse.de
- use plymouth-theme-tribar also for openSUSE
* Mon Oct 26 2015 snwint@suse.com
- include IBM1047.so (bsc#951953)
- 14.204
* Mon Oct 26 2015 snwint@suse.com
- adjust sle product name to sle12-sp1 (bsc#951244)
- 14.203
* Fri Oct 23 2015 snwint@suse.com
- tell udevd not to set mount flags (bsc#937237)
- 14.202
* Wed Oct 21 2015 snwint@suse.com
- set the default repo location based of the products file (bsc#904755)
- 14.201
* Tue Oct 13 2015 snwint@suse.com
- drop console=ttyS0 from s390x cd boot options (bsc#944443)
- 14.200
* Tue Oct 13 2015 snwint@suse.com
- fix SUSEConnect integration (bsc#949934)
- 14.199
* Mon Oct 12 2015 snwint@suse.com
- Add link to linux-devtools documentation
- Let the top-level README be only a pointer.
- Removed leftover file; see doc/README.md doc/files.md
- Try to display docs both on GitHub and ReadTheDocs
- 14.198
* Fri Sep 25 2015 snwint@suse.com
- adjust module config to latest kernel
- 14.196
* Thu Sep 17 2015 snwint@suse.com
- stop another console warning message (bsc#896804)
- 14.195
* Wed Sep 16 2015 snwint@suse.com
- add sap-installation-wizard (fate#318072)
- 14.194
* Wed Aug 12 2015 snwint@suse.com
- Drop rsh dependency
- 14.193
* Tue Aug  4 2015 snwint@suse.com
- better gawk handling
- 14.192
* Wed Jul 22 2015 snwint@suse.com
- don't strip anything (bsc#938738)
- 14.191
* Mon Jul 20 2015 snwint@suse.com
- don't srip ssl libs (bsc#938738)
- 14.190
* Mon Jul 20 2015 snwint@suse.com
- adjust to OBS api change
- 14.189
* Mon Jul 20 2015 snwint@suse.com
- keep most of initrd in a squashfs image also on s390x (bsc#937012)
- 14.188
* Mon Jul 20 2015 snwint@suse.de
- re-enable ltrace for aarch64
* Fri Jul 17 2015 snwint@suse.com
- Add Upgrade option for PowerPC
- 14.187
* Thu Jul  9 2015 snwint@suse.com
- ensure /dev/{u}random are where they are needed
- don't require ltrace on aarch64
- 14.186
* Tue Jul  7 2015 snwint@suse.com
- make net-tools-deprecated optional
- 14.185
* Tue Jul  7 2015 snwint@suse.com
- move snapper extension into regular root image (bsc#937243)
- add net-tools-deprecated (bsc#937121)
- 14.184
* Tue Jun 30 2015 snwint@suse.com
- also create /dev/random and /dev/urandom in the initrd
- 14.183
* Mon Jun 29 2015 snwint@suse.com
- Fixed installer name (fate#317637)
- There is no real /sbin/yast anymore
- It's been /usr/sbin/yast[2] for long time already
- 14.182
* Fri Jun 26 2015 snwint@suse.com
- Removed creating links to /usr/lib/YaST2/startup/YaST2.First-Stage (fate#317637)
- /sbin/yast (/usr/bin/yast) calls this script itself
- also removed removing /usr/bin/yast
- This is for simpler dud=yast2.rpm - no special changes needed anymore
- 14.181
* Fri Jun 26 2015 snwint@suse.com
- clarify meaning of git branches
- 14.180
* Tue Jun 16 2015 snwint@suse.com
- fix module dependency ordering (bsc#934580)
- 14.179
* Mon Jun 15 2015 snwint@suse.com
- Switch off Linemode for PowerPC64 architectures
- 14.178
* Thu May 28 2015 snwint@suse.com
- s390x: added hmcdrv module
- 14.177
* Thu May  7 2015 snwint@suse.com
- fix last udev rules fix
- 14.176
* Thu May  7 2015 snwint@suse.com
- Don't let udev lock the DVD drive in instsys (bsc#892941)
- 14.175
* Wed May  6 2015 snwint@suse.com
- Ruby instalation:
- 14.174
* Tue Apr 28 2015 coolo@suse.com
- buildignore build-compare to avoid hangs
* Wed Apr 22 2015 snwint@suse.com
- disable biostest build, it's not used any longer
- 14.173
* Wed Apr  1 2015 snwint@suse.de
- added ExcludeArch i586 (bnc#924024)
- add grub2 to buildrequires for s390x (bnc#893971)
- handle xen & xen-kmp separately in spec file (bnc#906248)
* Tue Mar 24 2015 snwint@suse.com
- Fix dangling symlinks for ca-certificates (with p11-kit 0.23.x)
- 14.172
* Fri Mar 20 2015 snwint@suse.com
- add polkit user to rescue system and create machine-id (bnc#922804)
- 14.171
* Wed Mar 18 2015 snwint@suse.com
- prepare for rpm signature checking in linuxrc (bnc#901598)
- 14.170
* Wed Mar 18 2015 snwint@suse.com
- Initial reorganization of the documentation
- 14.169
* Wed Mar 18 2015 lnussel@suse.de
- enable grub2 branding for aarch64
* Fri Mar 13 2015 snwint@suse.com
- Fix samba libs name for samba 4.2.0
- 14.168
* Mon Feb 23 2015 snwint@suse.com
- enable graphical grub2 with branding on aarch64
- 14.167
* Thu Feb 19 2015 snwint@suse.com
- Remove bogus check for udev init script
- 14.166
* Wed Feb 18 2015 snwint@suse.com
- Add new kernel module ipvlan for kernel 3.19.0
- 14.165
* Wed Feb 11 2015 snwint@suse.com
- add snapper.file_list
- 14.164
* Wed Feb 11 2015 snwint@suse.com
- create snapper image (fate#318392)
- 14.163
* Tue Feb 10 2015 snwint@suse.com
- align to new xorg packages
- update README
- fix zenworks boot theme
- zenworks adjustments
- 14.162
* Mon Feb  9 2015 schwab@suse.de
- libsmbios2 only exists on ia64 and x86
* Tue Feb  3 2015 snwint@suse.com
- fix dangling service links
- 14.161
* Tue Feb  3 2015 snwint@suse.com
- fix git2log script
- 14.160
* Tue Feb  3 2015 snwint@suse.com
- fix git2log to work if there's only a master branch
- fix install.i386 script
- overlayfs module comes in different names
- reduce zenroot image size
- 14.159
* Fri Jan 30 2015 snwint@suse.com
- add overlayfs module
- 14.158
* Tue Jan 20 2015 snwint@suse.com
- openldap2-client may require binutils
- 14.157
* Wed Jan 14 2015 snwint@suse.com
- xterm/xterm-bin package split
- added function to handle update-alternatives
- started to make zenworks work again
- adjust to rubygem package naming mess
- adjust to factory changes
- 14.156
* Thu Dec 11 2014 lmuelle@suse.com
- Drop bind-libs from BuildRequires as they got separated into single packages.
* Thu Dec 11 2014 snwint@suse.de
- i586: give up on xen-kmp
* Thu Dec 11 2014 snwint@suse.com
- improve git2log to work with sub-branches
- 14.155
* Thu Dec 11 2014 snwint@suse.com
- Rescue: bind-libs is in fact just a collection of libraries, that are automatically required by dependencies.
- 14.154
* Tue Dec  9 2014 schwab@suse.de
- No longer exclude valgrind and ltrace on ppc64le and aarch64
* Mon Dec  8 2014 snwint@suse.com
- adjust s390x module config
- 14.153
* Mon Dec  8 2014 snwint@suse.com
- fix Makefile
- 14.152
* Mon Dec  8 2014 snwint@suse.com
- aarch64: move kernel and initrd back to boot/aarch64
- 14.151
* Tue Nov 25 2014 snwint@suse.de
- enable xen on i586 (bnc#906248)
* Tue Nov 25 2014 snwint_jenkins@suse.com
- auto-add kernel modules needed due to module dependencies
- 14.150
* Fri Nov  7 2014 snwint_jenkins@suse.com
- aarch64: move kernel and initrd to boot/aarch64/loader
- 14.149
* Mon Oct 27 2014 snwint_jenkins@suse.com
- follow rubygem package renaming
- ignore dependency on rubygem-yard
- 14.148
* Tue Oct 14 2014 schwab@suse.de
- Add grub2-arm64-efi to BuildRequires for aarch64
* Mon Oct 13 2014 jenkins@suse.com
- updated git2log script
- 14.147
* Fri Oct 10 2014 snwint@suse.de
- add grub2-mkpasswd-pbkdf2 to inst-sys (bnc#900358)
- added 'archive' target to Makefile
- 14.146
* Mon Oct  6 2014 snwint@suse.de
- improved git2log script
- Add boot support for aarch64
- 14.145
* Wed Oct  1 2014 snwint@suse.de
- get server rescue image working
- 14.144
* Mon Sep 29 2014 snwint@suse.de
- start wpa_supplicant for wicked (bnc#898977)
- 14.143
* Mon Sep 29 2014 snwint@suse.de
- add wpa_supplicant to rescue system
- 14.142
* Thu Sep 25 2014 snwint@suse.de
- add splash=silent to enable plymouth on uefi systems (bnc#897461)
- 14.141
* Wed Sep 24 2014 snwint@suse.de
- update git2log script
- drop pcmciautils
- 14.140
* Fri Sep 19 2014 snwint@suse.de
- allow both pango-tools & pango-modules
- copy ssh keys into rescue system
- 14.139
* Mon Sep 15 2014 snwint@suse.de
- load scsi_dh_* before starting udevd (bnc#871617)
- kexec for everyone
- 14.138
* Wed Sep 10 2014 snwint@suse.de
- follow pango-tools to pango-modules rename
- improve ppc64le iso layout (bnc#894878)
- we have to load autoinst.xml, not autoyast.xml (fate#316530)
- remove rubygem(nokogiri) dependency (bnc#895069)
- 14.137
* Fri Sep  5 2014 coolo@suse.de
- run/lock is missing in more images (bnc#894648)
- optionally include custom gpg keys (bnc#895018)
  Take gpg keys from build root to allow having several packages that
  supply keys.
- 14.136
* Thu Sep  4 2014 coolo@suse.de
- increase the memory threshold to load images into RAM (bnc#893982)
- 14.135
* Thu Sep  4 2014 coolo@suse.de
- create /run/lock ourselves as it's %%ghost now (bnc#894648)
* Tue Sep  2 2014 locilka@suse.cz
- Removed "Firmware Test" from menu and firmwarekit package (bnc#894094)
* Wed Aug 27 2014 snwint@suse.de
- really use nfs-kernel-server
- 14.134
* Wed Aug 27 2014 snwint@suse.de
- use 'upgrade' (lower case, as expected by latest gfxboot)
- add ftp, nfs & samba server to rescue-server
- 14.133
* Mon Aug 18 2014 snwint@suse.de
- fix mkbootdisk (bnc#892339)
- 14.132
* Mon Aug 18 2014 snwint@suse.de
- prepare for new yast2-theme
- package split: util-linux-systemd
- move libgcrypt20-hmac to initrd, as gpg and libgcrypt20 live there already
- 14.131
* Fri Aug 15 2014 snwint@suse.de
- ensure autoyast files in /var are writable
- add back libgcrypt20-hmac and libcryptsetup4-hmac dependency
- 14.130
* Thu Aug 14 2014 snwint@suse.de
- xorg-x11-server: libglx.so link changed
- 14.129
* Wed Aug 13 2014 snwint@suse.de
- xorg-x11-server uses update-alternatives
- 14.128
* Wed Aug 13 2014 snwint@suse.de
- remove libgcrypt20-hmac and libcryptsetup4-hmac dependency for now
* Tue Aug 12 2014 snwint@suse.de
- openssh-fips will be renamed to openssh-hmac probably
- add libgcrypt20-hmac and libcryptsetup4-hmac
- 14.127
* Tue Aug 12 2014 snwint@suse.de
- fix BuildRequires
* Tue Aug 12 2014 snwint@suse.de
- Added SuSEfirewall2 sysconfig configuration (bnc#887406)
- 14.126
* Wed Aug  6 2014 snwint@suse.de
- change sshd startup to work with latest linuxrc
- 14.125
* Mon Aug  4 2014 snwint@suse.de
- fix ppc64le module config (bnc#886596)
- 14.124
* Mon Aug  4 2014 snwint@suse.de
- pass encrypted password into rescue system
- 14.123
* Thu Jul 31 2014 snwint@suse.de
- remove 'Server' from visible output (bnc#886778)
- 14.122
* Wed Jul 30 2014 snwint@suse.de
- set hostname and get ip from wicked (bnc#889374)
- 14.121
* Mon Jul 21 2014 snwint@suse.de
- adjust module config
- 14.120
* Fri Jul 18 2014 snwint@suse.de
- ca-certifices update.d snippets were renamed to clarify order
  of calling them. Adjust here (bnc#883386)
- 14.119
* Wed Jul 16 2014 snwint@suse.de
- ppc64: don't boot installation by default
- add openslp user (bnc#887016)
- added qlge, bnx2i, be2net, sfc, jsm modules to ppc64 (bnc#886596)
- 14.118
* Thu Jul 10 2014 snwint@suse.de
- ppc64: added cxgb3i and cxgb4i modules (bnc#886595, bnc#886594)
- 14.117
* Thu Jul 10 2014 snwint@suse.de
- ppc64: added mpt2sas module (bnc#886593)
- 14.116
* Wed Jul  9 2014 snwint@suse.de
- make plymouth-theme-tribar optional
- 14.115
* Wed Jul  9 2014 snwint@suse.de
- activate plymouth tribar theme (bnc#886148)
- 14.114
* Tue Jul  8 2014 snwint@suse.de
- SUSEConnect moved
- 14.113
* Mon Jul  7 2014 snwint@suse.de
- adjusted BuildRequires
* Fri Jul  4 2014 snwint@suse.de
- adjust module config
- create /etc/linuxrc.d
- 14.112
* Thu Jul  3 2014 snwint@suse.de
- keep /boot/zipl for s390
- autoload vlan module
- add vlan tools
- service_start: set exit code to 0 when we stop
- remove obsolete files
- 14.111
* Tue Jul  1 2014 snwint@suse.de
- added network start script
- cleaned up udev start script
- moved udev start script to /scripts dir
- service_start: stop services that don't have ExecStop
- 14.110
* Thu Jun 26 2014 snwint@suse.de
- adjust module config (bnc#882942)
- 14.109
* Wed Jun 25 2014 snwint@suse.de
- added tset (bnc#883898)
- drop obsolete packages: xf86-input-{joystick,keyboard,mouse}
- 14.108
* Tue Jun 24 2014 snwint@suse.de
- fix symlink issue with old udev package
- 14.107
* Tue Jun 24 2014 snwint@suse.de
- remove /lib/firmware from rescue image so it's not shadowing the one
  from initrd (bnc#882831)
- enable sshd if requested (bnc#882844)
- 14.106
* Mon Jun 23 2014 snwint@suse.de
- remove Upgrade from PTOptions, it's handled directly in linuxrc now
- 14.105
* Tue Jun 17 2014 snwint@suse.de
- move haveged to initrd (bnc#875848)
- s390x: keep /boot/zipl writable
- 14.104
* Thu Jun  5 2014 snwint@suse.de
- add all fonts except chinese/japanese/korean to inst-sys
- 14.103
* Tue Jun  3 2014 snwint@suse.de
- don't delete too many files in /var
- 14.102
* Fri May 30 2014 snwint@suse.de
- remove tightvnc from buildrequires
* Fri May 30 2014 snwint@suse.de
- get package solver working in sub-images
- cleaned up biostest image
- 14.101
* Wed May 28 2014 snwint@suse.de
- enable wicked in rescue system
- improve dhcpcd script to accept ethX
- fix 32 bit build
- 14.100
* Tue May 27 2014 snwint@suse.de
- reworked dangling symlink checking
- added ca-certificates (bnc#877004)
- added sle12-desktop-migration (bnc#876992)
- pata_macio added to modules.conf
- syslog also to console 4
- 14.99
* Fri May 23 2014 snwint@suse.de
- get syslogd working again, logging to /var/log/messages
- change nscd config to not cache passwd & group (bnc#878904)
- start nscd always (used to be for network installs only - but yast will
  probably start network anyway later on)
- 14.98
* Fri May 23 2014 snwint@suse.de
- don't run nscd (bnc#878904)
- 14.97
* Thu May 22 2014 snwint@suse.de
- add systemd-sysctl (bnc#879248)
- 14.96
* Thu May 22 2014 snwint@suse.de
- start wickedd-nanny, more debug output (bnc#879127)
- 14.95
* Wed May 21 2014 snwint@suse.de
- don't show default autoyast loading message
- Start hyper-v helpers manually with helper script
- add missing tools for netconfig
- 14.94
* Mon May 19 2014 snwint@suse.de
- add yast preferred font list (bnc#878292)
- mention dhcpcd in startup message
- 14.93
* Mon May 19 2014 snwint@suse.de
- get plymouth working again
- 14.92
* Fri May 16 2014 snwint@suse.de
- added /var/run -> /run symlink
- wicked is started with debug options
- fix all kinds of font issues (bnc#878292, bnc#866705)
- add systemd udev rules to initrd to make wicked work
- 14.91
* Thu May 15 2014 snwint@suse.de
- always set LIBGL_ALWAYS_INDIRECT (bnc#869172)
- added dhcpcd function for convenience
- added all of fonts-config (bnc#866705)
- added iscsiuio (bnc#874795)
- 14.90
* Thu May  8 2014 snwint@suse.de
- don't use linuxrc specific fonts (bnc#875592)
- 14.89
* Mon May  5 2014 snwint@suse.de
- remove kernel-installation-tapeipl (fate#316995)
* Mon May  5 2014 snwint@suse.de
- fix typo
- 14.88
* Mon May  5 2014 snwint@suse.de
- ensure /etc/iscsi is writable
- fips support for installation and rescue support bnc#875848
- add dracut-fips if present for FIPS capable rescue system
- add openssh-fips and libopenssl1_0_0-hmac for FIPS capable installation
- remove suspend from buildrequires
- add gptfdisk to buildrequires (bnc#801446)
- 14.87
* Fri May  2 2014 dvaleev@suse.com
- Remove lilo from BuildRequires
- Fix gawk symlink in base
- Require pdisk on ppc ppc64
* Wed Apr 30 2014 snwint@suse.de
- fix kernel image matching
- 14.86
* Wed Apr 30 2014 snwint@suse.de
- removed qemu-linux-aarch64 and kdump (bnc#875765)
- 14.85
* Mon Apr 28 2014 snwint@suse.de
- shuffle directories between inst-sys and initrd
- make sure /var is writable
- avoid filesystem package where possible
- 14.84
* Mon Apr 28 2014 snwint@suse.de
- fix SUSEConnect handling
- Drop Power lilo
- 14.83
* Mon Apr 28 2014 snwint@suse.de
- make /var/lock link work again
- fix SUSEGreeter handling
- 14.82
* Fri Apr 25 2014 snwint@suse.de
- handle SUSEConnect, add var/lock symlink
- 14.81
* Fri Apr 25 2014 snwint@suse.de
- add tar to initrd
- added virtio_scsi to ppc modules (bnc#874681)
- add xz to initrd
- remove /etc/os-release
- root.file_list: ignore zypper, add optional skelcd-control-SLES-for-VMware
- ignore zypper, add optional skelcd-control-SLES-for-VMware
- 14.80
* Tue Apr 22 2014 snwint@suse.de
- log wickedd output
- added --stop options to service_start script (bnc#873057)
- patch file removed: sysvinit.diff
* Mon Apr 21 2014 coolo@suse.com
- sysvinit no longer required: sysvinit.diff
* Tue Apr 15 2014 snwint@suse.de
- add rpc user (bnc#873173)
* Mon Apr 14 2014 snwint@suse.de
- deal with unnecessary links to /usr/sbin/service
* Mon Apr 14 2014 snwint@suse.de
- added haveged to BuildRequires
* Thu Apr 10 2014 snwint@suse.de
- added raleway-fonts (used by new yast theme)
* Mon Apr  7 2014 snwint@suse.de
- no perl in initrd
- fix Makefile
* Mon Apr  7 2014 snwint@suse.de
- switch to xz for initrd compression
- adjust module config
- simplify initrd creation
- keep original yast script out of the way
* Thu Apr  3 2014 snwint@suse.de
- go for kmod
* Tue Apr  1 2014 snwint@suse.de
- ignore yast2-schema
* Fri Mar 28 2014 snwint@suse.de
- add infiniband modules (bnc#865852)
* Fri Mar 28 2014 snwint@suse.de
- go for cracklib-dict-small
- log service output (bnc#868932)
- don't use stderr in service_start (bnc#868932)
* Thu Mar 27 2014 snwint@suse.de
- enforce cracklib-dict-small in initrd
- /etc/sysconfig/fcoe is gone
- added missing linuxrc options (bnc#869989):
-   * 'productprofile' option (fate#312035)
-   * 'addon' option (fate#314318)
* Mon Mar 24 2014 snwint@suse.de
- make sure plymouth is always turned off (bnc#869864)
- write ssh install instructions into motd
* Thu Mar 20 2014 snwint@suse.de
- move 'hostname' into initrd
- make 'boot installed system' work from usb disk (bnc#807157)
- add and start haveged (bnc#869158)
* Wed Mar 19 2014 snwint@suse.de
- move /run dir completely to initrd (bnc#869122)
* Wed Mar 19 2014 snwint@suse.de
- open-fcoe are now fcoe-utils
- take care of service types
- add script to start systemd services (without systemd)
* Tue Mar 18 2014 snwint@suse.de
- adapt to fixed yast2-theme
* Tue Mar 18 2014 snwint@suse.de
- s390: revert parmfile change (bnc#867811)
* Mon Mar 17 2014 snwint@suse.de
- added kdump package (fate#315241)
* Fri Mar 14 2014 snwint@suse.de
- remove system wide bash startup scripts (bnc#867577)
- prepare for a separate SLED theme but for now just drop 'Server' (bnc#867976)
* Fri Mar 14 2014 snwint@suse.de
- fix ppc grub2 branding
* Wed Mar 12 2014 snwint@suse.de
- startshell=1 now starts login shell, so .profile is actually read
* Wed Mar 12 2014 snwint@suse.de
- changed login message to refer to setup_ssh (bnc#866383)
- added help text to setup_ssh
- removed some unused files
- added basic .bashrc with some aliases
- ensure passwd/shadow/group are only in initrd
* Mon Mar 10 2014 snwint@suse.de
- go for release-mini instead of -dvd
* Mon Mar 10 2014 snwint@suse.de
- load autoyast.xml and driver updates from OEMDRV partition (fate#316530)
- Put grub2 on ppc media
- add all of Xvnc package (bnc 867273)
* Thu Mar  6 2014 snwint@suse.de
- add sg3_utils to initrd (bnc#866933)
* Thu Mar  6 2014 snwint@suse.de
- add sysconfig-netconfig to initrd (bnc#867078)
* Wed Mar  5 2014 snwint@suse.de
- fix yast2 theme handling in openSUSE
- change terminal to ibm3270
* Tue Mar  4 2014 snwint@suse.de
- fix rescue system (bnc#841695)
* Mon Mar  3 2014 snwint@suse.de
- rename yast theme in openSUSE
- filesystem package comes with /var/run symlink
- adjust module config
- systemd has new library names
- take all of fontconfig - see sr#224058
* Fri Feb 28 2014 snwint@suse.de
- adjust s390x parameters (bnc#866061)
* Thu Feb 27 2014 snwint@suse.de
- remove special branding image
- remove last remaining explicit qt4 references
* Thu Feb 27 2014 snwint@suse.de
- move s390x files to branding directory
- kill dhcpcd entirely
- create cd.ikr
- Add mount-rootfs-and-do-chroot.sh to inst-sys and rescue (bnc#674684)
- Add ed25519_key to predefined ssh keys
- Include hyper-v package in inst-sys and rescue to enable the host to query IP addresses.
- rearrange s390x files (bnc#865348)
- rename IMAGE to LINUX in sles12.exec (bnc#865348)
* Fri Feb 21 2014 snwint@suse.de
- replace sles11.exec with sles12.exec (bnc#865109)
- link gawk also in initrd or we get dangling symlinks
* Thu Feb 20 2014 coolo@suse.com
- also symlink awk in initrd
* Wed Feb 19 2014 snwint@suse.de
- add all tools from xorg-x11-Xvnc (bnc#855246)
* Tue Feb 18 2014 snwint@suse.de
- move /etc/motd and /etc/issue to initrd
* Tue Feb 18 2014 snwint@suse.de
- fix Solver usage
- add sysconfig files to initrd
* Tue Feb 18 2014 snwint@suse.de
- more branding fixes
* Tue Feb 18 2014 snwint@suse.de
- branding fixes
* Tue Feb 18 2014 snwint@suse.de
- adjust to new branding packages
* Mon Feb 17 2014 snwint@suse.de
- avoid using rcnscd (bnc#863430)
- Fix branding image installation for ppc64le
- switch back to yaboot for a while
- fix ssl certificates (bnc#863788)
- ignore rake, rdoc and ri from ruby
* Wed Feb 12 2014 coolo@suse.com
- add ruby-ua.patch to fix build with ruby 2.1
* Tue Feb 11 2014 snwint@suse.de
- fix wrong ifarch s390x
- set SLES boot theme temporarily to openSUSE as SLES branding is still missing
- don't produce nonsense if the grub2 theme package is missing
* Mon Feb 10 2014 snwint@suse.de
- start sshd without using sysvinit script (bnc#863029)
- switch to grub for ppc
- ppc boot config changes
- added aarch64
* Wed Feb  5 2014 snwint@suse.de
- switch to new installation-images-<theme> and install-initrd-<theme> packages
* Wed Feb  5 2014 snwint@suse.de
- added aarch64
* Wed Feb  5 2014 ohering@suse.de
- enable xen, use bcond so it does not get disabled by accident
* Mon Feb  3 2014 snwint@suse.de
- better update-alternatives alternative for ruby
* Mon Feb  3 2014 snwint@suse.de
- keep branding files all in the same image so relative symlinks work properly
* Sat Feb  1 2014 coolo@suse.com
- yast2-trans-allpacks is still needed
* Fri Jan 31 2014 snwint@suse.de
- no longer ignore certain yast2 packages
* Thu Jan 30 2014 snwint@suse.de
- use skelcd-control-* for yast package list
- Merge pull request#8 from lslezak/yast_deps_and_branding
- there can be different packages in SLES and openSUSE inst-sys
- make some branding packages optional (SLE branding has a different
  package set than openSUSE)
* Wed Jan 29 2014 snwint@suse.de
- build rescue-server
* Tue Jan 28 2014 snwint@suse.de
- added dmapi.ko
* Mon Jan 27 2014 snwint@suse.de
- fix dracut vs. mkinitrd build problems
* Fri Jan 24 2014 snwint@suse.de
- start dbus and wicked in initrd
* Thu Jan 23 2014 snwint@suse.de
- ppc64: yaboot binary only for chrp
* Wed Jan 22 2014 snwint@suse.de
- another try to resolve dracut vs. mkinitrd
* Wed Jan 22 2014 snwint@suse.de
- ignore dracut in initrd
- use xz for compression
* Tue Jan 21 2014 snwint@suse.de
- add dbus to initrd
- s390: added ls, tr, and chzdev to initrd (needed by qeth_configure)
- fix module info
- don't strip debuginfo
- moved last commit from myudevstart to early_setup script
* Wed Jan 15 2014 snwint@suse.de
- better update-alternatives alternative
- added wicked
- removed tightvnc
- fix the previous ruby update fix
- don't list libstroke
- prepare for ruby updates
- adapt to wicked and libqt5 changes
- icewm is using update-alternatives now
- removed icewm.patch
* Wed Jan 15 2014 coolo@suse.com
- extend icewm.patch with more changes in git
* Wed Jan  8 2014 coolo@suse.com
- icewm is using update-alternatives now (icewm.patch)
* Wed Jan  8 2014 mvidner@suse.com
- require the unversioned names of libyui backends
* Wed Jan  8 2014 snwint@suse.de
- add sysconfig to inst-sys
- add 'upgrade' boot entry
- special motd for s390x (bnc#795003)
* Sat Jan  4 2014 coolo@suse.com
- use bcond macros for vnc support, so I can disable it in
  core project
* Thu Dec  5 2013 snwint@suse.de
- re-enabled some yast packages
- make code ppc64le aware
- updated all_modules module list and included script to create it
* Wed Dec  4 2013 dvaleev@suse.com
- add ppc64le architecture
* Mon Dec  2 2013 snwint@suse.de
- s390 adjustments
- remove cyrus-sasl
* Thu Nov 28 2013 snwint@suse.de
- dracut or mkinitrd
* Thu Nov 28 2013 snwint@suse.de
- integrate s390 fixes
- dracut instead of mkinitrd
* Mon Nov 25 2013 snwint@suse.de
- adjust to yast2 package changes
- added `yast2-ldap-client`, `yast2-pam` and `yast2-security` to the root
  image (needed to write the user configuration in the 1st stage)
- `yast2-runlevel` has been replaced by `yast2-services-manager`
* Mon Nov 18 2013 snwint@suse.de
- integrate 13.1 changes and make it build again
- add rsxx for ppc
- added gptfdisk to rescue image (bnc#807098)
- added xen-usb.ko
- Merge pull request#3 from olafhering/hyperv-keyboard
- Include drivers/input/serio/hyperv-keyboard.ko (fate#315887)
* Wed Sep 25 2013 snwint@suse.de
- add fcoe support
* Thu Sep 19 2013 snwint@suse.de
- re-add libyui-qt-graph (bnc#841100)
* Fri Sep 13 2013 snwint@suse.de
- stop binutils in root image
* Thu Sep 12 2013 snwint@suse.de
- create sysconfig dir
- stop binutils
* Mon Sep  9 2013 snwint@suse.de
- Adopted for splitted sysconfig package
- Cleaned up setting of MODIFY_RESOLV_CONF_DYNAMICALLY
- remove yast2-mouse
- remove patch installation-images-14.13.diff
* Wed Sep  4 2013 coolo@suse.com
- add installation-images-14.13.diff to really drop yast2-mouse
* Mon Sep  2 2013 dvaleev@suse.com
- drop deprecated yast2-mouse package from buildrequires
* Mon Sep  2 2013 snwint@suse.de
- samba package changes
- On non intel architectures biosdevname doesn't exist.
* Fri Aug 30 2013 snwint@suse.de
- avoid /usr/src/packages else linuxrc thinks it's in test mode
- ppc64: use classic initrd and linux, we use yaboot anyway for netboot now
* Tue Aug 27 2013 snwint@suse.de
- convert root image - part 2
- add biosdevname (bnc#810478)
- packages we ignore need not exist
- convert root image - part 1
- convert initrd image to automatic dependency solving
* Fri Aug 23 2013 snwint@suse.de
- adjust to package changes
- convert rescue image to automatic dependency solving
- even better package deps handling
- add warning
- improved package solving
* Tue Aug 20 2013 snwint@suse.de
- move from zypper to libsolv
- minor tweak
* Mon Aug 12 2013 snwint@suse.de
- convert base image to automatic dependency solving
* Fri Aug  9 2013 snwint@suse.de
- support automatic dependency solving
- add templates
- fix elsif
* Wed Aug  7 2013 snwint@suse.de
- add ruby gems in a working way
- reenable yast2-nfs-client
- yast2-storage needs gems now
- small changes to the lists
- make sbl optional
- adapt to library changes
* Wed Aug  7 2013 coolo@suse.com
- add rubygems needed for yast2-storage (nokogiri does not seem
  to be required by rubygem-ruby-dbus, but I can find it used in
  the sources)
* Sat Aug  3 2013 coolo@suse.com
- make sbl optional to minimize staging projects (sbl requires speechd,
  orca, which requires gnome...): make-sbl-optional.diff
* Tue Jul 30 2013 snwint@suse.de
- add ruby
* Wed Jul 24 2013 snwint@suse.de
- libnscd -> libnscd1
- avoid LLVM
- we need autofs4 for systemd (bnc#807096)
- adapt to package changes
- adapt to library changes
- use debug ids
- Patch from lnussel
- Include /var/lib/ca-certificates/openssl/ as that's the current
  location openssl uses internally when SSL_CTX_set_default_verify_paths()
  is called.
* Mon Jul  8 2013 coolo@suse.com
- adapt to package changes
* Sun Jul  7 2013 coolo@suse.com
- update to git: installation-images-14.3.diff
* Thu Jul  4 2013 coolo@suse.com
- adapt to package changes
* Tue Jul  2 2013 snwint@suse.de
- generate debuginfo dependencies
- use new directory of trust anchors
* Thu Jun 27 2013 coolo@suse.com
- installation-images-14.2.diff - fix for p11kit and utempter
* Thu Jun 20 2013 snwint@suse.de
- added sg_inq (bnc#824300)
- adjust to package changes
- remove limal
- temporarly disable yast2-nfs-client
- adapt to further changes
- ibmvscsic is renamed to ibmvscsi
- Rename ibmvscsic to ibmvscsi, drop ibmvscsis module (bnc#816526)
* Sat Jun 15 2013 coolo@suse.com
- installation-images-14.1.diff - disable yast2-nfs-client temporarly
* Fri Jun  7 2013 snwint@suse.de
- remove eject
* Fri Jun  7 2013 snwint@suse.de
- adjust to package changes
* Thu Jun  6 2013 coolo@suse.com
- reenable xen
* Thu May 30 2013 coolo@suse.com
- adjust to package changes
- disable xen for the moment
* Fri May 17 2013 coolo@suse.com
- adjust to package changes
* Mon May 13 2013 coolo@suse.com
- adjust to package changes
* Sat Apr 20 2013 coolo@suse.com
- adjust to package changes
* Tue Apr  9 2013 coolo@suse.com
- adjust to package changes
* Tue Mar 19 2013 coolo@suse.com
- add patch installation-images-13.78.diff to go back to master
  branch
* Tue Mar  5 2013 snwint@suse.de
- adjust to package changes
* Wed Feb 27 2013 jslaby@suse.com
- build-require suse-module-tools (bnc#805250)
- include-s-m-t.patch: added
* Tue Feb 26 2013 snwint@suse.de
- add nfs mount to initrd (bnc#799496)
* Tue Feb 26 2013 snwint@suse.de
- ppc64 fixes
* Mon Feb 25 2013 meissner@suse.com
- spec file additions for non-x86 (ppc*) platforms
  * yast2-qt-branding-openSUSE needed also on non-x86
  * %%dir /usr/lib/install-initrd needed in %%files sections
    for some reason
* Mon Feb 25 2013 snwint@suse.de
- include ip compat links
* Wed Feb 13 2013 snwint@suse.de
- use EFI/BOOT
* Thu Feb  7 2013 meissner@suse.com
- kernel-ppc64 is now kernel-default
- xf86-video-vmware is x86 specific
* Thu Feb  7 2013 snwint@suse.de
- shim on
* Thu Feb  7 2013 snwint@suse.de
- fix rescue startup
* Wed Feb  6 2013 snwint@suse.de
- grub2 theme oddity
* Wed Feb  6 2013 snwint@suse.de
- fix efi setup
- fix spelling
* Tue Feb  5 2013 snwint@suse.de
- back to libmagic-data
* Mon Feb  4 2013 snwint@suse.de
- update efi booot config
* Mon Jan 28 2013 snwint@suse.de
- tcpd -> libwrap
- shim -> shim-unsigned
* Fri Jan 18 2013 snwint@suse.de
- add workaround until final grub2 package is ready
- get secure boot working with new grub2 package
- support https
* Mon Jan 14 2013 snwint@suse.de
- add complete lvm2 package (bnc#790724)
* Mon Jan 14 2013 snwint@suse.de
- insserv -> insserv-compat
- reworked grub2 efi config
- support shim
* Wed Jan  9 2013 snwint@suse.de
- turn on efi graphics
* Tue Jan  8 2013 snwint@suse.de
- unscd -> nscd
- adjust module config
- switch to grub2 for efi boot iso
* Tue Dec 11 2012 snwint@suse.de
- adust to package changes
* Mon Dec 10 2012 coolo@suse.com
- adapt to some package changes
* Mon Nov 26 2012 snwint@suse.de
- remove bootsplash even more
* Mon Nov 26 2012 snwint@suse.de
- removed bootsplash
- adjust to package changes
* Thu Nov 22 2012 coolo@suse.com
- bootsplash is no more
* Mon Nov 12 2012 snwint@suse.de
- adjust to package changes
* Tue Nov  6 2012 snwint@suse.de
- adjust to package changes
- fix video mode setting
* Mon Nov  5 2012 coolo@suse.com
- more adoption to sysvinit drop and systemd 195
* Sat Oct 27 2012 coolo@suse.com
- adjust to package changes - add installation-images-13.56.diff
* Tue Oct 16 2012 snwint@suse.de
- adjust to package changes
* Tue Oct  9 2012 coolo@suse.com
- adjust to package changes
* Fri Sep 28 2012 coolo@suse.com
- disable debug again to verify builds
* Thu Sep 27 2012 coolo@suse.com
- adjust to package changes
* Fri Sep 21 2012 snwint@suse.de
- adjust to package changes
* Tue Aug 14 2012 snwint@suse.de
- run udev prein script to get tape group (bnc#774725)
- add complete ntfsprogs package to instsys (bnc#775594)
* Mon Aug  6 2012 snwint@suse.de
- add udev compat link (bnc#774143, bnc#774599)
* Mon Jul 30 2012 snwint@suse.de
- add /etc/adjtime (bnc#764690)
* Sun Jul 29 2012 meissner@suse.com
- mark vmware mouse and intel video as intel/amd only.
* Fri Jul 13 2012 snwint@suse.de
- efi fix: actually remove offending line
* Fri Jul 13 2012 snwint@suse.de
- support plymouth
- efi image creation failed; added workaround (bnc#771307)
* Tue Jun 19 2012 snwint@suse.de
- fix font names in inst-sys (bnc#766991)
* Mon Jun 18 2012 snwint@suse.de
- add all of kbd to inst-sys
* Fri Jun 15 2012 coolo@suse.com
- libXp not needed, testutf8 we need in /bin
* Fri Jun 15 2012 coolo@suse.com
- add explicit xset buildrequire
* Tue Jun 12 2012 adrian@suse.de
- do not build on %%arm, we only have live images there
* Sat Jun  9 2012 ohering@suse.de
- adjust to package changes, libprocfs
* Wed Jun  6 2012 ohering@suse.de
- Restore ssh install helper features (bnc#676205)
* Tue Jun  5 2012 snwint@suse.de
- added yast2-proxy
* Wed May 23 2012 snwint@suse.de
- adjust to package changes
* Thu May 17 2012 ohering@suse.de
- adjust to package changes, libnl3-200 and libnl-1_1
* Thu May 17 2012 ohering@suse.de
- reenable xen
* Mon May 14 2012 snwint@suse.de
- disable xen
* Mon May 14 2012 snwint@suse.de
- adjust to package changes
* Thu Apr 26 2012 snwint@suse.de
- add yast2-x11 (bnc#759246, bnc#749184)
* Tue Apr 24 2012 snwint@suse.de
- adjust to package changes
* Wed Apr 18 2012 snwint@suse.de
- efont-unicode was renamed
* Tue Apr 17 2012 snwint@suse.de
- adjust rescue system setup
- installkey.gpg no longer needed
* Tue Apr  3 2012 coolo@suse.com
- reenable xen now that olaf made it build
* Tue Apr  3 2012 snwint@suse.de
- follow font package renaming
* Mon Apr  2 2012 snwint@suse.de
- adjust to package changes
- disable xen
* Mon Mar 26 2012 snwint@suse.de
- adjust to package changes
* Wed Mar 21 2012 snwint@suse.de
- adjust to package changes
* Fri Mar 16 2012 snwint@suse.de
- remove libelf0
* Fri Mar 16 2012 snwint@suse.de
- adjust xorg lib deps
* Thu Mar 15 2012 coolo@suse.com
- make it build for i586 too, so we can have it in M2
* Thu Mar 15 2012 snwint@suse.de
- make vbox package optional
- add yast.ssh link (bnc#745340)
* Thu Mar 15 2012 snwint@suse.de
- disable vbox
* Wed Mar 14 2012 snwint@suse.de
- build fails on dangling symlinks
- adjust to package changes
* Tue Feb 28 2012 snwint@suse.de
- add grub2 to buildrequires
* Mon Feb 27 2012 snwint@suse.de
- adjust to package changes
* Wed Feb 22 2012 snwint@suse.de
- adjust to package changes
- single root image filelist
- treat packages starting with '?' as optional
* Mon Feb 20 2012 snwint@suse.de
- adjust to package changes
* Thu Feb 16 2012 snwint@suse.de
- adjust to package changes
* Wed Feb 15 2012 snwint@suse.de
- adjust to package changes
- use xen kmps
- module config cleanup
- added cd1 dir
- add make target to prepare an iso image
* Wed Feb 15 2012 snwint@suse.de
- added xen-kmp
* Mon Feb 13 2012 snwint@suse.de
- adjust to package changes
- drop glibc locale archive
* Thu Feb  9 2012 snwint@suse.de
- fix symlink check
- adjust to latest package changes
* Thu Feb  9 2012 snwint@suse.de
- cpio moved
* Wed Feb  8 2012 coolo@suse.com
- some more libs deps and funny reformat of spec file
* Fri Jan 27 2012 snwint@suse.de
- ppc fixes
- fix 'find' path (bnc#733414)
* Wed Jan 25 2012 snwint@suse.de
- adjusted lib deps
* Thu Jan 19 2012 snwint@suse.de
- use liblua5_1
* Wed Jan 18 2012 snwint@suse.de
- updated config
* Wed Nov  9 2011 snwint@suse.de
- reduce udev timeout to 100s
* Wed Nov  9 2011 snwint@suse.de
- revert maxcpus workaround
* Tue Nov  8 2011 snwint@suse.de
- fix console device nodes and add tty8
* Mon Nov  7 2011 snwint@suse.de
- add maxcpus=1 to kernel options to work around udevd hang (bnc#722858)
* Wed Oct 19 2011 snwint@suse.de
- we need sysvinit-init
* Tue Oct 18 2011 snwint@suse.de
- we need efibootmgr
* Fri Oct 14 2011 coolo@suse.com
- follow libsolv rename
* Thu Oct 13 2011 snwint@suse.de
- switch to yast theme openSUSE-Oxygen
* Thu Oct 13 2011 ohering@suse.de
- add sysvinit
* Wed Oct 12 2011 ohering@suse.de
- add hdparm
- rename keyutils-libs usage to libkeyutils*
- add libgcc_s* and libstdc++ to base
* Tue Sep 27 2011 coolo@suse.com
- we need yast2-qt-branding too
* Mon Sep 26 2011 coolo@suse.com
- dmapi is gone for good
* Fri Sep 23 2011 coolo@suse.com
- Mesa changed again
* Wed Sep 21 2011 coolo@suse.com
- libattr is libattr1 now, same for libacl
* Tue Sep 20 2011 snwint@suse.de
- use new firewire modules
* Fri Sep 16 2011 snwint@suse.de
- adjust module config
- remove dhcpv6
- add drm modules
* Thu Sep 15 2011 coolo@suse.com
- fix file lists the crude way to make it build
* Thu Sep 15 2011 saschpe@suse.de
- Require dhcp-server instead of dhcpv6, the latter was dropped and
  merged into the dhcp package
* Tue Aug 30 2011 snwint@suse.de
- follow klogd split
- better module stats
* Mon Aug 29 2011 snwint@suse.de
- adjust package config
* Wed Aug 17 2011 snwint@suse.de
- adjust lib config
* Mon Aug  1 2011 snwint@suse.de
- fix ppc config
- xslt -> xslt1
* Mon Jul 25 2011 snwint@suse.de
- fix udevd startup
- unify theme handling
- adjust to various lib dependency changes
- run pango-querymodules (bnc#707016)
* Wed Jul 13 2011 coolo@novell.com
- tons of changes for GNOME libs and pam dependencies
* Mon Jun 20 2011 snwint@suse.de
- drop ash
* Wed Jun 15 2011 snwint@suse.de
- added rpmkeys (bnc#698284)
- added hyper-v drivers
* Tue Jun 14 2011 snwint@suse.de
- anticipate build service download problems & retry before giving up
- .oscrc might not be readable by root
* Tue Jun 14 2011 snwint@suse.de
- read .oscrc for auth data, better error reporting
- fix dbus-1 file list
* Fri Jun 10 2011 snwint@suse.de
- fix libusb; the good old netcat is gone
* Tue Jun  7 2011 snwint@suse.de
- don't forget to set suse release
* Fri Jun  3 2011 snwint@suse.de
- more fixes
* Fri Jun  3 2011 snwint@suse.de
- adjust module config
- cleanup version mess
- fix lib deps
- change rpm name in cache
- fix release tag
- track obs repos
- remove perl-Switch
- support obs source
* Mon May 30 2011 snwint@suse.de
- fix lib dependencies
* Mon May 30 2011 coolo@novell.com
- fix build with kernel 2.6.39 (to be redone, I have no idea
  about the modules) and new libstorage
* Wed May 25 2011 coolo@novell.com
- fix build with gcc 4.6 and perl 5.14
* Fri Mar 25 2011 snwint@suse.de
- adjust module config
* Thu Mar 24 2011 snwint@suse.de
- adjust lib deps
- start to rework module config to use the new regexp feature
- support regexp for module names in module config file
- get missing module descriptions via modinfo
* Mon Mar 21 2011 snwint@suse.de
- rename ddrescue -> dd_rescue
* Mon Feb 21 2011 snwint@suse.de
- add firmwarekit to rescue image (bnc#619520)
* Thu Feb 17 2011 snwint@suse.de
- changed inst_setup_ssh script to use rcsshd (bnc#672100)
- don't mess with mtab (bnc#668149)
* Mon Feb  7 2011 snwint@suse.de
- remove unzip and dependent libs
* Thu Jan 20 2011 snwint@suse.de
- added AutoUpgrade option to linuxrc
* Fri Jan 14 2011 snwint@suse.de
- we have libmount now
* Thu Jan 13 2011 snwint@suse.de
- remove hal
* Wed Jan 12 2011 snwint@suse.de
- opensc gone
* Mon Jan 10 2011 coolo@novell.com
- take out buildignore kernel-xen
- follow virtualbox rename
* Mon Dec 20 2010 snwint@suse.de
- tentatively enable xen (bnc#660306)
* Tue Dec 14 2010 coolo@novell.com
- libjpeg62 is default now
* Tue Nov 30 2010 snwint@suse.de
- fix insserv call
* Mon Nov 29 2010 meissner@suse.de
- Add some new PowerPC modules
- Disable more PS3 code
- Add opensc unconditionally
* Tue Nov 23 2010 snwint@suse.de
- fix xen build in spec file
* Mon Nov 22 2010 snwint@suse.de
- added tscan1 module
* Mon Nov 22 2010 snwint@suse.de
- more lib fixes
- adjust to new kernel
* Thu Nov 18 2010 meissner@suse.de
- removed petitboot, the ps3 bootloader.
* Tue Nov  2 2010 coolo@novell.com
- adjust to new libraries
* Thu Oct 21 2010 snwint@suse.de
- adjust to package changes
* Mon Oct  4 2010 snwint@suse.de
- fix package deps
* Mon Sep 27 2010 snwint@suse.de
- fix root image
* Fri Sep 24 2010 snwint@suse.de
- fix building of initrd & rescue image
* Fri Sep 10 2010 snwint@suse.de
- adjust to new kernel
- change product to 11.4
- remove floppy-READMEs (bnc#614013)
* Mon Aug 30 2010 snwint@suse.de
- make vnc optional
* Mon Aug 23 2010 snwint@suse.de
- remove aria2
* Fri Aug 20 2010 snwint@suse.de
- adjust to latest package changes
- mkinstallinitrd: take care of updated modules (bnc#622997)
* Tue Jun  8 2010 snwint@suse.de
- adjust module config
* Thu Jun  3 2010 coolo@novell.com
- add libcares2 as buildrequires, curl dropped support
  for it, but it may come back
* Wed Jun  2 2010 coolo@novell.com
- add some requires of yast2-repair as build requires
* Wed Jun  2 2010 snwint@suse.de
- remove yast2-repair
* Mon May 31 2010 snwint@suse.de
- libopenssl moved to /lib*
- sndirsch: remove kms support (bnc#610352)
* Fri May 28 2010 coolo@novell.com
- buildrequire iproute2
* Mon May 24 2010 coolo@novell.com
- libopenssl moved to /lib*
* Fri May 21 2010 snwint@suse.de
- new version
* Tue May 18 2010 coolo@novell.com
- add another kernel module to ignore list (quick hack)
* Tue May 18 2010 coolo@novell.com
- aspell is not in lib64 on i586
* Tue May 18 2010 ro@suse.de
- yast2-x11 was dropped
* Mon May 17 2010 snwint@suse.de
- fixed lib deps
- use Keyboard.map from xorg-x11
* Tue May 11 2010 snwint@suse.de
- added xkbctrl (bnc#601587)
* Mon May 10 2010 snwint@suse.de
- audit-libs is now libaudit1
- new kernel modules
- vbox adjustments (bnc#593326)
- removed hal
- allow kmps to have a different version than kernel
- removed brocade-bfa kmp
- moved all udev rules to initrd (bnc#592378)
- moved some packages from instsys to initrd
- rpm2cpio now needs rc file
* Fri May  7 2010 coolo@novell.com
- audit-libs is now libaudit1
* Tue Apr 27 2010 snwint@suse.de
- get cache directory working again
- mdadm has udev rules now (bnc#599209)
* Mon Apr 26 2010 snwint@suse.de
- rewrote package handling
* Thu Apr 22 2010 coolo@novell.com
- fix file glob
* Thu Apr 22 2010 snwint@suse.de
- fix module config to include some ex-ppc-only modules (bnc#565623)
* Thu Apr 22 2010 snwint@suse.de
- build only openSUSE theme
* Wed Apr 21 2010 snwint@suse.de
- support wildcard in package name to avoid specifying the package version
- adjust package config
* Mon Apr 12 2010 snwint@suse.de
- added /etc/xorg.conf.d (bnc#595641)
* Fri Apr  9 2010 snwint@suse.de
- use correct driverupdate path
- xterm now uses libXaw7
- use gfxboot.c32
* Tue Apr  6 2010 snwint@suse.de
- adjust config; remove most sax2 deps
* Tue Mar 30 2010 snwint@suse.de
- adjust to new lib deps
- remove "console=ttyS1" statement from parmfile.cd (bnc#502877)
* Mon Mar 22 2010 snwint@suse.de
- fix rescue system reboot (bnc#555825)
- create VERSION and changelog from git repo
* Mon Mar 22 2010 coolo@novell.com
- new hal, new samba
* Mon Mar  8 2010 snwint@suse.de
- new cracklib & udev
* Wed Mar  3 2010 snwint@suse.de
- gawk: link to awk
* Mon Mar  1 2010 snwint@suse.de
- adjusted to new sysvinit, jpeg8, gcc45
* Mon Feb 15 2010 coolo@novell.com
- adapt to sysvinit split
* Mon Feb 15 2010 snwint@suse.de
- adjust new lib deps
* Fri Feb  5 2010 snwint@suse.de
- adjust kernel module config
* Thu Jan 28 2010 meissner@suse.de
- xorg-x11-driver-radeonhd is only on x86 and x86_64, require it there
- wlan is everywhere (ppc,ppc64,ia64 are candidates, we could filter
  it on s390), added wpa_supplicant and wireless-tools
- various indirectly required things are not pulled in correctly in ppc.
- libcryptsetup0 was renamed to libcryptsetup1
- added libXi6 and xorg-x11-libs for xdpyinfo dependencies.
* Tue Jan 12 2010 snwint@suse.de
- remove empty resolv.conf (bnc#560405)
- adjust kernel module config
- fix lib deps
- more kernel module fixes
* Mon Nov 30 2009 meissner@suse.de
- remove kernel-ppc64-extra, no longer included
* Mon Nov  9 2009 snwint@suse.de
- added Xvnc back (bnc#530111)
- update dud url for 11.2
* Thu Oct 29 2009 snwint@suse.de
- adjust perl module deps
* Tue Oct 13 2009 snwint@suse.de
- adjust to new sbl package, part 2
* Tue Oct 13 2009 snwint@suse.de
- adjust to new sbl package
- fix missing ntfs link (bnc#540511)
- added /sbin/splash to rescue (bnc#511227)
* Wed Oct  7 2009 snwint@suse.de
- adjusted BuildRequires
* Fri Oct  2 2009 snwint@suse.de
- added vbox stuff (bnc#543517)
- more xorg modules (bnc#543517)
* Mon Sep 28 2009 snwint@suse.de
- don't depend on all branding files
* Thu Sep 24 2009 snwint@suse.de
- we need more perl modules
* Thu Sep 17 2009 snwint@suse.de
- keep initrd mostly compressed for i386 & x86_64
* Tue Sep 15 2009 snwint@suse.de
- reenabled xen (bnc#501700)
* Mon Sep 14 2009 snwint@suse.de
- drop nscd
* Mon Sep 14 2009 snwint@suse.de
- added unscd to BuildRequires
* Wed Sep  9 2009 snwint@suse.de
- start nscd in instsys (bnc#530440)
* Tue Sep  8 2009 snwint@suse.de
- more cleanups
* Mon Sep  7 2009 snwint@suse.de
- adapt to new rpm
- clean up some lib deps
- no longer ignore build errors
* Tue Sep  1 2009 snwint@suse.de
- uuidgen is in util-linux (bnc#418568)
- adjust module config
* Tue Aug 25 2009 snwint@suse.de
- adapt for latest gfxboot.com (bnc#530255)
* Mon Aug 24 2009 snwint@suse.de
- added btrfs.ko (bnc#529795)
* Tue Aug 11 2009 coolo@novell.com
- readd kernel-default instead of removing all kernels
* Mon Aug 10 2009 coolo@novell.com
- kernel-default-extra merged into kernel-default
* Tue Aug  4 2009 snwint@suse.de
- adjust to new kernel
- new libboost
* Mon Aug  3 2009 coolo@novell.com
- remove boost dependency, zypp doesn't need it since it links with
  as-needed
* Thu Jul 30 2009 snwint@suse.de
- added xorg-x11-driver-input fdi files (bnc#510739)
- fix ntfs mount (bnc#518724)
* Tue Jul 28 2009 snwint@suse.de
- install libs before running graphviz postin
- btrfsprogs are in /sbin now
- readded /sbin/blkid
- added valgrind to gdb image
* Mon Jul 27 2009 snwint@suse.de
- run postin for libstorage
- added btrfsprogs
* Tue Jul 21 2009 snwint@suse.de
- added graphviz-gnome
* Thu Jul 16 2009 snwint@suse.de
- adjtimex moved to /sbin (bnc#511226)
- added all crypto modules (bnc#484910)
- removed ppc lilo from rescue system (bnc#437793)
- track latest package splits
- support new syslinux
* Thu Jun 18 2009 snwint@suse.de
- add nls modules (bnc#510987)
- add tape group for udev (bnc#499094)
- disabled outdated ofed kmp; enic & fnic are gone
- avoid mkbootdisk hang (bnc#486791)
- mkbootdisk should not depend on lilo (bnc#485528)
- branding for mkbootdisk script (bnc#483790)
- wireless-tools got splitted
* Tue Jun 16 2009 coolo@novell.com
- unset MALLOC_CHECK_ to work around glibc deadlock
* Mon Jun 15 2009 snwint@suse.de
- no motd & issue for zenworks
- firmware test image needs libpcre
* Mon Jun 15 2009 snwint@suse.de
- fix libx86emu deps
* Wed Jun 10 2009 ro@suse.de
- drop buildreq for cxgb3-firmware (in kernel-firmware)
* Wed Jun 10 2009 snwint@suse.de
- remove xmset
* Wed Jun 10 2009 snwint@suse.de
- iwl3945-ucode conflicts with kernel-firmware; removed
* Wed Jun 10 2009 snwint@suse.de
- qlogic-firmware conflicts with kernel-firmware; removed
- new xorg.conf (bnc#510015)
- adjust to some new lib dependencies
* Tue Jun  9 2009 ro@suse.de
- really adjust buildrequires for pmtools split
* Wed Jun  3 2009 snwint@suse.de
- handle firmware files automatically
- yast2-storage-lib is now libstorage
- fix Zen theme, enable it for x86_64 (bnc#476443)
* Tue Jun  2 2009 snwint@suse.de
- pmtools gets split into dmidecode and acpica -> adjust BuildRequires
  and whatever else is needed
- adjust to new kernel
* Sun May 17 2009 coolo@suse.de
- take gcc44 libraries
* Mon May 11 2009 snwint@suse.de
- added aria2c to instsys
- some package adjustments
* Mon Apr 20 2009 dmueller@suse.de
- remove kdelibs3 buildrequires
* Fri Apr 17 2009 snwint@suse.de
- add modprobe rules from xen kmp (bnc#468265)
- enabled Zen theme (bnc#476443)
- install.s390x: patched to look for kernel-installation-tapeipl
  instead of installation-kernel-tapeipl in the /boot directory in
  order to accomodate package name change (bnc#471566)
- added xen-kmp (bnc#468265)
- added iconv (bnc#495038)
- adjust module config
- adjust to various package changes
* Thu Mar  5 2009 coolo@suse.de
- readline5 is now readline6, sonst ändert sich nix
* Thu Mar  5 2009 ro@suse.de
- disable tightvnc for the moment
* Sun Mar  1 2009 coolo@suse.de
- libcap2 and liblzma0 are needed in more sets now
* Sun Feb 22 2009 ro@suse.de
- change libboost_signals1_36_0 to libboost_signals1_38_0
- disable xen ofed enic fnic for the moment
* Thu Feb 19 2009 ro@suse.de
- fix kernel-installation-tapeipl (ifarch vs ifnarch)
* Wed Feb 18 2009 jjolly@suse.de
- Added kernel-installation-tapeipl to s390 BuildRequires
- install.s390x: fixed to look for kernel-installation-tapeipl
  instead of installation-kernel-tapeipl to accomodate package
  name change
* Mon Feb 16 2009 snwint@suse.de
- switch to use xz
- package libpixmap and libpciaccess, that moved out of xorg libs
- adjust modules.dep parser
* Sat Feb 14 2009 coolo@suse.de
- switch to use xz
- package libpixmap and libpciaccess, that moved out of xorg libs
* Mon Feb  9 2009 snwint@suse.de
- copy modprobe config from initrd to rescue system (bnc#471211)
- elilo: add extra options for broken firmware (bnc#466570)
* Wed Feb  4 2009 snwint@suse.de
- make it build in sle11-xxx
- check that insserv worked properly for rescue system (bnc#457947)
- add airport,b43,cfg80211,hermes,mac80211,orinoco,pcmcia,pcmcia_core,rfkill,ssb on ppc
- update module config
- add bonding module (bnc#470217)
- print message to cause build to fail
- added graphviz
* Mon Jan 19 2009 snwint@suse.de
- use kernel-extra (bnc#460812)
- remove kernel-binary-packages
* Fri Jan 16 2009 snwint@suse.de
- fixed sles11.exec (aka inst.exec) (bnc#447527)
* Tue Jan 13 2009 snwint@suse.de
- update sax2 package deps (bnc#461898)
* Mon Jan 12 2009 snwint@suse.de
- added qt translations (bnc#460214)
- adjusted module config to latest kernel
* Thu Dec 11 2008 uli@suse.de
- s390: force network setup when booting from CD (bnc#439907)
* Wed Dec 10 2008 snwint@suse.de
- added missing vmlinuz-xenpae link
* Tue Dec  9 2008 snwint@suse.de
- added dmraid script to rescue system (bnc#456801)
* Fri Dec  5 2008 snwint@suse.de
- added enic & fnic (bnc#455742)
* Wed Dec  3 2008 snwint@suse.de
- check /bin/bash size again at the end
* Mon Dec  1 2008 snwint@suse.de
- mkbootdisk could create an invalid FAT fs (bnc#450182)
* Mon Dec  1 2008 snwint@suse.de
- move biostest to correct place (bnc#450144)
* Sat Nov 29 2008 coolo@suse.de
- fix build in picking flavor for virtualbox-kmp
* Wed Nov 26 2008 snwint@suse.de
- rewrite modules.order (bnc#448203)
- adjust to some dm-xxx renaming
* Tue Nov 25 2008 snwint@suse.de
- check /bin/bash size in initrd
* Mon Nov 24 2008 snwint@suse.de
- added modules.order (bnc#448203)
* Mon Nov 24 2008 snwint@suse.de
- t3fw firmware is now in cxgb3-firmware (bnc#442117)
- added brocade-bfa
* Fri Nov 21 2008 snwint@suse.de
- add t3fw firmware (bnc#441595)
* Thu Nov 20 2008 snwint@suse.de
- turn kexec off for SLES & SLED (bnc#447095)
* Thu Nov 20 2008 snwint@suse.de
- move initrd to correct place
* Wed Nov 19 2008 coolo@suse.de
- do not drag in install-initrd into the minimal installation
- fix prereq
* Wed Nov 19 2008 ro@suse.de
- hack to move initrd back to boot/$ARCH/loader on x86,x86_64
* Wed Nov 19 2008 snwint@suse.de
- drop libusb1, glib
* Wed Nov 19 2008 snwint@suse.de
- libusb-0_1-5 -> libusb-0_1-4
* Wed Nov 19 2008 ro@suse.de
- use libboost_signals1_36_0 instead of boost
* Tue Nov 18 2008 snwint@suse.de
- libusb-0_1-4 -> libusb-0_1-5
- some more modules (bnc#445754)
- added 'theme' option to mkinstallinitrd
* Tue Nov 18 2008 snwint@suse.de
- fixed mkbootdisk to work with > 16 floppies (bnc#445946)
* Mon Nov 17 2008 snwint@suse.de
- added branding to install-initrd
- removed references to at76_usb & wlan-ng kmps
* Fri Nov 14 2008 snwint@suse.de
- fix mkbootdisk (bnc#444861)
* Fri Nov 14 2008 snwint@suse.de
- added video=efifb to elilo.conf
- added iscsi_ibft.ko (bnc#443531)
- ensure /etc/sysconfig is writable (bnc#441664)
- add more sax2 config files to sax2 image
- reworked branding (bnc#427743)
* Wed Nov 12 2008 snwint@suse.de
- af_packet had to be a module on ppc, add it to the module list (bnc#433540)
* Tue Nov 11 2008 snwint@suse.de
- yast2-trans-xx: we need aliases for languages linuxrc doesn't
  know about (bnc#443283)
* Mon Nov 10 2008 snwint@suse.de
- added libdrm_intel.so (bnc#442413)
- added mini-iso-rmlist (file that should not go to mini-iso, bnc#443400)
* Mon Nov 10 2008 snwint@suse.de
- added sg_luns & lsscsi to initrd (bnc#437633)
- added wireless-tools to rescue system (bnc#443199)
- don't use kernel-extra
* Fri Nov  7 2008 snwint@suse.de
- adapt mkinstallinitrd to kernel split (bnc#442177)
- prepare for initrd branding
- undid last kernel-ppc64 changes (with ok from olh)
* Fri Nov  7 2008 olh@suse.de
- disable kernel-default in dist ppc64 because it is not built
  anymore in kernel-source
* Fri Oct 31 2008 snwint@suse.de
- added gpg key for testing (for bnc#435685)
  (key does not appear in built package)
* Wed Oct 29 2008 ro@suse.de
- drop installation-kernel-tapeipl for now (s390)
* Wed Oct 29 2008 ro@suse.de
- drop cpint from buildrequires
  (unused since March 2006, see changelog)
* Mon Oct 27 2008 snwint@suse.de
- added cxgb3 on ppc (bnc#434203)
- added zfcp_san_disc (bnc#432644)
- add 3c59x, myri10ge, r8169, sky2, virtio_net (bnc#434203)
- added netconsole (bnc#430282)
- added missing perl module (bnc#432499)
* Mon Oct 27 2008 snwint@suse.de
- add xenpae compat symlinks (bnc#397065)
* Mon Oct 27 2008 snwint@suse.de
- replace FZSongTi -> ttf-arphic-uming (bnc#431280)
* Mon Oct 27 2008 snwint@suse.de
- add ibmvfc (bnc#438085)
- adjust to boost package split
- added showmount (bnc#432951)
* Mon Oct 20 2008 olh@suse.de
- use petitboot only on ppc
- remove librtas from BuildRequires, its a rpm dependency
* Fri Oct 17 2008 snwint@suse.de
- even s390x needs sax2 now (bnc#432738)
* Thu Oct 16 2008 snwint@suse.de
- fixed initrd fs parts code (bnc#430140)
* Wed Oct 15 2008 ro@suse.de
- re-enable ofed-kmp
* Wed Oct 15 2008 snwint@suse.de
- added sntp (bnc#431516)
- initrd can have parts in fs images (bnc#430140)
* Wed Oct 15 2008 ro@suse.de
- temporarily disable ofed-kmp
* Tue Oct 14 2008 uli@suse.de
- patch initrd offset in kernel when booting via suse.ins
  (bnc#432646)
* Mon Oct 13 2008 ro@suse.de
- remove dropped/upstreamed kmps from buildreqs
* Mon Oct 13 2008 snwint@suse.de
- the FTP dir was removed, move CD2 content to CD1 (bnc#431320)
- do not package ISERIES64 file anymore (bnc#433685)
- added all kbd keymaps to initrd (bnc#432581)
- various adjustments to new packages
* Mon Oct  6 2008 snwint@suse.de
- add libsqlite3-0 to rescue image
- md5sum is in /bin now (bnc#431887)
- get efi image size right (bnc#431678)
* Thu Oct  2 2008 ro@suse.de
- no ofed on ia64 for the moment
* Wed Oct  1 2008 ro@suse.de
- add the missing gfxboot-brandingg paackes to buildreq
* Wed Oct  1 2008 snwint@suse.de
- really use SLE themes for bootsplash
- add libservicelog-1_0-1 to rescue image
* Tue Sep 30 2008 snwint@suse.de
- removed %%patch from spec
* Tue Sep 30 2008 snwint@suse.de
- added yast2-reipl (fate#304960)
* Tue Sep 30 2008 snwint@suse.de
- yast2-theme-SLED -> *-SLE
- adapt to split kernel package
* Tue Sep 30 2008 kukuk@suse.de
- yast2-theme-SLED -> yast2-theme-SLE
* Mon Sep 29 2008 snwint@suse.de
- added uname (bnc#429917)
- look for driver updates on usb media (bnc#363650)
- yast2-theme-openSUSE -> *-SLED
* Fri Sep 26 2008 snwint@suse.de
- provide PS3 bootloader only on openSuSE
- remove /.buildenv usage, BUILD_DISTRIBUTION_NAME comes now from the rpm spec file
- added iwl5000-ucode
- really added ofed-kmp
* Fri Sep 26 2008 jjolly@suse.de
- Added ofed to BuildRequires in order to get the latest cxgb3
* Tue Sep 23 2008 snwint@suse.de
- ia64: link image -> efi, remove initdisk.gz
* Tue Sep 23 2008 snwint@suse.de
- add keyboard maps from sax2-indent
* Mon Sep 22 2008 schwab@suse.de
- Add perl-XML-Simple.
* Mon Sep 22 2008 snwint@suse.de
- add xen images
* Mon Sep 22 2008 olh@suse.de
- provide BUILD_DISTRIBUTION_NAME for scripts, /.buildenv is empty
* Fri Sep 19 2008 snwint@suse.de
- added rpcbind (bnc#427428)
- use either suse-build-key or openSUSE-build-key (bnc#427678)
- start yast repair module with 'dvd' as arg (bnc#403472)
- s390x: added qeth_l{2,3} (bnc#427482)
* Thu Sep 18 2008 snwint@suse.de
- avoid 'grep | head'
- EFI boot image size has 32MB limit (bnc#427303)
* Thu Sep 18 2008 adrian@suse.de
- use "build-key" meta provides instead of "suse-build-key"
* Wed Sep 17 2008 snwint@suse.de
- fixed theme bug
- buildservice fix
* Wed Sep 17 2008 snwint@suse.de
- split off 'bind' image (with bind tools) (bnc#425382)
- fix motd message (bnc#425403)
- always use openSUSE theme
* Wed Sep 17 2008 kukuk@suse.de
- disable speechd and yast2-theme-SLED
* Tue Sep 16 2008 snwint@suse.de
- follow cryptsetup package split
* Mon Sep 15 2008 snwint@suse.de
- adjust to autobuild changes ('head')
* Mon Sep 15 2008 snwint@suse.de
- new libvolumeid
- create efi boot image for x86_64
- s390: added manual=1 to parmfile (but not to parmfile.cd)
* Thu Sep 11 2008 uli@suse.de
- s390: added inst.exec script (fate#304028)
- merged resmgr patch from Autobuild
* Tue Sep  9 2008 ro@suse.de
- removed resmgr (dropped)
* Mon Sep  8 2008 snwint@suse.de
- look in /.build.binaries for rpms first
- added smartctrl (bnc#423661)
* Wed Sep  3 2008 snwint@suse.de
- sd_mod needs crc-t10dif
* Mon Sep  1 2008 snwint@suse.de
- load efivars module
* Mon Sep  1 2008 snwint@suse.de
- removed evms
- temporarily add alsa/sound to initrd (for blinux)
- added yast2-nfs-client
- new kernel modules
- remove unused InputDevices from xorg.conf, leave only /dev/input/mice
- remove unused ModulePath from xorg.conf, it breaks transition from 32 to 64 bit
* Fri Aug 29 2008 snwint@suse.de
- always use SLE branding
* Mon Aug 25 2008 snwint@suse.de
- fixed spec file typo
* Fri Aug 22 2008 snwint@suse.de
- merged Adrians OBS hack
- assume no SLE branding in OBS
* Wed Aug 20 2008 snwint@suse.de
- make /var/lock/libstorage writable (bnc#416276)
- added s390 network config scripts to initrd
- updated module config
- added bind-utils to inst-sys
- added yast2-multipath
* Thu Jul 31 2008 snwint@suse.de
- reworked instsys scripts
- added sax2 & gdb image
- added branding images
* Tue Jul 29 2008 coolo@suse.de
- libzypp needs more of boost now
* Tue Jul 29 2008 ro@suse.de
- ignore sax* on s390x
* Tue Jul 29 2008 snwint@suse.de
- fixed BuildRequires
* Wed Jul 23 2008 snwint@suse.de
- vnc needs Mesa
- added sax for mouse config
* Tue Jul 22 2008 snwint@suse.de
- removed yast2-storage-evms from BuildRequires
* Tue Jul 22 2008 snwint@suse.de
- fixed lib deps
* Mon Jul 21 2008 snwint@suse.de
- added yast2-kdump (fate#303263, fate#303893)
* Mon Jul 21 2008 snwint@suse.de
- adjusted to various package changes
- new modules
- fixed udev start script to use udevadm (bnc#406632)
- remove unneeded mkdir CD1/boot/ppc
- remove atimiscold_drv, i810_drv and SecurityPolicy
- add libpciaccess.so from xorg-x11-libs
- fix librtas installation for 64bit
- add start-statd (bnc#399987)
* Fri Jul  4 2008 snwint@suse.de
- fixed library deps: libldap, libncursesw
- atimisc_drv gone
- ipv6 support added
* Fri Jul  4 2008 aj@suse.de
- Follow ldap rename.
* Wed Jun 25 2008 snwint@suse.de
- update ppc image build for 32bit and 64bit
- keep /lib/libgcc_s.so on ppc64
- fix some missing /usr/lib64/ path in root image
- add arch ppc64 in addition to arch ppc (fate#304103)
- more xfs tools (bnc#401954)
* Mon Jun  9 2008 snwint@suse.de
- fix firmware test environment
- added missing desktop icon
* Mon Jun  2 2008 snwint@suse.de
- remove sk98lin (bnc#391275)
* Tue May 27 2008 snwint@suse.de
- add default openSUSE DUD location
* Mon May 26 2008 ro@suse.de
- scsi package has been split up, adapt rescue filelist
* Mon May 26 2008 snwint@suse.de
- fix cpufreq config (part 2)
* Mon May 19 2008 snwint@suse.de
- s390: new path to iucv
- fix cpufreq config
- move most fonts out of instsys
* Fri May 16 2008 uli@suse.de
- s390: new path to iucv module
* Thu May 15 2008 snwint@suse.de
- provide the linux32/initrd32 files on install media to simplify
  install on oldworld macs
- drop pata_isapnp (bnc#388948)
- adjust to new gfxboot package
* Wed May 14 2008 olh@suse.de
- remove unneeded /SuSE/SuSE/ppc/boot/ directory
* Tue May 13 2008 snwint@suse.de
- we need liblzmadec
* Tue May 13 2008 snwint@suse.de
- ps3: add swapon
- adjust to last bootsplash branding changes (no animations)
* Fri May  9 2008 snwint@suse.de
- firmware test needs pci lib
- remove autoloading of ps3vram and mtdblock, linuxrc loads them
* Thu May  8 2008 snwint@suse.de
- add swap to videoram on PS3 (ps3vram, mtd, mtd_blkdevs, mtdblock)
- fix some package deps
* Thu May  8 2008 snwint@suse.de
- configure & start brld in rescue system
* Wed May  7 2008 snwint@suse.de
- lower memory limit for swap (bnc#385699)
- ide-cd was renamed to ide-cd_mod
- moved braille programs to initrd
* Wed Apr 30 2008 snwint@suse.de
- added cracklib locales (bnc#381286)
- multipath tools need a lib
* Mon Apr 28 2008 snwint@suse.de
- virtio: load all virtio modules
- ncurses -> ncurses-utils, terminfo-base
* Thu Apr 24 2008 snwint@suse.de
- added nice (bnc#381470)
- more virtio modules
- added file to rescue system (bnc#381857)
* Mon Apr 21 2008 snwint@suse.de
- added arping (bnc#379987)
* Mon Apr 21 2008 ro@suse.de
- xenpae is gone
* Thu Apr 17 2008 snwint@suse.de
- re-enable xen (bnc#380635)
* Tue Apr 15 2008 ro@suse.de
- buildreq: ncurses-32bit -> libncurses5-32bit
* Tue Apr 15 2008 snwint@suse.de
- there are debuginfo & debugsource packages now
* Mon Apr 14 2008 snwint@suse.de
- various library fixes
* Wed Apr  9 2008 snwint@suse.de
- adjust to new bootsplash & gfxboot branding packages
* Mon Apr  7 2008 snwint@suse.de
- removed busybox (too broken)
- glib2 was splitted
- libxcrypt has plugin dir
- don't include yast2-trans-xx packages in inst-sys
* Wed Apr  2 2008 snwint@suse.de
- fixed spec fix
* Tue Apr  1 2008 snwint@suse.de
- changed config to use rpmlist
- fixed spec to copy rpmlist
- drop root.fonts
* Mon Mar 31 2008 snwint@suse.de
- add /boot/<arch>/rpmlist
* Mon Mar 31 2008 snwint@suse.de
- libgssapi renamed
- added lzma
- added rpm & mksquashfs to initrd
* Tue Mar 25 2008 snwint@suse.de
- adjust to new perl package
- parted needs libreiserfs (bnc#373166)
- Loma looks better than Garuda
* Mon Mar 17 2008 snwint@suse.de
- qt needs utf-16.so (bnc#371747)
* Fri Mar 14 2008 snwint@suse.de
- add bootsplash files directly to initrd for ZENworks (bnc#370332)
- add ipv6 module (bnc#370073)
* Thu Mar 13 2008 olh@suse.de
- PS3 otheros.bld moved from powerpc-utils to petitboot package
* Tue Mar 11 2008 snwint@suse.de
- curl needs kerberos
- adapt to new kernel
* Thu Mar  6 2008 snwint@suse.de
- added users_proposal.ycp (fate#302980)
* Thu Mar  6 2008 olh@suse.de
- add kernel-ppc64 to install-initrd for full module list
* Tue Mar  4 2008 snwint@suse.de
- added cracklib-dict-full to BuildRequires (bnc#365506)
* Mon Mar  3 2008 snwint@suse.de
- added virtualbox drivers (bnc#358460)
* Mon Mar  3 2008 snwint@suse.de
- A. Stieger: adjust mkbootdisk script to use two digits for floppy
  image names
- fixed library list for firmware test (bnc#359320)
* Wed Feb 27 2008 coolo@suse.de
- adapt to yast2-core split
* Fri Feb 22 2008 snwint@suse.de
- added inst_root_first.ycp
* Fri Feb 22 2008 snwint@suse.de
- added ralink-firmware (#357256)
- adapt to pwdutils changes
* Thu Feb 21 2008 coolo@suse.de
- adapt to libzypp changes
* Mon Feb 11 2008 snwint@suse.de
- add bnx2 on ppc (#359114)
- add ixgbe and e1000e on ppc (#358970)
- added sha1sum (fate#302955)
- added cracklib dict (fate#302980)
- fix module dependencies for fec_mpc52xx, dont mark required modules as hidden (#347234)
* Tue Feb  5 2008 bk@suse.de
- ntfs-3g uses /lib*/libntfs-3g.so.* for ntfs-3g and ntfs-3g.probe
* Tue Feb  5 2008 snwint@suse.de
- increased number of loop devs to 64
* Tue Feb  5 2008 olh@suse.de
- add more debuginfo packages to debug Xvnc (#358865)
- no -debuginfo packages on s390
* Mon Feb  4 2008 snwint@suse.de
- adapted to new gfxboot
- added 'mediacheck' boot option
* Fri Feb  1 2008 snwint@suse.de
- adjusted to new sbl package
- added yast2-users (fate#302980)
* Thu Jan 31 2008 snwint@suse.de
- put debuginfo into image files
* Wed Jan 30 2008 snwint@suse.de
- fixed perl file list (#357249)
* Wed Jan 30 2008 snwint@suse.de
- added icewm
* Wed Jan 30 2008 snwint@suse.de
- build with split root/rescue images
- fixed debug initrd
* Mon Jan 28 2008 snwint@suse.de
- add rescue system setup script
- add tmpfs bindmount to /usr/{lib,src}/debug
- adjust to perl package changes
* Wed Jan 23 2008 olh@suse.de
- add libqt4-debuginfo
  one line per debuginfo BuildRequires for simpler diffs
* Tue Jan 22 2008 snwint@suse.de
- removed all references to $INSTSYS
* Tue Jan 22 2008 snwint@suse.de
- add module dependencies for fec_mpc52xx (#347234)
- some package names changed
* Tue Jan 15 2008 snwint@suse.de
- fix crypto module list (#351604)
* Mon Jan 14 2008 snwint@suse.de
- prepare to split off common part from rescue/instsys images
- adapt to new perl
- sqlite is libsqlite3 now
* Wed Jan  9 2008 snwint@suse.de
- prepare for separate language-dependent instsys parts
* Tue Jan  8 2008 snwint@suse.de
- added mkfifo to instsys
* Mon Jan  7 2008 snwint@suse.de
- include the jpeg plugin so that qt can read the world map
- country was split into 2 packages
- remove some libraries no longer in use
- also rename the libpng package in the file list
- BuildRequires: libpng-debuginfo -> libpng12-0-debuginfo
- added igb
* Sat Dec 29 2007 coolo@suse.de
- include the jpeg plugin so that qt can read the world map
* Thu Dec 20 2007 coolo@suse.de
- country was split into 2 packages
* Thu Dec 13 2007 coolo@suse.de
- remove some libraries no longer in use
* Thu Dec 13 2007 coolo@suse.de
- remove yast2-qt4 again
* Wed Dec 12 2007 coolo@suse.de
- next try to get it build
* Mon Dec 10 2007 coolo@suse.de
- also rename the libpng package in the file list
- add yast2-qt4 for easier testing with both qt frontends
* Mon Dec 10 2007 aj@suse.de
- BuildRequires: libpng-debuginfo -> libpng12-0-debuginfo
* Mon Dec  3 2007 snwint@suse.de
- it's libblocxx6 now (#343731)
- sys-manager will be named ps3-sys-manager in newer kernels
- move ppc kernel/initrd from CD2 to FTP/suseboot directory (#333665)
* Mon Dec  3 2007 ro@suse.de
- mktemp is in coreutils now
* Sun Dec  2 2007 coolo@suse.de
- glib2 needs pcre now
* Fri Nov 30 2007 ro@suse.de
- remove liby2util (dropped)
* Wed Nov 28 2007 coolo@suse.de
- follow library renames
* Mon Nov 12 2007 snwint@suse.de
- adjust to new kernel
* Mon Nov 12 2007 ro@suse.de
- disable xen for the moment
- remove rt2x00,adm8211,iwlwifi (merged into mainline kernel)
* Fri Nov  9 2007 snwint@suse.de
- fix firmware test menu entry (#331531)
- include pkg-bindings translations (#330343)
- updated module list
- switch to gcc43
* Thu Oct 25 2007 ro@suse.de
- re-enable xen following kernel-source
* Mon Oct 22 2007 snwint@suse.de
- fixed fvmw deps
- reworked xen switch a bit
* Fri Oct 19 2007 ro@suse.de
- added libaio for multipath
- added libpixman for Xorg
- added gtk2/glib2/cairo/librsvg for fvwm
* Fri Oct 19 2007 snwint@suse.de
- changed product version to 11.0 (#332774)
- make /etc/YaST2 writable (#329795)
- added ldap libs to initrd (#333768)
* Fri Oct 19 2007 ro@suse.de
- add master-switch in specfile to enable/disable xen images
- disable xen until we have kernel-xen again
* Thu Sep 27 2007 snwint@suse.de
- added intel xorg driver (#328042)
* Tue Sep 25 2007 snwint@suse.de
- added libbrld.so
* Mon Sep 24 2007 snwint@suse.de
- reenabled atl1.ko (#309320)
* Mon Sep 24 2007 snwint@suse.de
- some kpartx parts were missing (#326692)
- run postin for module-init-tools (#326265)
- add cp936 (#327209)
* Mon Sep 17 2007 snwint@suse.de
- added ln & rmdir to initrd (#292375)
* Sun Sep 16 2007 coolo@suse.de
- adapt to new path of ncursesw
* Mon Sep 10 2007 snwint@suse.de
- adjust inst_setup script: dbus has been moved to /bin (#303799)
- get hald working again
* Fri Sep  7 2007 snwint@suse.de
- added brld
* Mon Sep  3 2007 snwint@suse.de
- add modprobe config to initrd (#303728)
* Mon Sep  3 2007 schwab@suse.de
- Fix build requires.
* Fri Aug 31 2007 snwint@suse.de
- sdparm is back (#304967)
- kpartx: add activate_dm_linear (#305095)
* Mon Aug 27 2007 snwint@suse.de
- add PS3 sys-manager module to allow reboot, remove old ps3_storage
- moved some files from firmware image to initrd
- increase boot loader timeout to 1 min
- add some ntp files (#299238)
- add drivers/cdrom/viocd.ko to search path
- remove unused ppc_iseries64 code
- squashfs in different dir now
* Sat Aug 25 2007 olh@suse.de
- remove squashfs-KMP
* Fri Aug 17 2007 snwint@suse.de
- x86_64: libusb really added
* Thu Aug 16 2007 schwab@suse.de
- Always add ltrace.
* Thu Aug 16 2007 snwint@suse.de
- fix x86 module deps
- fix perl module deps
* Thu Aug 16 2007 snwint@suse.de
- add fec_mpc52xx for efika
- advansys module added (#300791)
- appletouch mdule added
- fixed kmp list
* Mon Aug 13 2007 snwint@suse.de
- fixed perl module deps
- clean up library list
* Mon Aug 13 2007 snwint@suse.de
- adjusted to recent package changes
* Fri Aug 10 2007 snwint@suse.de
- added more requirements for Compress::Zlib: File/Spec
* Thu Aug  9 2007 snwint@suse.de
- removed old license.zip unpack code
- autoload some mods for wlan
* Thu Aug  9 2007 snwint@suse.de
- added showy2log and y2tool from yast2-devtools to inst-sys
- added perl dependencies of showy2log: Getopt/Long.pm, base.pm, sigtrap.pm
- removed duplicate entry for Errno.pm
- added yast to default .bash_history
- added requirements for Compress::Zlib: File/Glob.pm, auto/File/Glob,
  auto/List/Util, perl-*Compress*
- added kexec to initrd & rescue system
- some new ata modules
- fixed perl module deps
* Tue Aug  7 2007 snwint@suse.de
- libcurl fix, 2nd try
* Mon Aug  6 2007 snwint@suse.de
- added gpg to initrd (feat. 302195)
* Mon Aug  6 2007 snwint@suse.de
- getcfg gone
- use squashfs for images
- cleaned up Makefile a bit
- added yast2-ntp-client (#296469)
- readline renamed to libreadline5
- added xset (#294292)
* Sun Aug  5 2007 aj@suse.de
- Follow readline rename to libreadline5.
* Tue Jul 31 2007 snwint@suse.de
- include floppy images again
* Mon Jul 30 2007 snwint@suse.de
- firmwarekit now in /usr/lib
- added ps3 modules (#153268)
- added rpc.statd
- various package changes
* Mon Jul 23 2007 snwint@suse.de
- moved 'install - XXX' variants into submenu, added 'repair' entry (#293827)
* Fri Jul 20 2007 snwint@suse.de
- use perl-XML-Bare
* Mon Jul 16 2007 snwint@suse.de
- check perl module dependencies
- reduce MemYaST to 128MB (#282813)
- remove minmemory=0 boot option because it disables memory detection in linuxrc
- remove obsolete MemYaSTText=0 boot option
* Thu Jul 12 2007 snwint@suse.de
- added Sinhala font
- yast needs perl-XML-Simple/-Parser
* Wed Jul 11 2007 snwint@suse.de
- stop udevd from loading modules (a feature added in#286132)
* Wed Jul 11 2007 snwint@suse.de
- e2fsprogs package split
- xorg.conf: drop glx
* Thu Jul  5 2007 bk@suse.de
- fuse and ntfs-3g moved from /usr/{bin,lib*} to /bin and /lib*
* Wed Jul  4 2007 snwint@suse.de
- libelf -> libelf0
- limal is back
* Mon Jul  2 2007 lrupp@suse.de
- libelf => libelf0
* Mon Jul  2 2007 snwint@suse.de
- change cursor theme to DMZ
* Mon Jul  2 2007 snwint@suse.de
- put xen initrd & kernel on install media (#284121)
- no longer build um-initrds
* Mon Jul  2 2007 snwint@suse.de
- added socat, wget to rescue (#288734)
- gpg -> gpg2
* Thu Jun 21 2007 snwint@suse.de
- removed limal* packages
* Tue Jun 19 2007 snwint@suse.de
- use libstdc++42
* Mon Jun 18 2007 snwint@suse.de
- move to libgcc42
- libltdl -> libltdl-3
* Thu Jun 14 2007 snwint@suse.de
- vim is back
* Tue Jun 12 2007 snwint@suse.de
- added ntfs-3g support (#276450)
- added nfs-client to rescue system
* Mon Jun 11 2007 snwint@suse.de
- added mount.nfs from nfs-client (#282750)
* Mon Jun 11 2007 snwint@suse.de
- wlan module changes
- nfs package changes
- added xorg-x11-server to BuildRequires
* Fri Jun  8 2007 ro@suse.de
- add BuildIgnore for grass (pulled in by IPA fonts)
* Mon Jun  4 2007 snwint@suse.de
- added 'yes' to inst-sys
- new modules
- some package renames
* Tue May 29 2007 snwint@suse.de
- yast2-network added
- create_interface script removed
* Fri May 25 2007 snwint@suse.de
- MemYaSTText option no longer exists
* Thu May 24 2007 snwint@suse.de
- kpartx is separate package
- linuxrc needs liblkid & mkswap
* Mon May 21 2007 snwint@suse.de
- add ahci, sata_sil24, sata_sil on ppc
- added ps3_storage
- various package changes
- removed evms
- fix perl file list
- fixed module list parser (cbc.ko now really added)
* Tue May  8 2007 snwint@suse.de
- added otheros.bld for ps3
- move pre-generated ssh keys out of /etc
- we have libopenssl now
- added udev rule for ipw3945d
* Fri May  4 2007 snwint@suse.de
- libexpat.so.1 moved from expat to libexpat1
- fix inst_setup_ssh -n rootpassword
- re-add vim to inst-sys
- add mkdir to /bin, so udev scripts work (#270490)
* Mon Apr 30 2007 ro@suse.de
- added libexpat1 (#269981)
* Fri Apr 27 2007 snwint@suse.de
- s390: add dasdinfo
- readd ide-cd on ppc
- readd vim to inst-sys
- use kernel-ppc64 instead of kernel-iseries64 for ISERIES64 boot file
- added libzypp translations (#219783)
* Wed Apr 18 2007 ro@suse.de
- remove sqlite-zmd (dropped)
* Wed Apr 18 2007 snwint@suse.de
- add PS3 network and storage driver
- added s390 udev rules
- nsswitch.conf was missing in rescue system
- more ssh config fixes
- /root in rescue is now writable
* Wed Apr 18 2007 snwint@suse.de
- reworked ssh/sshd config
* Tue Apr 17 2007 schwab@suse.de
- libcurl moved to libcurl4.
- guessfstype is gone.
* Tue Apr  3 2007 snwint@suse.de
- remove unused coff support from ppc32, boot image cant fit into 4MB
- readd sd_mod and sr_mod on ppc32
- vim is back
- adjusted BuildRequires
* Wed Mar 28 2007 snwint@suse.de
- fixed type in BuildRequires
* Tue Mar 27 2007 snwint@suse.de
- ide-disk no longer autoloaded
- added rt2x00lib module
* Mon Mar 26 2007 snwint@suse.de
- add pata_sil680 for QS20 and pata_amd for JS20 to ppc64 initrd
- add viodasd, viocd and iseries_veth to ppc64 initrd
- added killproc (#244385)
- cleand up a bit & removed some really ancient files
- don't stop if kmp packages are missing
- add package list to initrd & rescue system
- use new wlan km packages
- autoload ide-disk module until#250241 is fixed
* Wed Mar 21 2007 snwint@suse.de
- add new 2.6.21 drivers
- we need fribidi to build gfxboot
* Tue Mar 20 2007 snwint@suse.de
- enable pata drivers for cmd64x, mpc52xx, via on ppc32
- added libsmbios
* Wed Mar 14 2007 snwint@suse.de
- add more evms tools (#249764)
- removed old ahci workaround (-> v6.35)
* Wed Mar 14 2007 snwint@suse.de
- s390: something about osa layer 2/3 (#184438)
- parted needs libreiserfs-devel (#198054)
* Tue Mar 13 2007 snwint@suse.de
- really set hostname in /sbin/inst_setup when booted with hostname=myhostname
- hal needs libuuid
* Mon Mar  5 2007 snwint@suse.de
- move unused bootfiles from CD1/suseboot/ to CD2/boot/ppc/ (#248844)
- we need sqlite-zmd
* Mon Feb 26 2007 snwint@suse.de
- added yast2-add-on, xorg-x11-libxcb
* Thu Feb 22 2007 snwint@suse.de
- fixed bug in splash config
- create_interface: extract OSA MAC address from install.inf (#184438)
- added new xen modules
- don't autoload scsi/ide base modules (udev does it for us)
* Wed Feb 14 2007 snwint@suse.de
- add qla3xxx and netxen for ppc
- added ext4 modules
* Fri Feb  9 2007 snwint@suse.de
- Korean uses UnDotum instead of gulim font
- added sha256 module (#242508)
* Thu Feb  8 2007 snwint@suse.de
- added#needsrootforbuild
* Mon Feb  5 2007 snwint@suse.de
- removed sock (#167572)
- fixed hostname fix (#230617)
- added keyutils-libs
* Tue Jan 30 2007 schwab@suse.de
- Add keyutils-libs.
* Fri Jan 26 2007 snwint@suse.de
- added checkmedia to BuildRequires (#238670)
* Thu Jan 25 2007 snwint@suse.de
- added adaptec firmware (#238630)
- added crc32 modules (#221223,#238661)
* Thu Jan 25 2007 snwint@suse.de
- track yast2 translations via yast2-trans-allpacks package (#216231)
* Wed Jan 24 2007 snwint@suse.de
- added new fonts to BuildRequires
* Wed Jan 24 2007 snwint@suse.de
- removed ShadowFB option (#231079)
- added some new fonts (#237347)
* Wed Jan 24 2007 snwint@suse.de
- wlan-kmp-xen is gone, ignoring it for now
* Mon Jan 22 2007 snwint@suse.de
- some new modules
- pciutils-ids gone crazy
* Fri Jan 19 2007 snwint@suse.de
- fix hostname display for ssh install (#230617)
- fixed mkbootdisk script to write files in correct order (#231158)
- make inst_setup_ssh script more robust (#233760)
* Thu Jan 18 2007 snwint@suse.de
- added ibmvstgt
* Wed Jan 17 2007 snwint@suse.de
- added cryptsetup
- added arch specific crypto modules
- remove udpcast (dropped package)
- gnome moved from /opt/gnome to /usr
- add new modules from 2.6.20-rc4
- add iscsi modules on ppc (#232501/#226682)
- libgcrypt was moved to /lib
- handle modular ramdisk
- add mptsas on ppc if available (#225712)
- add winbond pata pata_sl82c105 on ppc if availble (#159235)
* Tue Jan 16 2007 aj@suse.de
- Further changes for /opt/gnome move.
* Mon Jan 15 2007 aj@suse.de
- Get it building again with moved files.
* Wed Jan 10 2007 olh@suse.de
- handle new kernel modules from 2.6.20-rc4
  reenable evms
* Fri Dec 22 2006 ro@suse.de
- remove udpcast (dropped package)
* Wed Nov 29 2006 olh@suse.de
- disable evms for 10.2 only
  boot installer with give_me_evms_access to get it back
* Mon Nov 27 2006 snwint@suse.de
- adjust memory limits (#223753)
* Sat Nov 25 2006 olh@suse.de
- reenable xorg debuginfo packages, they are required (#223718)
* Fri Nov 24 2006 snwint@suse.de
- fixed README
* Thu Nov 23 2006 snwint@suse.de
- pmtools is intel only (#223186)
- add acpidump to rescue, moved pmtools from inst-sys to initrd
- mke2fs now needs a config file (#220200)
* Tue Nov 21 2006 snwint@suse.de
- added bcm43xx (#211037)
* Tue Nov 21 2006 snwint@suse.de
- s390x: no Xnest & Xvfb
- ia64: evmsn needs libpanelw
- pam_unix2.conf gone ages ago
* Mon Nov 20 2006 snwint@suse.de
- module config fix
- correct some build errors
* Mon Nov 20 2006 snwint@suse.de
- readd DefaultDepth 16 for fbdev at runtime (#221139)
- reenabled stricter build error checking
* Fri Nov 17 2006 snwint@suse.de
- added some yast2-trans packages
- removed DefaultDepth option from fbdev section (#221139)
- add ehea network driver on ppc (#221292)
- add qla4xxx to initrd on ppc
- fix kmp handling
- use memtest86+
* Wed Nov 15 2006 snwint@suse.de
- updated text mode boot menu
- portmap needs sysconfig (#220840)
- biostest needs dmidecode
* Tue Nov 14 2006 snwint@suse.de
- changed DefaultColorDepth to DefaultDepth in xorg.conf template
- fixed joe config
- fixed building with latest gfxboot
* Mon Nov 13 2006 snwint@suse.de
- added Option "ShadowFB" "off" to (vesa) xorg template
- added DefaultDepth 16 to (Screen[0]) xorg template
- remove /usr/sbin/atmel_fwl perl script from initrd
- separate pmac_coff and prep image building
* Fri Nov 10 2006 snwint@suse.de
- remove /etc/init.d content from udev
- move the wireless stuff into the i386/x86_64 into the bootsplash section
- remove firmware install scripts from wireless-tools
- provide wlan only on i386 and x86_64 to reduce final initrd size
- smartmontools need libstdc++
* Wed Nov  8 2006 snwint@suse.de
- added multipath-tools to inst-sys
* Mon Nov  6 2006 snwint@suse.de
- reduce the start_shell noise, reduce output by 3 lines
- a bit more ata modules
* Fri Oct 27 2006 snwint@suse.de
- works with latest gfxboot package
* Thu Oct 26 2006 snwint@suse.de
- added agp modules (#204324)
- let yaboot open the output device, instead of blindly using screen.
  should fix Xserve serial console
- fixed product name in mkbootdisk (#215214)
* Tue Oct 24 2006 snwint@suse.de
- minor firmware kit corrections
* Mon Oct 23 2006 snwint@suse.de
- added gfxboot.cfg
* Fri Oct 20 2006 snwint@suse.de
- added busybox
- minor biostest fixes
- fixed font issue (#213581)
* Tue Oct 17 2006 snwint@suse.de
- ext2/3 need mbcache module
* Tue Oct 17 2006 snwint@suse.de
- enable evms
* Mon Oct 16 2006 snwint@suse.de
- yast2 runs in fullscreen again (#208307)
- firmware kit gets scp
- fixed error checking when building firmware kit
- added pata modules
- iscsi config files changed
- added jfs_tune (#211412)
- prepare for ext2
- we now have a pciutils-ids package
- more wlan modules
- add ssh user ids back (#205380)
- remove unused YaST translations (#212233)
* Thu Oct  5 2006 snwint@suse.de
- remove pata-* modules to make it build
* Wed Oct  4 2006 snwint@suse.de
- get rid of -override- module dir
- ide modules have been moved into a new directory
* Mon Oct  2 2006 snwint@suse.de
- start hald later (#209086)
- added wlan packages to BuildRequires
* Thu Sep 28 2006 ro@suse.de
- yast2-tran-el_GR -> yast2-trans-el
* Wed Sep 27 2006 snwint@suse.de
- no via_drv
- added acpidmp, acpixtract to initrd
* Mon Sep 25 2006 snwint@suse.de
- build firmware test image (x86, x86_64)
* Tue Sep 19 2006 snwint@suse.de
- more lib fixes
* Tue Sep 19 2006 snwint@suse.de
- fixed Estonian
- fixed lib config
* Tue Sep 19 2006 aj@suse.de
- Fix BuildRequires:
  * Use correct name for openSUSE theme.
  * Fix estonian support.
* Mon Sep 18 2006 snwint@suse.de
- prepared for wlan
- YaST theme is now openSUSE
- added passwd/group to initrd (#205380)
- support Estonian
- add /var/lib/nfs/state to initrd to prevent lockd warnings
* Mon Sep  4 2006 snwint@suse.de
- added fvwm-root (#203510)
- new modules
- updated pam config
* Thu Aug 31 2006 snwint@suse.de
- use xorg-x11-fonts-core
* Tue Aug 22 2006 snwint@suse.de
- add /usr/lib/debug and /usr/src/debug directories to inst-sys, to mount debuginfo from remote
* Mon Aug 21 2006 snwint@suse.de
- more X11 changes
- added some new modules
* Mon Aug 21 2006 olh@suse.de
- create /CD1/boot/$arch/inst-sys.*.debuginfo.tar.bz2
  simple fix for#151157
* Tue Aug 15 2006 snwint@suse.de
- added libaudit
- more X11 changes
- vnc is back
* Mon Aug  7 2006 snwint@suse.de
- ongoing X11 changes
* Mon Aug  7 2006 snwint@suse.de
- added /etc/YaST2
- adjusted to hal changes
- ongoing X11 changes
- activate raid devs in rescue system
* Thu Aug  3 2006 snwint@suse.de
- added xxd
- disabled all but SuSE themes
- adjusted to Xorg changes
* Mon Jul 31 2006 snwint@suse.de
- embrace latest gcc packaging changes
- x11 starts to move to /usr
* Mon Jul 24 2006 snwint@suse.de
- cpufreq modules are back
* Mon Jul 24 2006 snwint@suse.de
- add DefaultColorDepth 16 to fbdev section (#144373)
- Depth 15 in fbdev Screen section was listed twice in xorg.conf
- added yast2-trans-{ca,vi}
- zypp needs sqlite
* Thu Jul 13 2006 trenn@suse.de
- add cpufreq modules (#176791)
* Tue Jul  4 2006 snwint@suse.de
- updated Zen theme
- makes boot floppies (#189947)
* Fri Jun 23 2006 snwint@suse.de
- acpidmp -> acpidump fixed in zen image
- added jfsutils to BuildRequires
* Wed Jun 21 2006 snwint@suse.de
- fixed root on iSCSI also for persistently named devices (#176804)
- BuildRequire yast2-vm only on x86 and x86_64
* Sun Jun 18 2006 ro@suse.de
- added libvolume_id also in zenimage
* Fri Jun 16 2006 ro@suse.de
- added libvolume_id
* Fri Jun  9 2006 snwint@suse.de
- added /usr/share/zypp/schema (#175197)
- s390: set TERM to "linux" for CD installation
- fixed 800x600 modeline in xorg.conf (#177378)
- add support for root on iscsi to create_interface (#176804)
* Wed Jun  7 2006 ro@suse.de
- BuildRequire yast2-vm only on x86 and x86_64
* Mon May 22 2006 snwint@suse.de
- added libltdl
- acpidmp got an 'u'
* Thu May 18 2006 uli@suse.de
- added new parmfile.cd with "console=ttyS1 console=ttyS0" (bug
    [#162954])
* Wed May 17 2006 snwint@suse.de
- added /var/lib/open-iscsi (#175462)
* Mon May  8 2006 snwint@suse.de
- removed obsolete (and non-working) udevd handling from inst_setup,
  linuxrc takes care of it now (#171872)
* Tue May  2 2006 snwint@suse.de
- always load sata_sis before sis5513 (#171359)
- s390x: zgetdump is gone
* Thu Apr 27 2006 snwint@suse.de
- use desktop-data-NLD for sles/d
- require only one of yast2-theme-NLD/SuSELinux (#169795)
- build only necessary themes
* Tue Apr 25 2006 snwint@suse.de
- added yast2-vm (#161721)
* Tue Apr 25 2006 snwint@suse.de
- adjusted module config
* Thu Apr 20 2006 snwint@suse.de
- x86_64 has a vmware xorg driver, too (#164319)
* Thu Apr 20 2006 snwint@suse.de
- build for xenpae, too (#167563)
* Wed Apr 19 2006 uli@suse.de
- s390: create_interface IUCV fix (bug#165898)
* Tue Apr 18 2006 snwint@suse.de
- add xen-specific modules (#166211)
* Mon Apr 10 2006 snwint@suse.de
- disable splash in ssh mode (#164740)
* Fri Apr  7 2006 snwint@suse.de
- make it build on ia64 & ppc64 & s390x
* Fri Apr  7 2006 snwint@suse.de
- raidautorun is in mdadm now (#162932)
- adjusted module config
- add missing kdb include files for mac-* keymaps to initrd
- adjusted BuildRequires
* Fri Apr  7 2006 snwint@suse.de
- added suse build key (#164001)
- disabled sloppy error checking, will fail on all errors now
- updated zenworks file lists, enabled zenworks build
* Wed Apr  5 2006 snwint@suse.de
- added yast2-trans-hr (#115341)
- fixed splash animation
- use udevsettle (#163010)
- s390: removed "console=ttyS0 console=ttyS1" from parmfile again
  (bug#163262)
- add entry firmware_class to ppc, to fix booting with 'insmod=ipr'
* Mon Apr  3 2006 snwint@suse.de
- add keymaps to ppc initrd
- added gpg (#162933)
- add symlink to plastik style (#162930)
* Fri Mar 31 2006 olh@suse.de
- acceleratedx=1 requires lspci,
  but X continues to work just fine without any BusID in xorg.conf
* Wed Mar 29 2006 snwint@suse.de
- ajusted module config
* Mon Mar 27 2006 snwint@suse.de
- use hwcfg-static for iseries_veth until the kernel is fixed (#159652 - LTC22358)
- bootsplash control socket is gone
- no yast2-x11 for s390*
* Fri Mar 24 2006 snwint@suse.de
- added s2io for ppc (#159639 - LTC22556)
- added msr module (#157429)
* Thu Mar 23 2006 snwint@suse.de
- adjusted sax2-* in BuildRequires
* Tue Mar 21 2006 snwint@suse.de
- added cpio & more to initrd
- fixed 'adddir' script to work better on conflicting directory
  trees (#159749)
* Mon Mar 20 2006 snwint@suse.de
- add spidernet for Cell
- simplify boot.msg inspection, case sensitive
- evms is back (#154379)
- use new udevtrigger command (#148043)
* Thu Mar 16 2006 uli@suse.de
- s390: added s390-tools binaries to rescue system (bug#157952)
* Wed Mar 15 2006 snwint@suse.de
- x86_64: added *32bit packages to rescue system for grub (#153094)
- s390*: has sax2-tools & ltrace (#145823)
- removed sax from BuildRequires
* Tue Mar 14 2006 kukuk@suse.de
- Remove bootsplash-theme-SuSE-Home from buildrequires
* Mon Mar 13 2006 snwint@suse.de
- mount /lib/firmware and /usr/lib/microcode as tmpfs in rescue (#155900)
- remove reiser4progs (#157465)
- added pci=nommconf to failsafe (#157390)
- driver update: NLD gets separate dir '<arch>-sled10'
- use updated themes
* Thu Mar  9 2006 snwint@suse.de
- added bc to rescue (#156061)
- ia64: added 60Hz 800x600 Modeline to xorg.conf. This is needed
  for the radeon driver on ia64 to start the X-Server (#155130)
- added via & sis drivers (#155681)
- updated mkbootdisk script (#155314)
- updated README
- back to a loose inst-sys compat check (see Mar 6 log below)
* Tue Mar  7 2006 uli@suse.de
- s390: removed cpint stuff, added /sbin/vmcp, vmcp kernel module
  (bug#149490)
- s390: added "console=ttyS0 console=ttyS1" to parmfile (bug#155707)
* Mon Mar  6 2006 snwint@suse.de
- added Khmer utf8 locale (#145854)
- added xmodmap (#154357)
- load ipr and sym53c8xx unconditionally to preserve SLES9 module loadorder (#145259)
- disable zImage.prep creation for the time being
- introduce instsys_complain_root to set warning level in inst-sys
- nolapic instead of noapic (#155280)
- this inst-sys will refuse to work with older initrds (they are
  incompatible - see previous log entry about sed)
* Wed Mar  1 2006 uli@suse.de
- moved /bin/sed from root to initrd (needed by s390
  zfcp_*_configure scripts, bug#153336)
* Wed Mar  1 2006 snwint@suse.de
- SLES: removed evms support
* Wed Mar  1 2006 snwint@suse.de
- /etc/iscsid.conf needs to be writable
- /dev/null was a file in rescue system (why?)
- added theming packages to BuildRequires
* Tue Feb 28 2006 snwint@suse.de
- s390: moved zfcp configure scripts from root to initrd
  (bug#153336)
- enabled themes
* Fri Feb 24 2006 snwint@suse.de
- add iprutils binaries from /usr/sbin (#152886)
- added yast2-trans-hi
* Tue Feb 21 2006 olh@suse.de
- do not strip debug info, leave all binaries alone (#134860)
* Tue Feb 21 2006 snwint@suse.de
- add noapic boot option (#150030)
- add initviocons on s390 (#144151)
* Mon Feb 20 2006 snwint@suse.de
- fixed rescue /dev dir
- xfs module config fixed
* Fri Feb 17 2006 snwint@suse.de
- Belgian keymap added (#117185)
- devs package no longer needed
- missing package could cause files from previous package to be added
- added accounting function showing how much each package
  contributes to boot image sizes
- add special font config file for chinese/japanese fonts
* Thu Feb 16 2006 snwint@suse.de
- fix console in rescue system for s390 (#149949)
* Thu Feb 16 2006 snwint@suse.de
- libpy2lang_perl.so needs libidn
- s390: fixed paths in suse.ins (new CD layout, bug#149406)
- give more context when following y2log
- pack sax2 stuff on s390 (needed for VNC installation)
* Wed Feb 15 2006 kukuk@suse.de
- Add libidn to root inssys.
* Tue Feb 14 2006 snwint@suse.de
- autoload battery & button modules (#149976)
* Tue Feb 14 2006 snwint@suse.de
- add apic boot option (#150030)
- try to get rescue login right (#149949)
- cleaned up ancient font mess
* Mon Feb 13 2006 snwint@suse.de
- font issue fixed (#132577)
- add ulimit -c unlimited to leave a core file if yast crashes
- add less -S /var/log/YaST2/y2log to default .bash_history
- remove unused boot.rootfsck, do not run boot.rootfsck in rescue
- add cat to initrd, for firmware.sh (#147337)
- s390: removed opensc stuff again (no longer needed by openssh)
* Sat Feb 11 2006 olh@suse.de
- do not build the pmac coff image anymore, initrd is way too big
* Fri Feb 10 2006 snwint@suse.de
- yast2-ncurses is back
* Fri Feb 10 2006 aj@suse.de
- Remove yast2-ncurses for now to get it build.
* Wed Feb  8 2006 snwint@suse.de
- ia64: move all to /boot/ia64
* Tue Feb  7 2006 snwint@suse.de
- some build fixes for ia64, x86_64
* Mon Feb  6 2006 uli@suse.de
- fix spec for /boot/<arch>
* Mon Feb  6 2006 snwint@suse.de
- use /boot/<arch>/ for all architectures
- no -nongpl kernel
- new acpi modules
* Thu Feb  2 2006 snwint@suse.de
- get rid of /dev/shm warning (#146456)
- adding libopensc to s390x image
- s390 build fix
- remove need for devs package, step 1
- added zypp
* Wed Feb  1 2006 ihno@suse.de
- adding libopensc to s390x image
* Wed Feb  1 2006 snwint@suse.de
- s390 build fix
* Wed Feb  1 2006 snwint@suse.de
- added aaa_base, util-linux to BuildRequires
- no sax2-ident on s390x
* Wed Feb  1 2006 olh@suse.de
- restore start_shell cmdline syntax, don't introduce a new option
* Mon Jan 30 2006 snwint@suse.de
- add ethtool
* Fri Jan 27 2006 snwint@suse.de
- add librtas, required by powerpc-utils
- add all tools from powerpc-utils to rescue
- lsprop and nvsetenv moved from util-linux to powerpc-utils
- remove clock from demo filelist
* Thu Jan 26 2006 snwint@suse.de
- initrd on ppc64 gets back qlogic firmware (#145152)
- added SLES theme
- SLES: added evms support
- add pidofproc, modify_resolvconf needs it (#144365)
- readd qla modules on ppc, changed link address for zImage (#145152)
- remove some dead code from inst_setup
- don't use /.start_shell, linuxrc handles it (#145619)
- add sax2-tools for s390 (#145823)
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Tue Jan 24 2006 snwint@suse.de
- reduce initrd size on ppc64 (#145152)
* Tue Jan 24 2006 snwint@suse.de
- autoload loop module
- add iscsi stuff
- rescue defaults to cramfs
* Mon Jan 23 2006 snwint@suse.de
- remove /usr/lib/YaST2/bin/yast2 (#144237)
- drop ibmsis (#144732)
- remove long obsolete and unused ppc_post_install.sh
- don't create font cache files
- added qlogic-firmware
* Thu Jan 19 2006 snwint@suse.de
- added yast2-trans-km
- added font for Hindi
* Wed Jan 18 2006 snwint@suse.de
- add 2 missing perl files for yast2-bootloader (#143746)
* Wed Jan 18 2006 snwint@suse.de
- get xfs module working again
- added perl-gettext
- less needs libncursesw
- added pam_resmgr to rescue system
* Mon Jan 16 2006 snwint@suse.de
- get modify_resolveconf working
- add /dev/md* statically
- new modules
* Wed Jan 11 2006 snwint@suse.de
- raidtools are gone
- added modify_resolvconf
* Tue Jan 10 2006 snwint@suse.de
- put lsprop into rescue system
- set version to 10.1
- adjust module info
- added xterm
- added links (at least for now)
* Wed Dec 21 2005 snwint@suse.de
- do not run initviocons for the time being, does not work on POWER4/5
  hvc console (#140383)
- put initviocons always in the rescue system
- removed module disk support
- module list cleanup, part 2
- use nongpl kernel
* Tue Dec 20 2005 snwint@suse.de
- added support for graphical installation on ia64 archs (#140142)
- module list cleanup, part 1
- activated dynamic udevd /dev handling
* Mon Dec 19 2005 snwint@suse.de
- move zImage.prep, iseries and coff kernel to CD1/boot/ppc (#118394)
- ppc: go for /boot/ppc
- don't use static insmod
- prepare for udevd in initrd
* Mon Dec 12 2005 snwint@suse.de
- fixed building rescue system
* Sun Dec 11 2005 ro@suse.de
- removed libselinux
* Fri Dec  9 2005 snwint@suse.de
- add sshd to rescue system
- build rescue system as cramfs
* Fri Dec  9 2005 snwint@suse.de
- added dhcpcd & some network tools to initrd
* Wed Dec  7 2005 snwint@suse.de
- adjust to new modules & package changes
- nfs is module now
- add portmap to initrd
* Fri Dec  2 2005 snwint@suse.de
- fix rescue system
- move initrd kbd maps to /usr/share/kbd
* Wed Nov 30 2005 snwint@suse.de
- adjust to new gfxboot/syslinux packages
* Tue Nov 29 2005 snwint@suse.de
- unpack license files
- adjust to some packages changes
* Tue Nov 29 2005 snwint@suse.de
- removed taper from neededforbuild
* Tue Nov 15 2005 snwint@suse.de
- removing /usr/lib/YaST2/bin from PATH (#131766)
- module list updated
* Mon Nov 14 2005 ro@suse.de
- disable xen for the moment
* Mon Nov  7 2005 sndirsch@suse.de
- libGL now in Mesa (xorg-x11-Mesa before)
* Wed Oct 19 2005 ro@suse.de
- removed yast2-trans-hr from nfb
* Wed Oct 19 2005 snwint@suse.de
- added libXfixes
* Wed Oct 19 2005 snwint@suse.de
- added yast2-hardware-detection
* Wed Oct 19 2005 snwint@suse.de
- add /var/lib/hardware/unique-keys directory (#117658)
- add xmset
- added croatian translations
* Fri Oct  7 2005 snwint@suse.de
- use new isolinux-config script
- produce new cd layout for i386 & x86_64 (#118394)
- add 8139too on ppc
- x11 lib names changed
* Wed Sep 14 2005 snwint@suse.de
- load psmouse module on ppc (#116406)
* Mon Sep 12 2005 snwint@suse.de
- add 'irqpoll' to failsafe (#105984)
* Wed Sep  7 2005 snwint@suse.de
- make it build on s390
* Mon Sep  5 2005 snwint@suse.de
- add mv643xx_eth,"Marvell MV643XX" for pegasos
- add reiser4 module & reiser4 support to rescue system (#114808)
- s390 module fixes
- mkbootdisk updated to handle lots of boot loader files
* Fri Sep  2 2005 snwint@suse.de
- updated docs (#113945)
- 64bit libglib2 fix
- add 'rm' to initrd
- add /sbin/lilo on ppc to root image
- shortened pcmcia module descriptions
- don't consider kernel-*-nongpl
* Tue Aug 30 2005 snwint@suse.de
- olh: correct test in mk_ppc_installation-images_bootbinaries.sh
  (thanks to jw for noticing the mistake)
- more acpi modules
* Mon Aug 29 2005 snwint@suse.de
- keep chinese fonts in japanese locale
- disable building of COFF images, linuxrc got too big to be useful
- keep the <boot-script> in one line because the Maple guys screwed their firmware
- added cfdisk to rescue
- added yast2-trans-{fi,sr}
- addes udf fs module (#113711)
* Wed Aug 24 2005 snwint@suse.de
- rescue system correctly supports keymaps (#105690)
* Tue Aug 23 2005 snwint@suse.de
- added sky2 module
- added pcmciautils & efont-unicode to neededforbuild
* Mon Aug 22 2005 snwint@suse.de
- add amd8111e and sata_vsc for 970eval board
- add &partition; to firmware path (#104649)
- removed remaining hotplug references
- added new pcmciautils
* Fri Aug 19 2005 ro@suse.de
- remove dropped package hotplug
* Wed Aug 17 2005 snwint@suse.de
- rename root, rescue -> root.ppc, rescue.ppc on pcc
* Tue Aug 16 2005 snwint@suse.de
- fixed /etc permissions (#104715)
- do not copy the vmlinux32/64 files via strip -o, they can not be reused for mkzimage that way (for unknown reasons)
- gzip the vmlinux32/64 files and name them linux32/64.gz
* Mon Aug 15 2005 olh@suse.de
- create CD1/ppc again, too much code moved around
* Mon Aug 15 2005 snwint@suse.de
- ppc: remove CD2
- ppc: move all boot related files from toplevel dir of CD1 to /suseboot
- adding a delay before registering vnc installation via slp,
  register in background, fix a typo (#104376)
- added sfdisk (#104451)
* Thu Aug 11 2005 snwint@suse.de
- new pcmcia files
- full bootsplash support (#104009)
* Fri Aug  5 2005 snwint@suse.de
- remove the 32/64bit detection part from os-chooser,
  use load go instead of boot to pass on /chosen/bootargs
- add via82cxxx and via-rhine for pegasos
- more perl modules
* Wed Aug  3 2005 snwint@suse.de
- pcmcia no longer exists
* Tue Aug  2 2005 snwint@suse.de
- no smbmount-diet
* Mon Aug  1 2005 snwint@suse.de
- added perl-Compress-Zlib
* Fri Jul 29 2005 snwint@suse.de
- removed yast2-storage-evms
- introduce instsys build id
* Tue Jul 26 2005 snwint@suse.de
- use the new image[32/64bit] syntax in yaboot.conf, offer also slp and rescue option
- mkbootdisk can now handle usb keys
- added efont
* Mon Jul 18 2005 snwint@suse.de
- new yast2 packages
* Thu Jul 14 2005 snwint@suse.de
- 64 bit glib2 issue fixed
* Wed Jul 13 2005 snwint@suse.de
- cnages for install-initrd
* Mon Jul 11 2005 snwint@suse.de
- prepared install-initrd package spinoff
- needeforbuild fixed
* Mon Jul 11 2005 snwint@suse.de
- a bit more perl stuff
* Mon Jul 11 2005 snwint@suse.de
- adjust to recent package changes
- new modules
* Thu Jul  7 2005 snwint@suse.de
- check libs in initrd
- mkbootdisk fixed
- package deps fixed
- more yast2 perl stuff added
* Wed Jul  6 2005 snwint@suse.de
- libhd is in /usr/lib again
* Mon Jul  4 2005 snwint@suse.de
- libbz2 moved
* Tue Jun 28 2005 snwint@suse.de
- use %%{buildroot}
* Mon Jun 27 2005 snwint@suse.de
- libsysfs is now in /lib
- lsusb is now in /usr/sbin
- don't pack initviocons on s390* (serves no purpose and is potentially
  harmful, bug#91029)
- indic font names changed
- evmsn now in /usr
* Wed Jun 15 2005 snwint@suse.de
- do not overwrite resolv.conf in inst_setup_ssh
- always set hosthame to Hostname or IP from install.inf in inst_setup,
  moved from inst_setup_ssh (part of#86203)
- create an CD1/install32 for older RS6K
- use ip instead of ifconfig to show active network interfaces during ssh installation
- keep the ifcfg-eth-id-* file in the installed system during a ssh/vnc/remoteX installation (#74329)
- adjusted to udev package split
* Tue May 31 2005 snwint@suse.de
- pass chrp instead of chrp64 to mkzimage
- hotplug now works
- removed inst-sys modules
- startup script cleanups
- made passwd working
* Fri May 27 2005 snwint@suse.de
- process the /proc/mounts output reverse when umounting inst-sys
- fix long standing bug in inst_setup_ssh, files go to /etc/ssh, not /etc
- set root password always, so inst_setup_ssh can run at any time (#85617)
- be less verbose in inst_setup_ssh, remove destination files before copying
- better /etc/profile
- start dbus & hal
- added hal to rescue system
- some cleanups
* Tue May 24 2005 snwint@suse.de
- more hal preparations
- add /sbin/lsprop to root image
- start sshd during vnc install, but keep the vnc install mode (#45127)
- remove check for s390 specific /etc/netsetup.inf, linuxrc writes now install.inf
- keep /etc/fstab in inst-sys, only yast1 did not like it
- mode 1777 for / is too open for sshd, change it to 755
* Mon May 23 2005 snwint@suse.de
- remove install=slp nosshkey from pmac yaboot.conf, this has to go the bootiso
- reorder autoload section, or some modules cant be loaded
- module autoload does not resolve dependencies, load nls_base manually
- quote Forth stuff in os-chooser properly
- remove printf in os-chooser, it wont appear anyway
- added ModeSetClearScreen option to xorg.conf file (#80333)
- pata_pdc2027x for pseries (#82638)
- rescue system uses modules from initrd
- added hal to inst-sys
* Thu May 19 2005 snwint@suse.de
- removed BusID from xorg.conf (#78950)
- use new mkzimage wrapper in bin/mk_ppc_installation-images_bootbinaries.sh
- fbset moved from /usr/sbin to /sbin
- add isofs to initrd, if available. autoload it
- i810_drv.o is only available on i386/x86_64
- set not only system time, also hardware clock.
  otherwise time will be incorrect again at the next occasion
- add sysfs and usbfs to fstab, remove / entry
- lpfcdd is now lpfc
- pmac cant have a boot file larger than 4Mb, so use yaboot install of installpmac*
- strip vmlinux32 and vmlinux64 kernels to load images faster
- add default cmdline to PReP images
- readd sym53c8xx driver to ppc
* Mon May  9 2005 ro@suse.de
- increase ramdisk_size in syslinux.cfg
* Fri Apr 29 2005 snwint@suse.de
- talk about SLES10 in CD1/yaboot.txt
- blocxx & libelf
* Fri Apr 22 2005 snwint@suse.de
- latest ia64 patch got lost, readded
* Fri Apr 22 2005 snwint@suse.de
- s390 build fix
* Tue Apr 19 2005 schwab@suse.de
- Increase initial rescue image size.
- Add libunwind on ia64.
- Don't add fdisk on ia64.
* Tue Apr 19 2005 schwab@suse.de
- Add ia32el to nfb.
- Start ia32el during installation and in rescue system.
* Wed Apr 13 2005 snwint@suse.de
- xorg.conf fix for 64 bit archs
* Wed Apr 13 2005 snwint@suse.de
- XF86Config -> xorg.conf (#66989)
- write static net variables only if it really is a static
  setup (#64131)
- some packages have been split
* Fri Apr  1 2005 uli@suse.de
- build rescue system for s390*
- added cpint.ko to initrd for s390*
- inittab can only handle 4 chars as 'id' field, but a console
  device name can be longer than that. Use /dev/console and 'cons'
  instead. Also handle TERM= passed on cmdline properly (#73814)
- add missing initviocons binary to help with terminal detection
* Wed Mar 23 2005 schwab@suse.de
- Fix syntax error in boot.local.
* Wed Mar 23 2005 snwint@suse.de
- really use suse sans font
* Tue Mar 22 2005 adrian@suse.de
- revert to suse sans font to workaround problems with asian fonts
* Sat Mar 19 2005 snwint@suse.de
- handle fully modular nls and cd drivers
- add st and rtas_flash for pseries
- enable hfs and hfsplus
- removed 'manual' from fallback message
* Fri Mar 18 2005 snwint@suse.de
- README updated (#66710)
* Thu Mar 17 2005 snwint@suse.de
- added missing zen files
* Wed Mar 16 2005 snwint@suse.de
- removed LC_CTYPE from /etc/profile (#72145)
- create_interface fix (#72903)
- fix fonts for japanese
* Mon Mar 14 2005 snwint@suse.de
- adjusted neededforbuild
* Mon Mar 14 2005 snwint@suse.de
- added crypto modules (#71766)
- umount install source in inst_setup
- adjusted yast mem limits (#71989)
- added acpi modules
- added japanese font
- added ntfs module to rescue system (#72280)
- fixed syntax error in data/rescue/etc/init.d/boot.local (#71759)
- merge kernel-pseries64+kernel-pmac64 into kernel-ppc64 (#72344)
* Fri Mar 11 2005 schwab@suse.de
- Fix syntax error in boot.local.
* Tue Mar  8 2005 snwint@suse.de
- added cifs-mount to neededforbuild
- lilo exists on amd64, too
* Mon Mar  7 2005 snwint@suse.de
- added Zen stuff from 9.2
- build additional root image for asian fonts
- bring rescue system in shape for s390*
- updated modules list
- added yast2-trans-pt
* Mon Feb 28 2005 snwint@suse.de
- added punjabi
- initrd: dynamic linker was missing on some archs
- indic fonts moved
- load ahci before ata_piix
* Mon Feb 21 2005 snwint@suse.de
- hwinfo needs libiw
* Mon Feb 21 2005 snwint@suse.de
- use initramfs
- added yast2-trans-stats
- use indic-fonts
* Thu Feb 17 2005 snwint@suse.de
- use cifs instead of samba
- add some libs to initrd, as linuxrc is no longer statically linked
* Wed Feb 16 2005 snwint@suse.de
- fixed font cache creation
* Mon Feb 14 2005 snwint@suse.de
- replace cd2 boot image
- add exportfs to rescue (#50687)
* Thu Feb 10 2005 snwint@suse.de
- support agfa fonts
* Tue Feb  8 2005 snwint@suse.de
- support ukrainian
- boot with 'quiet' option on ppc
- removed minix test from check-build.sh
* Mon Feb  7 2005 snwint@suse.de
- fixed pcmcia module config
- more perl modules
* Wed Feb  2 2005 snwint@suse.de
- added perl-Bootloader
* Wed Feb  2 2005 snwint@suse.de
- another perl module added
* Tue Feb  1 2005 snwint@suse.de
- added ide modules
- take *-nongpl into account
* Mon Jan 31 2005 snwint@suse.de
- added perl modules for yast
- libmagic is in /lib64
- new modules
- fixed some shared lib dependencies
- adapted to new boot graphics
- removed SuSE-Home theme
* Mon Jan 24 2005 snwint@suse.de
- improved mkbootdisk script
- module info updated
- allow empty root pw in rescue system (#49907)
* Tue Jan 11 2005 snwint@suse.de
- added libmagic
- strip X.org modules
- drop X.org glx modules
* Mon Dec 20 2004 snwint@suse.de
- boot disks are gone (#48962)
* Mon Nov 22 2004 snwint@suse.de
- use krb5 instead of heimdal-lib
* Thu Nov 18 2004 ro@suse.de
- use kerberos-devel-packages
* Tue Nov  9 2004 snwint@suse.de
- s390: added /sbin/dasdview (bug#42986)
- fix module dependencies (reverse loading order) (#47909)
- turn off automatic module disk requests when we boot from CD (it
  is pointless anyway) (#47909,#46809)
- no module disks
- new yast startup concept (#46886)
* Fri Oct  8 2004 snwint@suse.de
- added norwegian translations
* Tue Oct  5 2004 snwint@suse.de
- don't set lower_zone_protection (#46535)
- mount root image from CD if mem less about 350MB (#46535)
* Tue Oct  5 2004 snwint@suse.de
- set lower_zone_protection & local-oom-kill (#46535)
* Fri Oct  1 2004 snwint@suse.de
- added yast2-trans-zh_TW
- new sata driver
* Mon Sep 27 2004 snwint@suse.de
- s390: added some scripts removed from initrd to root image
- added hebrew yast translations
* Tue Sep 21 2004 snwint@suse.de
- qt package changes (#44803)
- added dmraid
* Mon Sep 20 2004 snwint@suse.de
- made cd2 boot image small enough
* Fri Sep 17 2004 snwint@suse.de
- more failsafe options
- libnscd added
- fbiterm added
* Mon Sep 13 2004 snwint@suse.de
- creating kernel modules 'updated' link (#44740)
- removed /sbin/quick_* (#45106)
- use linuxrc specific fonts
- syslinux has moved
* Thu Sep  2 2004 snwint@suse.de
- handle sparse files (#44603)
* Wed Sep  1 2004 snwint@suse.de
- libhd is in /lib
* Mon Aug 30 2004 snwint@suse.de
- removed the evil parallel universe of s390 installation; rejoice!
- fixed the generic stuff to be s390-safe
- module disks are back
- more yast translations
- added card reader libs (ssh needs them)
* Mon Aug 23 2004 snwint@suse.de
- changed keyboard section in XF86Config (#43899)
- added basic nls modules (#44080)
- added arabic & begali fonts
* Mon Aug 16 2004 snwint@suse.de
- add usbhid (#43764)
- old initrd fonts are back
* Tue Aug 10 2004 snwint@suse.de
- dropped module disks; modules are integrated into boot disks
* Mon Aug  9 2004 snwint@suse.de
- support 32+64bit dual boot
- x86_64: rename root,rescue,inst-sys --> root64,rescue64,instsys64
* Fri Aug  6 2004 snwint@suse.de
- set root_i18n & root_gfx env vars to include them to the inst-sys
- add machbunt.file_list and rooti18n.file_list
  to split the inst-sys into smaller parts for
  small memory configurations
- s390: eliminate invalid check for qeth data channel (bug#42538)
- new modules
- dropped legacy cdrom modules
- moved to utf8 for linuxrc
* Mon Aug  2 2004 olh@suse.de
- add new packs to neededforbuild:
  evms-gui hotplug kbd multipath-tools sax2 terminfo yast2-trans-pl
  remove packs from neededforbuild:
  inetd
* Tue Jul  6 2004 snwint@suse.de
- fvwmrc.notitle now fvwmrc.yast2, taken from sax2.rpm (#36488)
- joined changes up to 5.75 from 9.1 branch:
- SMB install does not work (#38777)
- added barrier=off to failsafe (#42526)
- s390: netsetup: fixed autocorrection of qeth channels (bug#42538)
- no memory check for NLD (#42310)
- ia64: XF86Config changes (#42237,#41764)
- ia64: add all XFree86 drivers (#42237)
- added SuSE-NLD theme
- added evms, evms-gui to rescue system (#42384)
- ppc only: added the necessary parts of "hotplug" to load
  updated firmware images to the IPR controller via iprconfig.
  (LTC#9506 / SUSE#42300)
- added hvsi* to rescue console / gettys. (requested by IBM)
- added megaraid-old
- fix ifcfg filename for ctc and lcs devices (#42329)
- create a CD1/suseboot/os-chooser file for PowerMac to load
  either 32bit or 64bit kernel, yaboot is shit. (#42070)
- create_interface: use by-bus naming for qeth/hsi (bug#38819)
- add /lib/lilo/chrp/mkzimage_cmdline to CD1/ppc/netboot
- add terminfo file for ibm3151
- use all terminfo files from ncurses in rescue system
- remove /sbin/activate on ppc, its gone
- save a few bytes by making symlinks to hfsutils binary
- add 'other' module section to module.config on ppc (#41195)
- added polish texts (#41598)
- s390: initrd: added dasd_reload, removed libvtoc (now static)
- build only one initrd for ppc32, use pmac64 for G5
- s390: add /sbin/hcp to root image (bug#38817)
- remove usr/bin/ppc_post_install.sh, it was yast1 code
- minor module config & driver update fixes
- write yast mem limit only once to linuxrc.config; lowered it a bit
- added multipath-tools (#40640)
- changed driver update handling to match the new linuxrc
- s390: netsetup: print the product string correctly (bug#40121,
  this time for real)
- add ibm3151 terminfo file
- ensure passwords do not expire; added passwd (#41180)
- some modules were added twice to initrd
- fixed module config
- use cool new product name
- s390: change memory requirements according to test results
- update comment for ibmveth
- fixed typo in LIESMICH
- applied create_interface patch from#39401#c5
- added megaide (#39570)
- xfsdump has moved
- fixed some dangling symlinks
- add pcnet32 and acenic for chrp, fix typo in yaboot.conf
- copy initrd files fo i/p to sles cd1
- fixed typo in module config
- s390: netsetup: fix up parameters passed via READ/WRITE_DEVNO
- s390: netsetup: added LCS fixes by Mark Ver (bug#40097)
- add ibmveth, iseries_veth
- reworked module disk#1
- add /sbin/hotplug, drop remove events (#39109,#39894)
- drop udev.permissions from inst-sys
- minor module config fixes
- added memtest to boot disk
- s390: netsetup: use /linuxrc.config instead of /etc/SuSE-release
  (bug#40121)
- inst_setup_ssh: run with -n if not booted with nosshkey
- fixed .timestamp creation
- s390: netsetup: construct welcome msg from /etc/SuSE-release
  (bug#40121)
- add descriptions to elilo.conf entries
- write min memory requirement to linuxrc.config
- autoload loop.ko and unix.ko, if available
- add nv_drv.o to inst-sys for ppc (#39767)
- add vga_drv.o to inst-sys only for i386, x86_64 and ia64 (#39767)
- use real install file for pmac64
- set system time to inst-sys built time, for gpg key. part of (#28688)
- start a shell if /.start_shell exists, instead of just grepping
  in /proc/cmdline. gives yast a chance to touch this file after a crash (#33087)
- add dm-*.ko to initrd on i386, too
- put boot files for ppc on CD1
- autoload floppy driver (to give amd64 a chance to use driver
  update floppies)
- modules: +megaraid_mm, -xfs_dmapi
- enable memtest for x86_64
- desktop-data-SuSE -> *-SLES
- s390: round up detected memory size (bug#39504)
- s390: netsetup: cosmetic fixes
- s390: added dasdro script to initrd
- handle fractional kernel release numbers
- s390: better gateway default (bug#38895)
- added e100-intel
- minor s390* fixes
- rescue system: mount /sys (#38933), mount usbfs,
  start device-mapper (#38990)
- add ibmvscsis vscsi server for pseries
- add /etc/shadow to the file list for S/390
- added card bus modules to network module list (#36572)
- Fixed netsetup to not sleep for qeth deviced (#38816).
  Using correct path for statistics in netsetup.
- add CD2/suseboot to trigger the HFS part,
  avoid 8.3 filenames and allow OF booting
- /lib/modules/<kernel>/extras -> extra/ibmsis
- add sgiioc4 module (#38628)
- support SGI XPNET (#35867)
- no rpc.statd
- no error if module config mentions nonexistent modules
* Sat Apr 24 2004 sndirsch@suse.de
- installation-images-5.40.diff:
  XFree86 --> xorg-x11 package renaming
- fixed neededforbuild (saxident/saxtools --> sax2-ident/sax2-tools)
* Thu Apr  8 2004 snwint@suse.de
- support SuSE-SLES theme
* Tue Apr  6 2004 snwint@suse.de
- added bootsplash-theme-SuSE-Home to neededforbuild
* Mon Apr  5 2004 snwint@suse.de
- increased boot timeout to 20s (#38252)
- lowered YaST memory limit, YaST checks itself (#38298)
* Sat Apr  3 2004 snwint@suse.de
- adjusted YaST memory limits (#34537)
* Sat Apr  3 2004 snwint@suse.de
- added dm-* modules (#37289)
- added iprutils for ppc to rescue
- added /sbin/raiddetect (#36157)
* Fri Apr  2 2004 snwint@suse.de
- s390: make memory sanity check more dynamic (bug#21606)
- s390: netsetup: accept spaces in QETH channel list (bug#37058)
- add ipr to iseries initrd
- add more dm-* modules to ppc initrds
- added getcfg & create_interface (#35624)
- updated README/LIESMICH
- add arch info to isolinux.cfg
- don't build DVD2
* Thu Apr  1 2004 uli@suse.de
- s390: added initrd size to suse.ins*
* Wed Mar 31 2004 snwint@suse.de
- add icom serial driver to iseries initrd
- s390: added missing files from s390-tools
- s390: netsetup: NETIUCV is now netiucv (bug#37092)
- s390: added lotsa perl stuff for YaST disk dialogs (bug#37068)
- s390: added missing sshd user/group (bug#37056)
- added more dm-* modules
- make boot cd2 image build
* Mon Mar 29 2004 snwint@suse.de
- added pmtools (#36818)
- changed sshd message (#36928)
- use linemode on ppc (#35826)
- japanese keyboard (#31417)
- added setctsid, showconsole, FvwmCommand
- added sata_sis.ko, edd.ko
- removed xpenguins from neededforbuild
* Sun Mar 28 2004 olh@suse.de
- do not strip the files, keeps the ELF files intact
* Thu Mar 25 2004 uli@suse.de
- use different suse.ins files for s390x (bug#36145)
* Wed Mar 24 2004 snwint@suse.de
- fvwmrc now fvwmrc.notitle again
- suppress syslogd warning
- another libwrap fix
* Tue Mar 23 2004 adrian@suse.de
- fix slp anouncement of VNC installation
  (patch also commited to cvs)
* Tue Mar 23 2004 snwint@suse.de
- temporarily renamed fvwmrc.notitle to fvwmrc
* Tue Mar 23 2004 snwint@suse.de
- added NoTitle to fvwmrc (#36488)
- don't use kdebase3-*
- using udev as hotplug helper
- replace tg3 with bcm5700 on pseries
- libwrap & libsysfs have moved
* Tue Mar 23 2004 nashif@suse.de
- remove yast2-theme-UnitedLinux
* Mon Mar 22 2004 snwint@suse.de
- more space in rescue system
- use freefont
- new modules
- s390: fix linuxrc automatic setup parameters (bug#36237)
- s390: cosmetic fix for halt script
- s390: add missing procps binaries
- s390: add 64-bit suse.ins.* files that do not mention S/390 (bug#36145)
- s390: netsetup: add "NetConfig: static" to install.inf (bug#36252)
- s390: (lukem)ftp _is_ needed
* Thu Mar 18 2004 schwab@suse.de
- Leave more space in rescue fs.
* Wed Mar 17 2004 snwint@suse.de
- check-build.sh got lost
* Wed Mar 17 2004 snwint@suse.de
- new modules
- removed UL references
- fixed rescue system
* Tue Mar 16 2004 snwint@suse.de
- support sles9
* Mon Mar 15 2004 snwint@suse.de
- added sata_vsc
- s390: fixed missing NS problem (bug#35812)
- add usb and firewire to old pmac initrds, remove xfs and jfs from coff initrd
- s390: do not delete modules.dep and friends
- add /etc/sysconfig, /etc/sysconfig/hardware to initrd
- s390: add missing libnss*, basename, modprobe to initrd
- s390: add missing /etc/passwd, /etc/group to initrd
- s390: mount/unmount with -n in linuxrc
- s390: unmount sysfs in linuxrc.finish
- s390: netsetup: fix memory detection
- s390: netsetup: don't show obsolete /proc/chandev options
- s390: ditch LCS license
- s390: netsetup: fix qeth, iucv setup
- s390: netsetup: minor fixes
- add /lib/modules/<version>/extras to kernel module search list
  needed for ibmsis
* Wed Mar 10 2004 snwint@suse.de
- make slpd start
- disable udev
* Wed Mar 10 2004 snwint@suse.de
- s390: new netsetup
* Wed Mar 10 2004 snwint@suse.de
- added vesa driver (x86-like archs only)
- added vesa-section to XF86Config
- larger root image
- fixed#neededforbuild
- s390: create_interface fixed
- no kdebase3-Home yet
- amd64 has a floppy module
- ia64: no fpswa_check_version
* Mon Mar  8 2004 snwint@suse.de
- added udp-receiver
- made cd2 boot image small enough
- add modules.pcimap to initrd
* Mon Mar  8 2004 snwint@suse.de
- new Crystalcursors (crystalwhite) mouse cursor theme
- add yast2-s390
* Mon Mar  8 2004 olh@suse.de
- build Home theme only on intel to reduce build time
* Sun Mar  7 2004 olh@suse.de
- add evms and screen
  build rescue as cramfs to avoid sizing problems
* Sun Mar  7 2004 olaf@suse.de
- add libXxf86vm.so, libmenu.so
- add hfs, hfs+ on ppc
- add /etc/bash.bashrc to ignore history dups
- run udevstart early and reconnect console fd
- add udev to rescue
- added evms
- .bash_login: exit early on system console
- typo in ppc/bootinfo.txt (#35176)
* Thu Mar  4 2004 snwint@suse.de
- libkafs for s390
- build uml initrd
* Tue Mar  2 2004 snwint@suse.de
- use SUSE Sans fonts
- use thinkeramik as default widget set
- added Home theme
* Mon Mar  1 2004 snwint@suse.de
- add kernel/drivers/base/ to search list
- add firmware_class to list of know modules
- add dm-mod, dm-crypt and raid6 on ppc
- remove RhostsAuthentication from sshd_config
- ready for pre-4
* Fri Feb 27 2004 snwint@suse.de
- add gen/module.files.autoload for ppc initrds
- bk: s390 fixes
* Mon Feb 23 2004 snwint@suse.de
- ready for pre-3
* Sun Feb 22 2004 olh@suse.de
- add bin/mk_ppc_installation-images_bootbinaries.sh
- update pseries64 initrd content, all scsi stuff is a module now
- create /lib/modules/<version> if it does not exist
* Wed Feb 18 2004 uli@suse.de
- s390: new hardware configuration format for install.inf
* Wed Feb 18 2004 schwab@suse.de
- Add relocatable tag to elilo.conf.
* Tue Feb 17 2004 adrian@suse.de
- anounce VNC sessions via SLP
* Mon Feb 16 2004 snwint@suse.de
- added yast2-runlevel
- add /usr/bin/stat to instsys on ppc
- fixed module setup in inst_setup
* Sun Feb 15 2004 olh@suse.de
- add gdb for the time being
  ps was splitted into procinfo, procps and psmisc
  build initrd for pmac64_32bit
* Fri Feb 13 2004 olh@suse.de
- add small initrd images for ppc:
  ppc_pmac_new ppc_pmac_miboot ppc_pmac_coff ppc_chrp ppc_prep
  ppc_power3 ppc_pseries64 ppc_iseries64
* Wed Feb 11 2004 snwint@suse.de
- more libwrap things
- added new modules
- added libgcc to rescue system
* Tue Feb 10 2004 uli@suse.de
- added libwrap missing on s390*
- rescue: files for lilo on ppc moved to /lib/lilo
- remove /sbin/clock on ppc
* Tue Feb 10 2004 uli@suse.de
- clean up after Mr. olh
* Tue Feb 10 2004 olh@suse.de
- build initrds for kernel-pseries64 kernel-iseries64 kernel-power3
* Mon Feb  9 2004 snwint@suse.de
- lvm -> lvm2
- some module fixes
- added scsi package to rescue system (#34384)
* Wed Feb  4 2004 uli@suse.de
- s390 adaptions for 2.6 kernels (no rdripl, no LICENSE.OCO,
  no mkdevs, kernel name)
* Tue Feb  3 2004 snwint@suse.de
- add package list to inst-sys
- some 2.6 module cleanup
- added yast2-tune
* Sat Jan 31 2004 arvin@suse.de
- fixed neededforbuild (kernel is called kernel-default)
* Fri Jan 30 2004 snwint@suse.de
- conservative_lndir no longer needed, linuxrc does it
- make it actually boot SL 9.1
* Sat Jan 24 2004 ro@suse.de
- package rename: shadow -> pwdutils
- package rename: modutils -> module-init-tools
* Thu Jan  8 2004 snwint@suse.de
- fixed spec file typo
* Mon Jan  5 2004 schwab@suse.de
- Fix creation of boot image.
- Increas rescue image size.
* Tue Dec 16 2003 snwint@suse.de
- minor boot disk fix
* Tue Dec 16 2003 snwint@suse.de
- switch ADB keyboards to linuxkeycodes
- new boot disk layout
* Mon Dec  8 2003 schwab@suse.de
- Fix location of elilo.efi.
* Tue Nov 18 2003 snwint@suse.de
- LiveEval changes
- moved to kernel 2.6
- no CD2 boot image
- for now no boot & module disks
* Wed Nov  5 2003 snwint@suse.de
- renamed config-dist.sh to check-build.sh
* Sun Nov  2 2003 ro@suse.de
- removed XFree86-compat-libs (deleted package)
* Thu Oct 23 2003 schwab@suse.de
- Add mingetty to rescue.
* Thu Oct 23 2003 schwab@suse.de
- No libdb in glibc any more.
- Add librtkaio.so.1 to root.
* Tue Oct  7 2003 ro@suse.de
- removed xfiregl1, xfiregl23
* Wed Sep 24 2003 snwint@suse.de
- drop boot & module disk README on x86_64
* Tue Sep 23 2003 snwint@suse.de
- fixed cut-and-paste-programming error in create_interface (#31455)
- do not touch resolv.conf and defaultdomain on update (#30672)
* Tue Sep 23 2003 snwint@suse.de
- SuSE-DVD theme for x86_64
* Fri Sep 19 2003 snwint@suse.de
- keep module list sorted
* Thu Sep 18 2003 snwint@suse.de
- support 9.0
* Wed Sep 17 2003 snwint@suse.de
- don't use freefont
- new sata module
- added xrefresh
- try to avoid 'syslogd terminated' message (#30944)
* Mon Sep 15 2003 snwint@suse.de
- moved floppy & cdrom dir to /media (#30728)
- splash=silent needed in syslinux.cfg (as a result of#28780)
- give x86_64 people some keymaps (#30458)
- added testutf8
- create_interface should set DHCLIENT_SET_HOSTNAME to yes (#30528)
* Wed Sep 10 2003 snwint@suse.de
- added smartmontools to neededforbuild
* Wed Sep 10 2003 snwint@suse.de
- fixed bootdisk (knew nothing about scsi mods)
- added sata driver
- sorted module lists
- enable pcmcia on x86_64 (#30153)
- CD3 no longer bootable
* Tue Sep  9 2003 snwint@suse.de
- use blueprint cursor theme
* Tue Sep  9 2003 snwint@suse.de
- added setfont (got accidentally lost)
* Mon Sep  8 2003 snwint@suse.de
- added VGAClocks option to XF86Config (#30038)
- mfabian: some font config changes
* Sat Sep  6 2003 snwint@suse.de
- mfabian: fixed some utf8 things in fvwmrc
* Sat Sep  6 2003 snwint@suse.de
- remove setfont wrapper script
- adapted splash mode resolution list
- apply driver updates in inst_setup (used to be in YaST2.start)
* Wed Sep  3 2003 snwint@suse.de
- no boot disks for x86_64
* Thu Aug 28 2003 adrian@suse.de
- Bitstream Vera fonts do not support all latin chars, so we
  can not use it as default :/ (#29308)
* Wed Aug 27 2003 ro@suse.de
- remove traceroute-lbl from neededforbuild (unused)
* Mon Aug 25 2003 snwint@suse.de
- added smartmontools to rescue system (#26414)
- build special SuSE-DVD theme
- make CD3 bootable for beta tests (simulates DVD2)
* Thu Aug 21 2003 snwint@suse.de
- better kernel rpm handling
* Wed Aug 20 2003 snwint@suse.de
- fixed device compression
* Tue Aug 19 2003 snwint@suse.de
- we missed the bootlogo
* Mon Aug 18 2003 ro@suse.de
- removed gfxboot-devel from neededforbuild
* Mon Aug 18 2003 snwint@suse.de
- fixed locale-archive
- splash script usage changed
- adapted to new gfxboot package
- s390: qeth is GPL now, do not show OCO license when loading it
* Thu Aug 14 2003 adrian@suse.de
- activate Bitstream fonts again
* Mon Aug 11 2003 snwint@suse.de
- kernel module issues
- sysrq key enabled in rescue system
* Fri Aug  8 2003 snwint@suse.de
- new kernel, new modules
* Thu Aug  7 2003 snwint@suse.de
- added dhcp client to rescue system
- some s390 things
- added ntfsprogs
* Fri Aug  1 2003 snwint@suse.de
- didn't catch all build errors
- make s390 happy
* Fri Aug  1 2003 snwint@suse.de
- kbd package changes
* Thu Jul 31 2003 ro@suse.de
- yast2-network-instsys has been deleted
* Fri Jul 25 2003 snwint@suse.de
- added glx to XFree config
* Thu Jul 24 2003 snwint@suse.de
- added perl & unicode things
* Wed Jul 23 2003 snwint@suse.de
- added libncursesw
* Fri Jul 18 2003 snwint@suse.de
- use kernel pcmcia
- call it 9.0
- include full dev tree, not the one from mkdevs.floppy
* Tue Jul 15 2003 snwint@suse.de
- added bzip2 to rescue system (#27896)
- compress /dev tree
- catch up with latest kernel & package changes
* Mon Jun 23 2003 ro@suse.de
- remove krb4-lib (package dropped)
* Mon Jun 16 2003 snwint@suse.de
- minor package fixes
- fixed locale building
- ensure loop devices are freed on build errors
* Tue May 27 2003 snwint@suse.de
- kernel rpm fixes
- lib fixes
* Tue May 20 2003 ro@suse.de
- rename vnc -> tightvnc, add XFree86-Xvnc
* Thu Apr 24 2003 snwint@suse.de
- use setxkbmap
- integrated 8.2 live eval changes
- adapted to recent package changes
* Wed Apr  9 2003 ro@suse.de
- fixed deprecated head/tail calling syntax (-1)
* Tue Apr  1 2003 ro@suse.de
- fix build without dropped mesasoft/mesaglu packages
* Fri Mar 21 2003 snwint@suse.de
- ignore minor errors
* Thu Mar 20 2003 ro@suse.de
- merge changes from olh:
- add scsi to neededforbuild
- add installation-images-kernel_modules.patch
* Mon Mar 17 2003 ro@suse.de
- added module info for qla2100
* Mon Mar 17 2003 snwint@suse.de
- added symlinks for samba (#25411)
* Thu Mar 13 2003 snwint@suse.de
- updated list of yast2 translation packages (#25157)
* Wed Mar 12 2003 snwint@suse.de
- support 8.2
* Tue Mar 11 2003 snwint@suse.de
- added sungem_phy to module config
- added ide raid mods to inst-sys (#25098)
- added mdadm
- ide_cs seems to be now ide-cs
* Mon Mar 10 2003 snwint@suse.de
- Create root64 image for UltraSPARC
* Mon Mar 10 2003 snwint@suse.de
- fixed some arch issues
* Sat Mar  8 2003 snwint@suse.de
- errors are no longer ignored
- add samba support only on CD1
* Sat Mar  8 2003 snwint@suse.de
- putting cd related modules back (#24709)
* Fri Mar  7 2003 snwint@suse.de
- build splashs without silent image to reduce size (#24750)
- put only a limited number of splash images on cd2 (#24750)
- run /bin/initviocons in .bash_login (#24728)
- removed all xfree drivers but fbdev, vga and vmware (#24623)
* Fri Mar  7 2003 snwint@suse.de
- don't put cd related modules into initrd (#24709)
- changed boot loader menu texts
- speed up things by building /dev dir only once
* Tue Mar  4 2003 snwint@suse.de
- fixed lib64 issue in rescue system
- put bootlogo on x86_64 disks
* Tue Mar  4 2003 snwint@suse.de
- fixed text mode boot message (#24600)
- /etc/font.config has moved
- added /etc/hosts with localhost entry (#22207)
- floppy message file should not mention memtest
* Mon Mar  3 2003 snwint@suse.de
- added ips_old module
- more splash sizes
- fixed klogd startup
* Sat Mar  1 2003 snwint@suse.de
- remove module.conf after yast2 exits
- don't include libfreetype.so (not needed)
- take boot loader splash from gfxboot package
- added 1600x1200 splash
* Mon Feb 24 2003 snwint@suse.de
- added fdisk (#23864)
* Mon Feb 24 2003 adrian@suse.de
- use Bitstream Vera fonts, if avaible
* Mon Feb 24 2003 snwint@suse.de
- updated module config
- added alias file to locale database (#23348)
- added .old modutils to rescue system (#24017)
* Tue Feb 18 2003 snwint@suse.de
- libresmgr moved to /lib
- new splash code: (splash files are no longer added to initrd,
  * .spl files are used instead) - needs updated syslinux package!
* Mon Feb 17 2003 snwint@suse.de
- more font fixes
- split scsi modules disk
* Thu Feb 13 2003 adrian@suse.de
- fix unicode meta data
- ensure correct time stamps
- drop qt mng plugin
- move perl out of root image
* Thu Feb 13 2003 adrian@suse.de
- fix font meta data
- add ntfsprogs to rescue system
* Wed Feb 12 2003 adrian@suse.de
- fix path to X11 freetype module
* Wed Feb 12 2003 ro@suse.de
- added ghostscript-fonts-std to neededforbuild
* Wed Feb 12 2003 snwint@suse.de
- new fonts stuff
- some module config updates
- temporarily added perl to inst-sys
* Tue Feb 11 2003 snwint@suse.de
- temporarily removed some scsi mods to make it build
* Mon Feb 10 2003 snwint@suse.de
- adapted to new graphics boot code
* Mon Feb 10 2003 ro@suse.de
- build with coreutils
* Wed Feb  5 2003 snwint@suse.de
- new fvwmrc
* Tue Feb  4 2003 snwint@suse.de
- added star to rescue system
- added sock to inst-sys
- qt3 fixes
* Mon Feb  3 2003 snwint@suse.de
- added glibc locale
* Wed Jan 29 2003 snwint@suse.de
- added some libs
- new fvwmrc
* Mon Jan 20 2003 snwint@suse.de
- boot menu changes
- added fvwm2
* Fri Jan 17 2003 ro@suse.de
- skip umsprogs
* Tue Jan 14 2003 snwint@suse.de
- added new network modules
* Mon Jan 13 2003 snwint@suse.de
- knows about libgdbm_compat
- added sysconfig.keyboard
* Thu Jan  9 2003 snwint@suse.de
- acl & attr package split
- depmod.old etc.
- dropped glibc locale (#22161)
* Thu Nov 28 2002 snwint@suse.de
- better theme handling
* Wed Nov 27 2002 snwint@suse.de
- really added OpenXchange theme
- add scsidev to rescue image (#20490)
- check entered machine and path for ftp-installation (#20792)
- MTU-is only written to parameterfile if != 0 (#21119)
- autoinstall does now work (#21200)
- portmapper is killed before linuxrc is called (#18461)
- fixed labeling of product in suse.ins files (#21202)
- fixed typo in linuxrc					#21465
- fixed endlessloop if AUTOINSTALL was set and no
  medium was selected.
- fixed login behaviour (second getty)    (s390/s390x)#20780
- fixed error handling of lcs-device      (s390/s390x)#21558
- fixed error handling of wrong parameter (s390/s390x)#21587
- fixed permissions for .netrc. Otherwise ftp
  is not executing the script.			(s390/s390x)#21296
- removed warning if valid default is accepted (s390/s390x)#21557
- added xfs_repair to rescue system (#21671)
- fixed qla* module info (#21567)
- merged 8.1 tree
- new config file
- aaa_version no longer needed
* Mon Nov 25 2002 ro@suse.de
- added patch for XFree86 package rename
- removed XFree86-3x packages from neededforbuild (used nowhere)
- still needs work with expat/fontconfig/db3
* Sun Nov 24 2002 sndirsch@suse.de
- adjusted#neededforbuild according to the XFree86 package rename
* Sat Nov  9 2002 olh@suse.de
- check for loop mount in $BUILD_ROOT, not in /tmp
* Wed Oct 23 2002 ro@suse.de
- added aaa_version to neededforbuild (make it build for now)
* Thu Oct 17 2002 ro@suse.de
- added bootsplash-theme-OpenXchange
- only build themes needed for distribution
  (SuSE only on 8.1, UL only on UL, rest on SLES)
- build rescue image once, no matter what themes are built
* Tue Oct 15 2002 snwint@suse.de
- fixing PAM error-messages (only s390/s390x)#18456,#20121,#20893
- check valid VNC-password length (only s390/s390x)#20884
- fixing segfaulting VNC on s390x (only s390x)#20403
- enabling telnet for installation (only s390/s390x)#20708,#20790, 20789
- fixing generation of /etc/resolv.conf (s390/s390x/all arch for installation via VNC, SSH)#20697,#19738
* Mon Oct 14 2002 snwint@suse.de
- make sure crypto module is present in inst-sys (#20606)
* Mon Oct 14 2002 snwint@suse.de
- fixed theme handling (#19442)
- new theme UL-SLES
* Wed Oct  9 2002 snwint@suse.de
- fixed missing traceroutecommand in netsetup   (s390/s390x)#20462
- fixed mising MTU-parameter in interfacefile   (s390/s390x)#20644
- fixed wrong motd                              (s390/s390x)#20404
- fixed mising / in ftp/Samba-path              (s390/s390x)#19967/#20152
* Mon Oct  7 2002 snwint@suse.de
- say "SuSE Linux" unless it's UnitedLinux (#20336)
* Fri Oct  4 2002 olh@suse.de
- disable mk_initrd on ppc
  the initrd is too small now and not used anyway in this package
* Fri Oct  4 2002 olh@suse.de
- add ibmsis to neededforbuild on ppc32 (rescue image) (#20490)
- add vt320 terminfo entry for p690 hvc console (#20494)
- write correct inittab entry for hvc console (#20494)
- be more verbose during inittab modification
* Fri Sep 27 2002 snwint@suse.de
- samba-client package has changed
* Fri Sep 27 2002 snwint@suse.de
- corrected Installation error in linuxrc for s390 (Bug#20245)
- corrected string in linuxrc.config (Bug#19947)
* Thu Sep 26 2002 kukuk@suse.de
- Add bootsplash-theme-SuSE-SLES to neededforbuild
* Thu Sep 26 2002 snwint@suse.de
- bootlogo back on SLES
* Thu Sep 26 2002 snwint@suse.de
- yast uses SL theme on SLES
- fixed bootlogo handling
* Wed Sep 25 2002 snwint@suse.de
- Writing MTU to Devicefile
- added missing sambafile to initrd
- adding necessary parameters for ssh-install
* Wed Sep 25 2002 snwint@suse.de
- support SuSE-SLES theme
* Wed Sep 25 2002 snwint@suse.de
- added sisconfig and respective libraries to ppc rescue
- boot.local for serial console (#19498)
* Wed Sep 25 2002 snwint@suse.de
- don't use cracklib to check passwords (#20121)
* Mon Sep 23 2002 snwint@suse.de
- lower memory limit for loading inst-sys into ramdisk
* Fri Sep 20 2002 snwint@suse.de
- added samba installation support for s390
* Wed Sep 18 2002 snwint@suse.de
- added yast2 translations
- driver updates are looked for in
  linux/UnitedLinux/<arch>-ul1 for UL and
  linux/UnitedLinux/<arch>-sles8 for SLES8 (#19442)
- added activation of network for s390/s390x/i&p-series
* Mon Sep 16 2002 snwint@suse.de
- Removed writing entries in chandev.log in create_interfaces
- Removed bug in netsetup for iucv-Parameters
- Added missing files for samba-client
- changed check for installation media for s390
* Fri Sep 13 2002 snwint@suse.de
- changed parmline for installation boot
- changed create_interface to write entry in
  modules.conf
- fixed y2debug issue (too much logs per default)
* Wed Sep 11 2002 snwint@suse.de
- run linuxrc in linemode on s390
- add uncompressed length after splash
- don't build uncompressed root image
- don't remove /root, second try
* Mon Sep  9 2002 snwint@suse.de
- don't remove /root
* Mon Sep  9 2002 snwint@suse.de
- create a 2.88MB boot image for CD2 (no k_inst)
- updated README/LIESMICH (#19132)
- pcilynx needs i2c mods
- fixed braille support
* Sun Sep  8 2002 snwint@suse.de
- fixed pcmcia cardmanager config (#18311)
- simplify ssh login to inst-sys for debugging
- made cd2 boot image fit
- use k_inst again
* Sat Sep  7 2002 kukuk@suse.de
- Don't include root.uncompressed (except on s390*)
* Sat Sep  7 2002 snwint@suse.de
- no -themes subpackage, theme dependent files are in /SuSE/$theme/
* Fri Sep  6 2002 schwab@suse.de
- ia64: move initrd and kernel image to boot/efi in boot image.
* Fri Sep  6 2002 snwint@suse.de
- no apic on x86_64, now really
- build rescue system on ppc
* Fri Sep  6 2002 snwint@suse.de
- Corrected data/root/etc/create_interface
- new yast2 theme layout
- root image is now theme dependent
* Thu Sep  5 2002 snwint@suse.de
- module config fixed on x86_64
- samba, again (#18963)
- add firewire modules to initrd (#18583)
- new tar.bz2, patches left some empty files
* Thu Sep  5 2002 snwint@suse.de
- modprobe in linuxrc to fix kmod problem
- changed parmfile for kernel (s390)
* Thu Sep  5 2002 snwint@suse.de
- openssh fix & 64bit samba workaround
* Thu Sep  5 2002 snwint@suse.de
- added amd-8111, minor module config fixes
- removed hard coded SL from motd/issue
- added YaST2 UL theme
* Wed Sep  4 2002 bk@suse.de
- config-dist.sh: disable emulated build for s390(loop does not work)
* Wed Sep  4 2002 bk@suse.de
- 390: use installation-kernel-rdripl as kernel rpm
- add config-dist.sh to ensure the host can do loop mounts
* Wed Sep  4 2002 snwint@suse.de
- ftp and samba installation on s390
- fixed bugs in ftp and VNC-installation on s390
- added ip to rescue system (#18644)
- added openssh to rescue system
* Tue Sep  3 2002 snwint@suse.de
- Modify WAIT_FOR_INTERFACES in /etc/sysconfig/network/config
* Mon Sep  2 2002 snwint@suse.de
- do start_shell also with usessh, there is a console anyway
- remove the info file for YaST1, not needed anymore
- checkproc & klogd for all
- refined theme support
- include xauth and libXmuu* for ssh -X mode
- removed minor bugs from scrips
- fixed suse.ins for new CD-Layout
- add ssh_host_rsa_key* to avoid changed hostkey after ssh installation
- add HISTCONTROL=ignoredups to /etc/profile in inst-sys
- correctet handling of HSI-interface in
  data/initrd/s390/bin/netsetsup
- removed hanging ping (-w-parameter)
- memorycheck buildin
- take passwd/shadow/group from aaa_base
- no apic on x86_64
* Wed Aug 28 2002 snwint@suse.de
- preserve installer name and use it in .bash_profile
  move yast2 debugging from inst_setup_ssh to inst_setup
  make the start_shell code multiline
  allow ssh installations everywhere, relies on YaST2.start support
  return to linuxrc if /tmp/YaST2_keep_sshd_running is not present
  add PATH to .bash_profile and print installer name
- apic is back
* Tue Aug 27 2002 snwint@suse.de
- ssh needs libgssapi now
* Tue Aug 27 2002 snwint@suse.de
- remove /etc/inst_setup_ssh and /etc/create_interface in inst-sys
- create new cd layout
- added all yast translations
- removed inst-sys dir
* Fri Aug 23 2002 msvec@suse.cz
- include czech yast2 translations for testing (#17780)
* Fri Aug 23 2002 ro@suse.de
- remove k_inst from neededforbuild
* Fri Aug 23 2002 snwint@suse.de
- added Option "ShadowFB" (#18235)
* Thu Aug 22 2002 stepan@suse.de
- add SuSE IA64 bootloader menu
* Thu Aug 22 2002 snwint@suse.de
- /usr/sbin vs. /sbin fun with xfs & dmapi
- samba package has innovative new layout
* Wed Aug 21 2002 snwint@suse.de
- support UL/SuSE themes
* Tue Aug 20 2002 snwint@suse.de
- no samba-classic-client package
- started to add yast2 translations
- added liby2util & yast2-packagemanager
* Mon Aug 19 2002 snwint@suse.de
- extended create_interface for broadcast-interfaces
- enabled create_interface for s390 and ppc
- corrected filelists
* Mon Aug 19 2002 snwint@suse.de
- use pcmcia in root image only on ia32
- start ssh in inst-sys when requested via UseSSH from install.inf
  create fresh hostkeys on sshd startup, or use provided hostkeys
  wenn booted with "nosshkey", default password is "root"
  boot option nossh is gone
  remove special s390 handling in inst_setup, use inst_setup_ssh if needed
  create resolv.conf from $nameserver and $domain, if set
  set hostname to IP:, if set, avoids root@(none) hostkeys
  do not use UsePrivilegeSeparation in inst-sys
* Mon Aug 19 2002 snwint@suse.de
- inst_source in sync with docu
- DASD-Parameter insertet
- added acl,attr,libmng libs to base file list
- fillup in separate package
- added pcnet32-old module
- fixed some lib dependencies
- handle UnitedLinux properly
- add ssh-keygen
- add ssh and related files, starting with release 8.1
- add a few ifarch ppc64 to ifarch ppc checks
* Sun Aug 18 2002 ro@suse.de
- added acl,attr,libmng libs to base file list
* Thu Aug 15 2002 snwint@suse.de
- mousedev module was lost in i386
* Mon Aug 12 2002 ro@suse.de
- k_apic is gone
* Mon Aug 12 2002 ro@suse.de
- removed splashanim from neededforbuild
* Mon Aug 12 2002 snwint@suse.de
- Include chpasswd, libpam_misc and /etc/pam.d/shadow so we can
  set a password for root using linuxrc.
- added grub to rescue system
- memtest is now a separate package
- splashanim is bootsplash* now
* Fri Aug  9 2002 snwint@suse.de
- added 'InputDevices' entries to XF86Config
- added mousedev.o to initrd
* Wed Aug  7 2002 ihno@suse.de
- corrected script create_interface
* Wed Aug  7 2002 snwint@suse.de
- traceroute no longer exists
* Wed Aug  7 2002 ihno@suse.de
- corrected file list and neededforbuild
* Tue Aug  6 2002 snwint@suse.de
- added locale libs (#17161)
* Tue Aug  6 2002 snwint@suse.de
- fixed typo in spec file
- removed qt & qt3-non-mt from neededforbuild
* Tue Aug  6 2002 froh@suse.de
- s390: fix remaining lib64 problems
- s390x is not s390 in etc/config any more
- s390: add etc/zfcp.conf
* Mon Aug  5 2002 froh@suse.de
- added multipath module
- add /usr/bin/reset to inst-sys
- symlink /sbin/fdisk to /usr/lib/YaST2/bin/fdisk
- remove hwclock_wrapper, use hwclock directly
- s390: added load from CD-rom or server helper files
- s390: removed hack to get %%version and %%release into the linuxrc prompt
- s390x: fix lib64 support
* Tue Jul 30 2002 olh@suse.de
- add initviocons to neededforbuild
* Mon Jul 29 2002 snwint@suse.de
- raid modules got accidentally removed from inst-sys
* Mon Jul 29 2002 snwint@suse.de
- more libz -> zlib fun
- fixed check_libs script
* Sat Jul 27 2002 kukuk@suse.de
- bzip -> bzip2, libz -> zlib
* Fri Jul 26 2002 adrian@suse.de
- fix neededforbuild
* Fri Jul 26 2002 sf@suse.de
- remove gdb (used for x86_64 as workaround)
* Thu Jul 25 2002 snwint@suse.de
- make it actually work on s390
* Wed Jul 24 2002 snwint@suse.de
- openssh needs kerberos libs now
- fixed initrd modules layout for non-ix86/x86_64 archs
* Mon Jul 22 2002 snwint@suse.de
- corrected error in /linuxrc and yast_start
* Mon Jul 22 2002 snwint@suse.de
- add usr/X11R6/lib64 to ld.so.conf
- fixed x86_64 typo
* Mon Jul 22 2002 snwint@suse.de
- use lib64/modules in XF86Config on x86_64
* Mon Jul 22 2002 snwint@suse.de
- added yast2-transfer
- 'KGAUniversal' option for vga16
- lvm needs its lib
* Tue Jul 16 2002 sf@suse.de
- corrected initrd_base.file_list
- use linuxrc with gdb on x86_64 for now
- don't build moddisk 1 as the initrd doesn't fit on it
* Tue Jul 16 2002 snwint@suse.de
- added yast2-update
* Tue Jul 16 2002 snwint@suse.de
- ihno: latest s390/s390x changes
* Mon Jul 15 2002 sf@suse.de
- added module.config.x86_64 to have less modules on moddisk3
- patch to increase no. of inodes on moduledisks
* Fri Jul 12 2002 snwint@suse.de
- remove explicit isa-pnp deps from module.config
* Fri Jul 12 2002 snwint@suse.de
- mkfs.cramfs has moved
- fixed package name handling
* Thu Jul 11 2002 snwint@suse.de
- added saxident
- corrected some devs package confusion
* Wed Jul 10 2002 snwint@suse.de
- avoid mixing 32/64 bit pthread libs
* Tue Jul  9 2002 snwint@suse.de
- make it possible to run rpm scripts chrooted
  (note: semantics of 'e/E' commands have changed, see docs!)
* Tue Jul  9 2002 snwint@suse.de
- ext2 has an upper inode number limit; avoid it building
  initrd on x86_64
* Mon Jul  8 2002 snwint@suse.de
- no kdb/pcmcia in initrd on ppc
- use makedevs.floppy on ppc
- add ide-floppy, mesh and mac53c94 to modules list
- set RPM_ARCH for makedevs script
- run prein script for openssh package
- added config for sd_mod.o & scsi_mod.o
- use cache=4 as default
- more inodes in initrd
* Mon Jul  8 2002 snwint@suse.de
- added autoyast2-installation
- fixed neededforbuild
* Fri Jul  5 2002 snwint@suse.de
- libpng fixes
* Fri Jul  5 2002 snwint@suse.de
- make it work with long package names
* Fri Jul  5 2002 kukuk@suse.de
- Use %%ix86 macro
* Wed Jul  3 2002 snwint@suse.de
- added yast2-x11
- added bc to neededforbuild
- don't build cd2 boot image
* Wed Jul  3 2002 snwint@suse.de
- add bin/ci_y2image_for_ppc, creates initrd on ppc
- add plain_initrd target
- new yast2 packages
* Thu Jun 20 2002 snwint@suse.de
- cdrom support is in kernel modules now
* Thu Jun 20 2002 snwint@suse.de
- fixed for x86_64
* Wed Jun 12 2002 snwint@suse.de
- yast2 package changes
- tar & sed are in separate packages
* Wed May 29 2002 snwint@suse.de
- added yast2-storage & libxml2 to neededforbuild
* Wed May 29 2002 snwint@suse.de
- added yast2-storage
- lib64 fixes
- make it work on x86_64
* Mon May 27 2002 snwint@suse.de
- yast2 wants qt3-mt now
- unified module handling for all archs (except s390*)
* Fri May 24 2002 snwint@suse.de
- no bootlogo on CD2 boot image
- liveeval changes
- updated module info for new kernel
- introduced 4th module disk
- added latest mips changes
- fixed bug in (empty) include file handling
* Fri May 17 2002 schwab@suse.de
- Update elilo configuration.
* Tue May 14 2002 schwab@suse.de
- Ignore non-critical errors.
* Thu Apr 25 2002 ro@suse.de
- deactivate bootlogo on small bootimages until kernel shrinks
  to a reasonable size to make the package build
- deactivated xfs for module disk 1 (>650K)
- deactivated aic7xxx_old for module disk 2
- lvm package currently has no library
- added libxcrypt
- libgpp is now libstdc++, filename libstdc++.so.4.0.0
- added libgcc to root and brescue (probably needed elswhere too)
- XXX if this does not work yet, add libgcc to other images ...
* Thu Apr 25 2002 ro@suse.de
- remove surprise from neededforbuild (package deleted)
- building "ps" image should probably be removed
* Sun Mar 24 2002 snwint@suse.de
- add sg.o module and sg* devices to initrd, they are needed
  for usb (scsi emulation!)
- added agetty to rescue system (#15429)
- don't include rpmqpack
- don't offer apic kernel on bootdisk
- use 'rescue=1' to start rescue system
* Thu Mar 21 2002 snwint@suse.de
- added FireWire modules again, as there's enough space left and it
  seems to work
- create a boot image for CD2, that won't ask for a module disk
- added module info for amdtp & cmp
* Mon Mar 18 2002 snwint@suse.de
- fixed typo in inst_setup
- ppc needs md.o
- ia64 doesn't have jfs.o
- dropped xfbdev, it's never used
- added /etc/inputrc (#12937)
* Sun Mar 10 2002 snwint@suse.de
- fixed typo in inst_setup
* Sat Mar  9 2002 snwint@suse.de
- re-enabled apic boot option
- prepare inst_setup to run other commands besides yast
- fixed ppc module list
* Tue Mar  5 2002 ro@suse.de
- really add yast2-trans-inst-proposal to root image
* Tue Mar  5 2002 ro@suse.de
- added yast2-trans-inst-proposal to neededforbuild
* Mon Mar  4 2002 snwint@suse.de
- add harddisk boot entry
- updated bootdisk README
* Sun Mar  3 2002 snwint@suse.de
- allow bootdisks to have the initrd on a module disk
- support really small initrd (no pcmcia, nearly no keytables)
- rearranged module disks
- prepare for module config to be arch dependent
- added ntfs driver (for harddisk installs)
- added usb network driver (pegasus)
- added trivial bootloader to module disk that just prints a message
- removed apic boot option
- new text boot message
* Fri Mar  1 2002 snwint@suse.de
- added 'gconf-modules' (#13991)
- added new network cards
- fixed lvm in rescue system (#13947)
- use special dietlibc smbmount
- increased initrd size
* Tue Feb 26 2002 snwint@suse.de
- added hex,attr,xfsdump,dmapi to neededforbuild
* Tue Feb 26 2002 snwint@suse.de
- some minor fixes (mainly xfs)
* Tue Feb 26 2002 ro@suse.de
- it's k_apic, not k_apci
* Mon Feb 25 2002 snwint@suse.de
- fixed rescue system (#13854)
- added ehci driver
- added apic kernel
- added xfs module
- added xfsprogs
* Sun Feb 24 2002 schwab@suse.de
- Increase initial initrd size again.
* Tue Feb 19 2002 ro@suse.de
- removed setclock and added /sbin/hwclock_wrapper from aaa_base
  (content is identical)
* Mon Feb 18 2002 snwint@suse.de
- drop firewire modules
- clear /module dir before starting yast2 if we don't have much memory
* Sat Feb 16 2002 ro@suse.de
- install root image now that it's built
* Fri Feb 15 2002 snwint@suse.de
- make it possible to create an initrd where linuxrc runs in gdb
- create cramfs images, too
- renamed files on module disks ("*-mod.gz" -> "*-modules")
- minor fixes in module list
- added timezone data to inst-sys
- add proceed hint to start_shell kernel arg
* Tue Feb 12 2002 snwint@suse.de
- increase free space on rescue disk
* Tue Feb 12 2002 snwint@suse.de
- fixed kbd dirs
- added pam modules (make sshd happy)
- removed ssh keys from /root/.ssh
* Mon Feb 11 2002 snwint@suse.de
- kbd things have been moved to /usr/share
- heimdal libs have been moved, too
- implemented better caching to speed things up
* Tue Feb  5 2002 snwint@suse.de
- added Xft fix again
* Mon Feb  4 2002 snwint@suse.de
- we have 3 module disks now
- usb modules are no longer on bootdisk
* Thu Jan 31 2002 ro@suse.de
- changed neededforbuild <libpng> to <libpng-devel-packages>
* Mon Jan 28 2002 ro@suse.de
- changed neededforbuild <yast2-agent-rcconfig> to <yast2-agent-ini>
* Mon Jan 28 2002 snwint@suse.de
- check for vfat support in config-dist.sh
* Mon Jan 28 2002 snwint@suse.de
- fixed package list
- Y2DEBUG no longer set
* Mon Jan 28 2002 ro@suse.de
- added missing yast2-packages to neededforbuild
* Wed Jan 23 2002 ro@suse.de
- removed non-existant packages from neededforbuild
* Mon Jan 21 2002 snwint@suse.de
- some new yast2 packs
- added smb stuff to large initrd
* Mon Jan 14 2002 ro@suse.de
- removed yast and lx_sus22 from neededforbuild
* Thu Jan 10 2002 snwint@suse.de
- write correct qtrc
* Tue Jan  8 2002 snwint@suse.de
- new module handling
- qt3-non-mt
- yast2-trans-inst-environment has been splitted
* Fri Jan  4 2002 snwint@suse.de
- added more yast2 packages
- added wget & openssl
* Thu Jan  3 2002 snwint@suse.de
- fixed minor bug in bin/check_libs
- XftConfig is no in xf86tools
- added libusb
- disabled check for ext2 in config-dist.sh
- diable xft
* Tue Dec 18 2001 snwint@suse.de
- added qt3 to neededforbuild
* Tue Dec 18 2001 snwint@suse.de
- yast2 needs qt3
- added libpkg to neededforbuild
* Tue Dec 18 2001 snwint@suse.de
- updated boot & module disks
- no french boot images
* Mon Dec  3 2001 olh@suse.de
- remove some kernel-installer-hint packages, never used
* Mon Nov 26 2001 snwint@suse.de
- add "start_shell" cmdline option to inst_setup
- fixed it to more or less build
* Thu Nov 22 2001 sf@suse.de
- added packages bzip, XFree86-compat-libs to neededforbuild
- modified initrd.file-list, rescue.file-list, root.file-list
  to adapt the changed location of some libs.
- make it build on Alpha again, removed some kernel modules that
  still do not build on Alpha
* Wed Nov 14 2001 ro@suse.de
- xf86glu is mesaglu again
- bootdisk (boot.small) still won't fit
* Fri Oct 19 2001 snwint@suse.de
- added popt to neededforbuild
* Fri Oct 19 2001 snwint@suse.de
- add 15bit to the fbdev section, needed on old pmacs (#11788)
- liveeval changes for 7.3
- added popt package
* Fri Oct  5 2001 kukuk@suse.de
- Fix removing of YaST1
* Wed Oct  3 2001 kukuk@suse.de
- Remove unused files from initrd for 32bit SPARC
* Tue Oct  2 2001 kukuk@suse.de
- No YaST1 for SPARC
* Tue Sep 25 2001 snwint@suse.de
- added mptbase.o & mptscsih.o (LSIFC9xx/LSI409xx Fibre Channel,#11251)
* Tue Sep 25 2001 snwint@suse.de
- add 'enableapic' to default boot entry
* Mon Sep 24 2001 snwint@suse.de
- removed 'rw' kernel parameter, this caused a fs check
  in some cases
* Thu Sep 20 2001 snwint@suse.de
- added /sbin/blockdev to inst-sys
- i386 bootdisk no longer defaults to 'manual'
- appended 'failsafe' parameters to 'failsafe' entry on bootdisk
  (this is _not_ needed for the gfx isolinux version) (#10925)
- automatically load network and storage drivers before starting
  rescue system (the is still the 'manual' option if this makes
  problems) (#10028)
- added 8390.o to bootdisk (#10696)
- added network modules to modules disk
- no nfs-server in rescue system
* Wed Sep 19 2001 snwint@suse.de
- forgot to add mk_splash in 1.96
- integrated bdflush patch into 1.97
- no longer ignore errors in ia32 build
* Tue Sep 18 2001 ro@suse.de
- removed references to bdflush: package deleted
* Tue Sep 18 2001 snwint@suse.de
- nfs-server: /var/state/nfs -> /var/lib/nfs
- splash is taken from splashanim package
- handle PReP zImage in yast1 post install
* Tue Sep 18 2001 snwint@suse.de
- prepare to build initrd with ext2 on ia32
- replace qla2x00.o with qla2[23]00.o
- ia32: remove modules from initrd before starting yast
* Thu Sep 13 2001 snwint@suse.de
- added cups-libs & nfs-utils to neededforbuild (s390 needs it)
* Tue Sep 11 2001 snwint@suse.de
- really use pcmcia-external modules
* Mon Sep 10 2001 snwint@suse.de
- new boot splash
- fixed typo in inst_setup
- added checkproc to instsys
* Sun Sep  9 2001 snwint@suse.de
- added 'top' to instsys
- work with gfxboot-1.4
- append boot splash to initrd
- linuxrc always reboots on bootdisks (due to k_inst)
* Thu Sep  6 2001 snwint@suse.de
- parted lib name had been changed, too
* Wed Sep  5 2001 snwint@suse.de
- parted has moved
* Tue Sep  4 2001 snwint@suse.de
- added root password for instsys
- added tulip & isa-pnp to module disks
* Mon Sep  3 2001 kukuk@suse.de
- Remove more modules on SPARC
- Don't include PS/2 keymaps (not needed on sparc32)
* Fri Aug 31 2001 kukuk@suse.de
- Add lvm/raid kernel modules to initrd on SPARC
* Fri Aug 31 2001 snwint@suse.de
- 'make root' no longer implicitly builds initrd
* Thu Aug 30 2001 kukuk@suse.de
- Remove old X server for Sun from inst-sys
* Thu Aug 30 2001 snwint@suse.de
- make non-ia32 archs build again
* Wed Aug 29 2001 snwint@suse.de
- bootdisk: kernel from k_inst, modules from k_deflt
* Wed Aug 29 2001 snwint@suse.de
- re-added usb-storage to bootdisk
* Wed Aug 29 2001 snwint@suse.de
- added vmstat to inst-sys
- use k_inst for boot disks
* Tue Aug 28 2001 snwint@suse.de
- create new modules.dep at start of the installation
- use only _some_ files from /usr/lib/gconv
- added jbd.o
- added fs modules to rescue system
* Mon Aug 27 2001 snwint@suse.de
- added 'extramod' env var to assist creating specialized boot disks
- added jfs.o, ext3.o
* Mon Aug 27 2001 ro@suse.de
- replaced <smbclnt> by <samba-client> in neededforbuild
* Fri Aug 24 2001 snwint@suse.de
- fixed typo
* Wed Aug 22 2001 snwint@suse.de
- re-added gconv directory
* Mon Aug 20 2001 snwint@suse.de
- adapt to aaa_dir changes
* Mon Aug 20 2001 snwint@suse.de
- improved inst_setup script
- new motd/issue files
- dropped 'ifdef' support
* Sun Aug 19 2001 olh@suse.de
- add a few *-installer-hint.rpms for ppc to avoid warnings
* Wed Aug 15 2001 snwint@suse.de
- make sure all CVS files are actually present
* Tue Aug 14 2001 froh@suse.de
- initrd works on s390: netsetup, ssh login, linuxrc working
* Tue Aug 14 2001 snwint@suse.de
- added jfsprogs to neededforbuild
* Mon Aug 13 2001 snwint@suse.de
- added jfsprogs to inst-sys & rescue
- added hdparm to rescue
* Fri Aug 10 2001 kukuk@suse.de
- Remove 3.3.6 X server for SPARC, 4.1.0 works for all now
* Fri Aug 10 2001 snwint@suse.de
- added 'failsafe' boot menu entry
* Fri Aug 10 2001 snwint@suse.de
- added yast2-lib-sequencer
* Fri Aug 10 2001 snwint@suse.de
- fixed typo in rescue system
* Thu Aug  9 2001 snwint@suse.de
- added ssh to inst-sys (in pre-releases only)
- added inst_setup
* Mon Aug  6 2001 snwint@suse.de
- 'no emulation' boot instead of 2.88MB floppy emulation on CD1
  (isolinux vs. syslinux)
* Mon Aug  6 2001 snwint@suse.de
- new 'pre_release' variable
* Wed Aug  1 2001 snwint@suse.de
- more inodes for rescue system
* Wed Aug  1 2001 snwint@suse.de
- use linuxrc_tiny in 'small' initrd
* Mon Jul 30 2001 snwint@suse.de
- dropped some mods to make it build
* Mon Jul 30 2001 snwint@suse.de
- _no_ network modules on moddisk#1
* Fri Jul 27 2001 schwab@suse.de
- Add filesystem kernel modules to initrd on ia64.
- Increase initial initrd size.
* Wed Jul 25 2001 snwint@suse.de
- create correct fonts.dir
- various file list fixes
- started to rework module handling
* Thu Jul 19 2001 snwint@suse.de
- check for loop device support in config-dist.sh
* Thu Jul 19 2001 snwint@suse.de
- joerc has moved to /etc
* Thu Jul 19 2001 snwint@suse.de
- fixed typo to make axp work again
* Wed Jul 18 2001 schwab@suse.de
- Use elilo instead of gnu-efi.
* Tue Jul 17 2001 snwint@suse.de
- support gcc 3.0
- made it work with xf86 4.1
- *.file_list cleanup
- check yast2 package list consistency
* Mon Jul 16 2001 snwint@suse.de
- fixed elsif
- removed unnecessary keytable includes
- started to drop support for SL < 7.2
- dropped /usr/lib/gconv/
* Sat Jul 14 2001 kukuk@suse.de
- Fix /lib/ld* rules
* Fri Jul 13 2001 olh@suse.de
- remove yast2-core-translator from file list
* Fri Jul 13 2001 ro@suse.de
- removed yast2-core-translator from needed
* Fri Jul 13 2001 olh@suse.de
- add yast2-agent-system to neededforbuild
* Tue Jul 10 2001 olh@suse.de
- always add /lib/ld{.,-}*
* Tue Jul 10 2001 olh@suse.de
- update for ppc
  add freetype2.rpm
  umsprogs i386 only
  /usr/X11R6/lib/modules/*.uc maybe i386 only
* Wed Jun 27 2001 snwint@suse.de
- integrated latest ia64/sparc patches
- added new 'F' command (cf. README)
* Tue Jun 19 2001 schwab@suse.de
- Increase the number of inodes in rescue filesystem.
* Tue Jun 12 2001 snwint@suse.de
- remove /etc/X11/xserver/C/ from inst-sys (saves about 12MB)
* Mon Jun  4 2001 kukuk@suse.de
- Enable reiserfs on SPARC, change tilo call for new version
* Fri Jun  1 2001 kukuk@suse.de
- Add yast2-agent-prom on SPARC
* Mon May 28 2001 schwab@suse.de
- Adjust elilo config file for gnu-efi 2.5.
* Sun May 20 2001 schwab@suse.de
- Make rescue system on ia64.
* Mon May 14 2001 snwint@suse.de
- updated README for CD1/disks/
* Fri May 11 2001 snwint@suse.de
- remove lessopen/close from rescue system (#8101)
* Thu May 10 2001 kukuk@suse.de
- Fix to build on SPARC
* Thu May 10 2001 snwint@suse.de
- drop permission fix for /lib/modules in root.file_list completely
  (not needed anyway)
* Thu May 10 2001 snwint@suse.de
- changed libdri patch to: no libdri.a on ia64
- added usleep to rescue system
* Wed May  9 2001 snwint@suse.de
- no libdri.a except on ia32
- no agp module in xsvga for ia64
- no blinux link unless sbl package is installed
* Wed May  9 2001 snwint@suse.de
- next try to fix it
* Wed May  9 2001 snwint@suse.de
- removed fix
- added gfxboot-devel to neededforbuild
* Wed May  9 2001 kukuk@suse.de
- Fix last fix
* Wed May  9 2001 kukuk@suse.de
- Adept new locations of files
* Tue May  8 2001 snwint@suse.de
- worked on module lists
- back to 2.88MB boot image
- added yast2-db-groups,finger,rsh,telnet to neededforbuild
* Mon Apr 30 2001 snwint@suse.de
- kendy: have fix_locale link all utf8 locales to en_US.utf8
- support creation of isolinux boot CDs
- gfx boot images are taken from gfxboot package now
- added nvram.o back to (small) initrd
- new elilo.conf
* Wed Apr 25 2001 snwint@suse.de
- create utf8-links in fix_locale
- stop on missing modules
- added missing euro keytables to initrd
- more yast2 packages
- added pcmcia to neededforbuild
* Tue Apr 24 2001 snwint@suse.de
- more mods & utils in rescue system
- re-added some tools formerly in nkitb
- no memtest on boot floppy
* Tue Apr 24 2001 snwint@suse.de
- added loop_fish2.o to inst-sys
- added fs modules (raid, lvm, etc.) to rescue system
* Mon Apr 23 2001 snwint@suse.de
- more yast2 stuff
* Sun Apr 22 2001 kukuk@suse.de
- Fix last changes
* Sat Apr 21 2001 kukuk@suse.de
- Disable root image
* Thu Apr 19 2001 snwint@suse.de
- added tee
* Wed Apr 18 2001 snwint@suse.de
- fixed evil bug in 'elsif' implementation
* Wed Apr 18 2001 snwint@suse.de
- integrated latest ia64 changes (by schwab)
- kkaempf: add y2d* packages
* Wed Apr 11 2001 ro@suse.de
- removed smp from neededforbuild (deleted package)
* Tue Apr 10 2001 schwab@suse.de
- neededforbuild eli -> gnu-efi.
- Update for new boot loader on ia64.
- Include raidutils in root on ia64.
* Sun Apr  8 2001 snwint@suse.de
- new boot logo
* Sat Apr  7 2001 snwint@suse.de
- removed some non-existent yast2 packages from neededforbuild
* Fri Apr  6 2001 snwint@suse.de
- added lvm mods
- boot floppy didn't ask for modules disk
- fixed neededforbuild
* Wed Apr  4 2001 snwint@suse.de
- fixed rescue system
- yast2 reworked again
* Tue Apr  3 2001 snwint@suse.de
- added graphical boot screen
- bootdisk should build
* Fri Mar 30 2001 snwint@suse.de
- renamed package
- yast2 reworked again
- tuned module list
* Tue Mar 27 2001 snwint@suse.de
- new yast2 package names
- added GL support
* Tue Mar 20 2001 snwint@suse.de
- awk now needed for all archs
* Fri Mar 16 2001 snwint@suse.de
- copy vmlinuz_24 to /CD1/suse/images/k_deflt
* Fri Mar 16 2001 snwint@suse.de
- more or less ready for 7.2/kernel 2.4
* Tue Mar  6 2001 snwint@suse.de
- re-enabled yast2 for alpha
- it's now possible to remove yast2 via environment: 'with_yast2=no'
* Thu Mar  1 2001 snwint@suse.de
- _disabled_ yast2 for alpha
* Tue Feb 27 2001 snwint@suse.de
- fixed file lists (readline vs. bash)
- added readline to neededforbuild
- don't build liveeval boot image
* Tue Feb 27 2001 snwint@suse.de
- integrated latest changes by ro & kukuk
- fixed bug in ia64 boot image code (image was 2 bytes to short)
- we can now prepare hard disk boot images
- enabled yast2 for alpha
- added nasm to neededforbuild
* Mon Feb 26 2001 ro@suse.de
- libreadline is in readline package now
* Thu Feb 22 2001 kukuk@suse.de
- Add missing keymaps for SPARC
* Wed Feb 21 2001 kukuk@suse.de
- Adjust patch for liblvm
* Sat Feb 17 2001 kukuk@suse.de
- Add libdri.a back, some xf86 4.0 modules need it
* Wed Feb 14 2001 kukuk@suse.de
- Add xglint to needed for build
* Thu Feb  8 2001 olh@suse.de
- fix parted file list
* Thu Feb  8 2001 olh@suse.de
- use correct LVM libs*
* Thu Feb  8 2001 olh@suse.de
- remove unneeded ppc kernel rpms
* Tue Feb  6 2001 snwint@suse.de
- added parted (ppc)
* Sat Feb  3 2001 snwint@suse.de
- fixed spec
* Fri Feb  2 2001 snwint@suse.de
- removed ext2 abuild test from spec file
- added /sbin/nvsetenv to inst-sys (ppc only)
* Fri Feb  2 2001 snwint@suse.de
- olh: add hfsutils, build only the root image on ppc
- olh: updated /usr/bin/setclock
- liveeval updated for 7.1
* Sat Jan 27 2001 kukuk@suse.de
- Add i386 keytables for SPARC/PS/2 keyboards
* Tue Jan 23 2001 schwab@suse.de
- eli.cfg: Add loaddisk when installing with yast1.
* Mon Jan 22 2001 snwint@suse.de
- extended *file_list syntax
* Sun Jan 21 2001 ro@suse.de
- added config-dist.sh for filesystem guess
* Thu Jan 18 2001 snwint@suse.de
- syslogd logs to /dev/null if tty4 is not a console
  (ro: don't move it to 7.1-i386)
* Wed Jan 17 2001 snwint@suse.de
- fixed typo in spec
* Wed Jan 17 2001 snwint@suse.de
- added scsi mods to root images
- make sure 8390.o is on all boot disks
- fixed SuSE-release handling
* Wed Jan 17 2001 snwint@suse.de
- dropped live boot/root images
- added gpart to neededforbuild
* Wed Jan 17 2001 ro@suse.de
- fixed ext2 check for initrd leftover in proc/mounts
* Tue Jan 16 2001 snwint@suse.de
- added gpart
- fixed mod disk1 module list
* Tue Jan 16 2001 snwint@suse.de
- put ext2 check back in, ia32 only
* Tue Jan 16 2001 ro@suse.de
- blocksize detection i386 only
* Tue Jan 16 2001 snwint@suse.de
- fixed module lists
* Tue Jan 16 2001 ro@suse.de
- don't guess filesystem, guess blocksize
* Tue Jan 16 2001 ro@suse.de
- updated build-fs detection
* Mon Jan 15 2001 snwint@suse.de
- fixed rescue system (reboot now works)
- make scsi/net module loading work in linuxrc
* Sun Jan 14 2001 snwint@suse.de
- more module list fixes
- create /etc/need_modules_disk on floppy images
  so linuxrc asks for modules disk automatically
* Sun Jan 14 2001 snwint@suse.de
- fixed module lists
- bootdisk no longer has _any_ scsi/net modules
- removed laptop floppy from spec file
* Fri Jan 12 2001 snwint@suse.de
- missing braille start script added
- syslogd moved to /sbin
- make it possible to consistently reload the module disk
- no laptop floppy
* Fri Jan 12 2001 ro@suse.de
- fix for syslog move
* Tue Jan  9 2001 snwint@suse.de
- drop all XFree86 3.x servers (ia32 only)
- add /usr/bin/od
- use long filenames on modules disk
* Sun Jan  7 2001 ro@suse.de
- create lang/fr/CD2 dir
* Sun Jan  7 2001 snwint@suse.de
- fixed rescue-system
- added 8139too.o/BusLogic.o to module disk
* Sun Jan  7 2001 snwint@suse.de
- integrated v1.23 diffs
- add firegl2 & 3 driver
- dropped serial.o
- re-added fbdev_drv.o
* Sun Jan  7 2001 snwint@suse.de
- add CD2 boot image
* Fri Jan  5 2001 kukuk@suse.de
- Updates for SPARC
- Fix location of libz
* Thu Jan  4 2001 kendy@suse.cz
- patched bin/fix_locale to link iso2 languages to cs_CZ, not en_US
* Tue Jan  2 2001 msvec@suse.cz
- added trivial console translation
* Sun Dec 31 2000 olh@suse.de
- update for ppc instsys
* Fri Dec 22 2000 ro@suse.de
- changed neededforbuild <dosfstls> to <dosfstools>
* Wed Dec 20 2000 ro@suse.de
- build it only on ext2
* Mon Dec 18 2000 snwint@suse.de
- agpgarti810 device no longer in xsvga package
* Fri Dec 15 2000 snwint@suse.de
- fixed minor bug in boot disk creation
* Fri Dec 15 2000 snwint@suse.de
- dropped 'update' boot option
- booting with 'yast1' now makes linuxrc load scsi/blkdev mods
- less modules
- creation of boot disks now considerably faster
- no rescue system for ia64
* Fri Dec 15 2000 ro@suse.de
- try to make it build
* Wed Dec 13 2000 snwint@suse.de
- chvt & loadkeys have been moved to /bin
* Tue Dec 12 2000 snwint@suse.de
- hwinfo needs its shared lib
- added locale again (all linked to en_US)
- reordered building of boot images to speed it up a bit
* Sat Dec  9 2000 snwint@suse.de
- avoid insserv error msg
- fixed kbd include file list
- libz moved to /lib
* Fri Dec  8 2000 ro@suse.de
- fixed file-list for new kbd
* Wed Dec  6 2000 snwint@suse.de
- added cache for rpms
- renamed mdutils -> raidtools
- new y2[dt]_* packages!!!
* Wed Dec  6 2000 ro@suse.de
- replaced mdutils by raidtools
* Tue Dec  5 2000 snwint@suse.de
- create /lang/fr/CD1/disks
* Tue Dec  5 2000 snwint@suse.de
- added dosfsck
- added README/LIESMICH for CD1/disks dir
- added CD1/disks/k_deflt
- fixed to work with new fileutils
* Tue Dec  5 2000 snwint@suse.de
- fix xkb problem
- updated modules disks
- build module disks here (no longer in bootdisk package)
- renamed bootdisks (cf. bootdisk package):
    yast2    --> bootdisk
    bootdisk --> i386
* Mon Dec  4 2000 ro@suse.de
- build fixes (temporarily removed some modules ...)
* Sun Dec  3 2000 ro@suse.de
- adapted neededforbuild
* Sat Dec  2 2000 kukuk@suse.de
- Quick hacks to get it build
* Fri Dec  1 2000 snwint@suse.de
- updated ci_y2image to include disk_* files
* Fri Dec  1 2000 kukuk@suse.de
- Add missing file lists
* Fri Dec  1 2000 snwint@suse.de
- prepared to build rescue CD
- build various boot disks directly
- fixed file lists
* Fri Nov 24 2000 snwint@suse.de
- changed initrd to work with new kbd package
* Wed Nov 22 2000 snwint@suse.de
- fixed neededforbuild
* Tue Nov 21 2000 snwint@suse.de
- now builds rescue system
- renamed ix86 -> ia32
- made root & demo images build again
- added check for shared lib dependencies
* Thu Nov 16 2000 snwint@suse.de
- added support for loopc.o compression module (image "susee")
- support for compressing loop device (cloop.o)
- moved LiveEval images to suse/images/
- started to switch to new package names
- improved error handling on missing files
- dropped locale stuff
- integrated 7.0-ppc changes
- renamed 'yast2' to 'root'
- startet to drop unneeded stuff: libjpeg,libpng,libz,libmng
* Mon Nov  6 2000 kukuk@suse.de
- Change qtlib2 -> qt
- Set Autoreqprov to off
- Use SuSE internal group
* Thu Sep 28 2000 snwint@suse.de
- more sophisticated ia64 boot config
* Wed Sep 20 2000 schwab@suse.de
- Add eli to neededforbuild.
* Wed Sep 20 2000 snwint@suse.de
- ia64: added keytables & modules
* Tue Sep 19 2000 snwint@suse.de
- create a boot image for ia64
* Thu Sep 14 2000 snwint@suse.de
- no yast2/x11 on axp
* Thu Sep 14 2000 snwint@suse.de
- fixed bug in kernel version number handling
* Wed Sep 13 2000 snwint@suse.de
- added i2o modules (module disk1)
- rewrote etc/config & lib/ReadConfig.pm to handle more
  complex SuSE release names
- increased initial root image size in mk_yast2
* Fri Aug 25 2000 snwint@suse.de
- needed in 7.0-i386 to get updated live/liveeval images
* Thu Aug 24 2000 snwint@suse.de
- increased initial initrd size
- file list fixes for alpha
* Thu Aug 24 2000 olh@suse.de
- remove yaboot and activate from neededforbuild, now in lilo.rpm
* Tue Aug 22 2000 snwint@suse.de
- fixed bin/ci_bootdisk to patch syslinux.cfg.fr too
- introduced new 'if' statement to *.file_list
- ro: activate yast2 fo alpha
- allow indentation in *.file_list
- introduced 'elsif' statement to *.file_list
- ppc kbd & xf86 changes
- updated docu
* Thu Aug 17 2000 snwint@suse.de
- new kbd package for 7.1 only
* Wed Aug 16 2000 snwint@suse.de
- fixed strip_dir to handle strange filenames
- 7.0 live/eval done
- changes to deal with the new kbd package
* Mon Aug 14 2000 schwab@suse.de
- Add initdisk.gz on ia64.
* Mon Jul 24 2000 snwint@suse.de
- *dropped* sw_cursor for XF3 (trouble with i810)
- live/eval fixes
- kukuk: we don'thave xfbdev on sparc
* Sat Jul 22 2000 kukuk@suse.de
- Move message file and silo.conf to bootdisk
* Fri Jul 21 2000 kukuk@suse.de
- we don'thave xfbdev on sparc
* Wed Jul 19 2000 snwint@suse.de
- sw_cursor even for XF3
* Wed Jul 19 2000 snwint@suse.de
- moved french images to /lang/fr/...
- no french subpackage
- live/liveeval subpackage
* Tue Jul 18 2000 snwint@suse.de
- dropped some mods
* Mon Jul 17 2000 snwint@suse.de
- removed imm.o/ppa.o from modules disk
- made french the default language on french disks
- added xargs,tr,old to inst-sys
* Sat Jul 15 2000 snwint@suse.de
- worked on the module lists
- introduced the chk_modules script to check the module lists
* Fri Jul 14 2000 snwint@suse.de
- added parport_probe.o
- added syslogd (started by linuxrc)
- added missing get_kernel_version
- made subpackage y2image2 for live/liveevel/partition suprise/french images
* Mon Jul 10 2000 snwint@suse.de
- added taper & surprise to#neededforbuild
* Mon Jul 10 2000 snwint@suse.de
- removed imm.o & ppa.o from initrd
- added partition surprise image
- changed demo= parameter [was: yes, old; is: eval, live, ps]
- added french boot images (.fr extension)
* Fri Jul  7 2000 snwint@suse.de
- olh: add missed mac-de map
- kukuk: Minor fixes for SPARC
- olh: add available mac keytables, fix typo in spec file
- schwab: [ef]?grep moved to /bin
- added "sw_cursor" to XF4 XF86Config
* Thu Jul  6 2000 olh@suse.de
- add missed mac-de map
* Thu Jul  6 2000 kukuk@suse.de
- Minor fixes for SPARC
* Thu Jul  6 2000 olh@suse.de
- add available mac keytables, fix typo in spec file
* Wed Jul  5 2000 snwint@suse.de
- added XkbKeycodes to XF86Config
- added parport mods (for Zip)
- fixed: modules.dep was not created
* Mon Jul  3 2000 snwint@suse.de
- added BlankTime option to XF4 config file
- Andreas' ia64 patches
* Thu Jun 29 2000 snwint@suse.de
- reiserfs for ia32 only
- fixed /.rpm-cache problems
* Thu Jun 29 2000 ro@suse.de
- remove pas16 to make it build
* Wed Jun 28 2000 snwint@suse.de
- [temporary] removed some pcmcia mods to make it build
* Wed Jun 28 2000 snwint@suse.de
- workaround in XF4 config file to fix mouse problems
* Tue Jun 27 2000 snwint@suse.de
- put "Auto" proto back in XF4 config
* Tue Jun 27 2000 snwint@suse.de
- new usb devs
- use /.rpm-cache in autobuild
- fixed initrd mod list
- added y2t_inst, cron, ltrace, xfiregl1, sysvinit, sbl
  to neededforbuild
* Tue Jun 27 2000 ro@suse.de
- added xloader to neededforbuild
* Thu Jun 22 2000 snwint@suse.de
- prepeared XF86Config for options & extensions
* Wed Jun 21 2000 snwint@suse.de
- worked on module lists
* Tue Jun 20 2000 ro@suse.de
- removed pas16.o to make it build
* Tue Jun 20 2000 snwint@suse.de
- fixed boot patch
* Tue Jun 20 2000 snwint@suse.de
- added saxtools
- added unicode fonts from y2base
- worked on module list
* Wed Jun  7 2000 snwint@suse.de
- added rc.status to demo image
* Wed Jun  7 2000 snwint@suse.de
- fixed filelist typo
- added unicode to fontpath in XF4.0
* Wed Jun  7 2000 snwint@suse.de
- XF86Config fixes
* Wed Jun  7 2000 snwint@suse.de
- fixed several bugs in the scripts
- filelist fixes for inst-sys (due to progs moved form /usr/bin to /bin)
* Tue Jun  6 2000 snwint@suse.de
- integrated the various ia32 boot disks: cf. 'data/initrd/disk_*'
- re-added mkdosfs stuff
* Mon Jun  5 2000 snwint@suse.de
- added latest *dif
- fixed demo for 7.0 (boot & halt patches)
- ready for 7.0 yast2
- Wrote a short README. :-))
- removed mkdosfs package (*and* the progs in it)
* Sat Jun  3 2000 olh@suse.de
- mv ramdisk.image.gz to suseboot on ppc
* Tue May 30 2000 kukuk@suse.de
- fix initrd for SPARC: Adjust kernel module paths,
  remove openprom module
* Mon May 29 2000 snwint@suse.de
- fixed Makefile typo
* Tue May 16 2000 snwint@suse.de
- integrated 0.43'er difs
- live/liveeval changes
- scripts now automatically try to fit the initrd on the boot disk
- use minix for initrd on ix86
- removed initrd2/boot2 stuff (-> use initrd & boot instead)
* Tue May 16 2000 snwint@suse.de
- first pre-7.0 version
* Fri May 12 2000 ro@suse.de
- added ramdisk.image.gz for ppc
* Wed May  3 2000 kukuk@suse.de
- Use always ext2 for initrd2
* Wed May  3 2000 kukuk@suse.de
- Fix doc path for makedevs.floppy
* Sat Apr 29 2000 kukuk@suse.de
- Add libICE, libSM and libpng for YaST2
- Add /usr/lib/qt2/lib to ld.so.conf
- sparc: Network drivers are now in misc !?
- /sbin/portmap is now in packages portmap
- xservers is now in /etc/X11
- nls doesn't seem to exist any longer
- libXext has a new version
* Thu Apr 27 2000 snwint@suse.de
- demo cd changes
- ppc: added fbset stuff
* Wed Apr 26 2000 snwint@suse.de
- integrated 0.39 ppc dif (added gawk)
- integrated 0.41 dif (no mods stripped, -> shorter mod list)
- added setclock to inst-sys
* Thu Apr 20 2000 ro@suse.de
- don't strip modules
* Tue Apr 18 2000 snwint@suse.de
- Rudi's axp patches
- live cd stuff
- different images for 'classic' live cd & for the new liveeval
* Tue Apr 18 2000 ro@suse.de
- disabled yast2 for alpha
* Mon Apr 17 2000 kukuk@suse.de
- Add tftp boot image for SPARC
* Mon Apr 17 2000 snwint@suse.de
- specfile-fix
* Wed Apr 12 2000 ro@suse.de
- fixed file-list for root-img on alpha
- remove other alpha specific-hacks: moved to bootdis2-package
* Tue Apr 11 2000 snwint@suse.de
- live cd changes
* Mon Apr 10 2000 snwint@suse.de
- lots of changes to build live CD
- fix: agpgarti810 device was missing!
- added eject to inst-sys
- ppc: added yaboot
* Tue Apr  4 2000 snwint@suse.de
- neededforbuild fix for *all* archs
* Mon Apr  3 2000 ro@suse.de
- specfile fix
* Mon Apr  3 2000 snwint@suse.de
- axp module list changes
- script to generate install_xx
* Mon Apr  3 2000 snwint@suse.de
- activate on ppc
* Mon Apr  3 2000 snwint@suse.de
- ppc fixes
* Mon Mar 27 2000 kukuk@suse.de
- sparc fixes
* Thu Mar 23 2000 snwint@suse.de
- ppc fixes
* Wed Mar 22 2000 snwint@suse.de
- sparc & ppc improvements
- package should be architecture independent now
* Tue Mar 21 2000 kukuk@suse.de
- Add Xsun* and Xmach64 to need for build
- Increase initial root size.
* Tue Mar 21 2000 kukuk@suse.de
- Fix initrd and yast2 file list for SPARC
- Copz makedevs.floppy from devs package
* Mon Mar 20 2000 kukuk@suse.de
- added initrd for SPARC
* Sun Mar 19 2000 ro@suse.de
- added initdisk.gz
* Fri Mar 17 2000 ro@suse.de
- changed filelist to CD-layout
* Thu Mar 16 2000 snwint@suse.de
- setfont workaround
* Mon Mar 13 2000 snwint@suse.de
- added /bin/loadkeys
* Thu Mar  9 2000 snwint@suse.de
- new XF86Config
* Tue Mar  7 2000 snwint@suse.de
- fixed wrong module link
* Tue Mar  7 2000 snwint@suse.de
- added libhd to spec file
* Mon Mar  6 2000 snwint@suse.de
- pcmcia mods from kernel package
* Mon Mar  6 2000 snwint@suse.de
- pcmcia mods were copied to wrong place
* Mon Mar  6 2000 snwint@suse.de
- added lp mod to root image
- added some cdrom mods to initrd
* Mon Mar  6 2000 ro@suse.de
- added recode to neededforbuild
- provide gzipped root-image
* Sun Mar  5 2000 snwint@suse.de
- some minor module list fixes
- new devs
* Sat Mar  4 2000 snwint@suse.de
- added pcmcia tools
- added VGA16 server
- more unicode fonts for yast2
- reworked module list
- added modules that didn't fit onto the 2.88MB image to the root image
* Wed Mar  1 2000 snwint@suse.de
- removed unnecessary locales
* Tue Feb 29 2000 snwint@suse.de
- unicode X11 stuff
* Mon Feb 28 2000 snwint@suse.de
- integrated 0.22 difs
* Mon Feb 28 2000 ro@suse.de
- removed slip.o/ppp*.o from initrd2
* Mon Feb 28 2000 ro@suse.de
- run depmod safely in autobuild
* Sun Feb 27 2000 ro@suse.de
- make boot2 fit on 2.88
* Sat Feb 26 2000 snwint@suse.de
- merged last changes into CVS
- removed modules
* Sat Feb 26 2000 ro@suse.de
- merged with instsys (hope all that's needed)
* Fri Feb 25 2000 snwint@suse.de
- add modules to inst-sys
- new if's: ifabuild & ifnabuild
* Thu Feb 24 2000 ro@suse.de
- cleaned neededforbuild, added linuxrc , syslinux
- still needs to be fixed for non-x86: shlibs have different versions
* Wed Feb 16 2000 snwint@suse.de
- adapted to new yast2
* Mon Feb  7 2000 snwint@suse.de
- added "manual" boot config
* Thu Feb  3 2000 ro@suse.de
- fixed welcome message for cebit
- added shared libreadline
* Wed Feb  2 2000 ro@suse.de
- fixed other occurences of kernmod and k_pentiu
* Wed Feb  2 2000 ro@suse.de
- needs k_deflt instead of k_pentiu or k_alpha
* Thu Jan 27 2000 ro@suse.de
- removed ldso (ldconfig is part of libc)
- removed kernmod (modules are part of installed kernels)
- reworked filelists
  no loop.o (is compiled into install-kernel for a while)
  ncurses is 5.0, jpeg is 62, ldconfig in shlibs
  rpcinfo is in /usr/sbin in shlibs
  kernel-modules are in k_pentium: FIXME on non-x86
* Mon Dec  6 1999 snwint@suse.de
- removed net/epic100.o from initrd (not enough space left)
* Wed Nov 10 1999 snwint@suse.de
- added accel section to XF86Config
* Tue Nov  9 1999 snwint@suse.de
- changed framebuffer line in syslinux.cfg
* Mon Nov  8 1999 snwint@suse.de
- SVGA server instead of VGA16
* Fri Nov  5 1999 snwint@suse.de
- more /dev/ram's
* Thu Nov  4 1999 snwint@suse.de
- probably no changes
* Thu Nov  4 1999 snwint@suse.de
- new modules
* Thu Nov  4 1999 ro@suse.de
-added kernels
* Wed Nov  3 1999 snwint@suse.de
- added AXP stuff
* Tue Nov  2 1999 snwint@suse.de
- added the smp program
* Mon Nov  1 1999 snwint@suse.de
- removed id_list
* Sat Oct 30 1999 snwint@suse.de
- file list update
- new yast2rc
* Fri Oct 29 1999 snwint@suse.de
- yast2rc changes
* Fri Oct 29 1999 snwint@suse.de
- hopefully it's now correct
* Wed Oct 27 1999 snwint@suse.de
- image size is now automatically set
* Tue Oct 26 1999 snwint@suse.de
- /lib/YaST2 permissions fixed
* Tue Oct 26 1999 ro@suse.de
- added ash to neededforbuild
* Tue Oct 26 1999 snwint@suse.de
- added {ash,insmod}.static
* Mon Oct 25 1999 snwint@suse.de
- removed absolute PATH for *.rpms
* Mon Oct 25 1999 snwint@suse.de
- new file lists
* Wed Oct 20 1999 snwint@suse.de
- refined init-sys file list
- added isax
* Mon Oct 18 1999 snwint@suse.de
- new version that works with current yast2's
* Wed Oct 13 1999 snwint@suse.de
- package created
